/*= RS SMIQ Vector Signal Generator Include File ============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
	 
#ifndef __rssmiq_HEADER
#define __rssmiq_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_FILE_READ                (_VI_ERROR+0x3FFC0802L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/

#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)
#define RSSMIQ_ERROR_INSTR_PARAMETER16          (VI_ERROR_INSTR_OFFSET+0L)
#define RSSMIQ_ERROR_INSTR_PARAMETER17          (VI_ERROR_INSTR_OFFSET+1L)
#define RSSMIQ_ERROR_INSTR_PARAMETER18          (VI_ERROR_INSTR_OFFSET+2L)
#define RSSMIQ_ERROR_INSTR_PARAMETER19          (VI_ERROR_INSTR_OFFSET+3L)
#define RSSMIQ_ERROR_INSTR_PARAMETER20          (VI_ERROR_INSTR_OFFSET+4L)
#define RSSMIQ_ERROR_INSTR_PARAMETER21          (VI_ERROR_INSTR_OFFSET+5L)

#define RSSMIQ_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSSMIQ_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSMIQ_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)

#define RSSMIQ_OPT_B1     (1 << 0)  /* 0x1 */
#define RSSMIQ_OPT_B5     (1 << 1)  /* 0x2 */
#define RSSMIQ_OPT_B10    (1 << 2)  /* 0x4 */
#define RSSMIQ_OPT_B11    (1 << 3)  /* 0x8 */
#define RSSMIQ_OPT_B12    (1 << 4)  /* 0x10 */
#define RSSMIQ_OPT_B12SEC (1 << 5)  /* 0x20 */
#define RSSMIQ_OPT_B14    (1 << 6)  /* 0x40 */
#define RSSMIQ_OPT_B15    (1 << 7)  /* 0x80 */
#define RSSMIQ_OPT_B16    (1 << 8)  /* 0x100 */
#define RSSMIQ_OPT_B20    (1 << 9)  /* 0x200 */
#define RSSMIQ_OPT_B21    (1 << 10) /* 0x400 */
#define RSSMIQ_OPT_B42    (1 << 11) /* 0x800 */
									/* 0x1000 */
#define RSSMIQ_OPT_B44    (1 << 13) /* 0x2000 */
#define RSSMIQ_OPT_B45    (1 << 14) /* 0x4000 */
#define RSSMIQ_OPT_B46    (1 << 15) /* 0x8000 */
#define RSSMIQ_OPT_B47    (1 << 16) /* 0x10000 */
#define RSSMIQ_OPT_B48    (1 << 17) /* 0x20000 */
#define RSSMIQ_OPT_B60    (1 << 18) /* 0x40000 */
#define RSSMIQ_OPT_K11    (1 << 19) /* 0x80000 */
#define RSSMIQ_OPT_K12    (1 << 20) /* 0x100000 */
#define RSSMIQ_OPT_B51    (1 << 21) /* 0x200000 */  
#define RSSMIQ_OPT_B49    (1 << 22) /* 0x400000 */
#define RSSMIQ_OPT_B57    (1 << 23) /* 0x800000 */  
//Definition of constant

#define RSSMIQ_DEN_LOW      0       //Data enable input Low 
#define RSSMIQ_DEN_HIGH     1       //Data enable input HIGH
#define RSSMIQ_DEN_OFF      2       //Data enable input OFF  

#define RSSMIQ_UNIT_ENG 0           //BERT Unit ENGineering
#define RSSMIQ_UNIT_SCI 1           //BERT Unit SCIentific       
#define RSSMIQ_UNIT_PCT 2           //BERT Unit PCT  
#define RSSMIQ_UNIT_PPM 3           //BERT Unit PPM 

#define RSSMIQ_BLER_SEQ_SINGLE  0       //BLER Measurement single  
#define RSSMIQ_BLER_SEQ_AUTO    1       //BLER Measurement continuous


#define RSSMIQ_BLER_TYPE_CRC16  0       //BLER Type is CRC16 

#define RSSMIQ_BLER_DATA_INV    0       //BLER Data polarity is inverted  
#define RSSMIQ_BLER_DATA_NORM   1       //BLER Data polarity is normal 
#define RSSMIQ_BLER_CLOCK_FALL  0       //BLER Clock active edge is falling 
#define RSSMIQ_BLER_CLOCK_RISE  1       //BLER Clock active edge is rising

#define RSSMIQ_BER_STOP         0       //BLER Stop
#define RSSMIQ_BER_START        1       //BLER Start    

#define RSSMIQ_GPS_STANDARD     0       //GPS modulation standard
#define RSSMIQ_GPS_OTHER        1       //GPS modulation no-standard 

#define RSSMIQ_SIGNAL_POLARITY_POS  0       //Signal Polarity Positive
#define RSSMIQ_SIGNAL_POLARITY_NEG  1       //Signal Polarity Negative       

#define RSSMIQ_GPS_DATASOUR_PATTERN  0      //GPS data source Pattern
#define RSSMIQ_GPS_DATASOUR_DLIST    1      //GPS data source Data list

#define RSSMIQ_W3GP_STATION_BASE    0       //W3GP Base station
#define RSSMIQ_W3GP_STATION_MOBILE  1       //W3GP Mobile station       
#define RSSMIQ_W3GP_ERROR_BIT       0       //W3GP Bit Error
#define RSSMIQ_W3GP_ERROR_BLOCK     1       //W3GP Block Error
#define RSSMIQ_W3GPP_CHAN_DPDCH     0       //W3GP Channel Type DPDCH
#define RSSMIQ_W3GPP_CHAN_DPCCH     1       //W3GP Channel Type DPCCH

#define RSSMIQ_DECT_FILT_SQRCOS     0       //DECT Filter type 
#define RSSMIQ_DECT_FILT_COS        1       //DECT Filter type  
#define RSSMIQ_DECT_FILT_USER       2       //DECT Filter type  


#define RSSMIQ_FDEL_STANDARD_G3C1   0       //Fading Dealy Standard G3C1
#define RSSMIQ_FDEL_STANDARD_G3C2   1       //Fading Dealy Standard G3C2 
#define RSSMIQ_FDEL_STANDARD_G3C3   2       //Fading Dealy Standard G3C3 
#define RSSMIQ_FDEL_STANDARD_G3C4   3       //Fading Dealy Standard G3C4 
#define RSSMIQ_FDEL_STANDARD_G3UEC1 4       //Fading Dealy Standard G3UEC1 
#define RSSMIQ_FDEL_STANDARD_G3UEC2 5       //Fading Dealy Standard G3UEC2 
#define RSSMIQ_FDEL_STANDARD_G3UEC3 6       //Fading Dealy Standard G3UEC3 
#define RSSMIQ_FDEL_STANDARD_G3UEC4 7       //Fading Dealy Standard G3UEC4 
#define RSSMIQ_FDEL_STANDARD_G3UEC5 8       //Fading Dealy Standard G3UEC5 
#define RSSMIQ_FDEL_STANDARD_G3UEC6 9       //Fading Dealy Standard G3UEC6 

#define RSSMIQ_FDEL_PROFILE_PDOP    0       //Fading Delay Profile Pdopler
#define RSSMIQ_FDEL_PROFILE_RAYL    1       //Fading Delay Profile Rayleight 

#define RSSMIQ_FDEL_SPEED           0       //Fading Dalay Path Speed
#define RSSMIQ_FDEL_DOPLLER         1       //Fading Dalay Path Doppler 

#define RSSMIQ_UNIT_MPS             0       //Fading Speed Unit MPS
#define RSSMIQ_UNIT_KMPH            1       //Fading Speed Unit KMPH   
#define RSSMIQ_UNIT_MPH             2       //Fading Speed Unit MPH  

#define RSSMIQ_GSM_FILTER_USER      0       //GSM DM Filter User 
#define RSSMIQ_GSM_FILTER_GAUSS     1       //GSM DM Filter Gauss

#define RSSMIQ_LISTS_GPS            0
#define RSSMIQ_LISTS_DMFILTER       1

#define RSSMIQ_DSOURCE_PN9          0       //Data source W3GPP
#define RSSMIQ_DSOURCE_PN11         1       //Data source W3GPP 
#define RSSMIQ_DSOURCE_PN15         2       //Data source W3GPP 
#define RSSMIQ_DSOURCE_PN16         3       //Data source W3GPP 
#define RSSMIQ_DSOURCE_ZERO         4       //Data source W3GPP 
#define RSSMIQ_DSOURCE_ONE          5       //Data source W3GPP 
#define RSSMIQ_DSOURCE_PATT         6       //Data source W3GPP
#define RSSMIQ_DSOURCE_DLIS         7       //Data source W3GPP 

#define RSSMIQ_LEVEL_LOW            0       //Lower Limit
#define RSSMIQ_LEVEL_UPP            1       //Upper Limit

#define RSSMIQ_AM_EXT               0       //Amplitude modulation source - external
#define RSSMIQ_AM_INT               1       //Amplitude modulation source - internal
#define RSSMIQ_AM_EXTINT            2       //Amplitude modulation source - external and internal in one time

#define RSSMIQ_IQTRANS_NORM         0       //IQ digital modulation transition Normal   
#define RSSMIQ_IQTRANS_FAST         1       //IQ digital modulation transition Fast 

#define RSSMIQ_DMLIST_SEL           0       //DM list select
#define RSSMIQ_DMLIST_CRE           1       //DM list create form data
#define RSSMIQ_DMLIST_DEL           2       //DM list delete    

#define RSSMIQ_W3GP_CHANNEL_DTCH    0       //W3GPP channel DTCH
#define RSSMIQ_W3GP_CHANNEL_DCCH    1       //W3GPP channel DCCH
#define RSSMIQ_W3GP_CHANNEL_DPCH    2       //W3GPP channel DPCH

#define RSSMIQ_SOURCE               0       //RF source
#define RSSMIQ_SOURCE2              1       //LF Source

#define RSSMIQ_MARKERS_FREQ         0       //Frequency Markers
#define RSSMIQ_MARKERS_LEVEL        1       //Level Markers

#define RSSMIQ_STANDARD_NADC        0       //Standard NADC
#define RSSMIQ_STANDARD_PDC         1       //Standard PDC
#define RSSMIQ_STANDARD_PHS         2       //Standard PHS
#define RSSMIQ_STANDARD_WCDM		3		//Standard WCDMA

#define RSSMIQ_WCDMA_CLFREQ_R4M     0       //Chip rate 4.096 Mcps
#define RSSMIQ_WCDMA_CLFREQ_R8M     1       //Chip rate 8.192 Mcps

#define RSSMIQ_EXT_COUPL_AC         0       //AM External coupling AC
#define RSSMIQ_EXT_COUPL_DC         1       //AM External coupling DC

#define RSSMIQ_BERT_UNIT_ENG        0
#define RSSMIQ_BERT_UNIT_SCI        1
#define RSSMIQ_BERT_UNIT_PCT        2
#define RSSMIQ_BERT_UNIT_PMM        3

#define RSSMIQ_BIRT_LOSMODE_NORMAL  0
#define RSSMIQ_BIRT_LOSMODE_LACP    1

#define RSSMIQ_RF_RECALL_NOTLOAD    0
#define RSSMIQ_RF_RECALL_LOAD       1

#define RSSMIQ_POLARITY_NORMAL      0
#define RSSMIQ_POLARITY_INV         1

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssmiq_init (ViRsrc resourceName, ViBoolean IDQuery,
				ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_applicationExample (ViSession instrumentHandle,
				ViReal64 RFFrequency_inMHz,
				ViReal64 RFLevel_in_dBm,
				ViBoolean RFOut,
				ViString predefinedFrame);
ViStatus _VI_FUNC rssmiq_RFfrequency (ViSession instrumentHandle,
				ViReal64 RFFrequency_inMHz,
				ViReal64 RFOffset_inMHz,
				ViReal64 knobStep_inMHz);
ViStatus _VI_FUNC rssmiq_RFlevel (ViSession instrumentHandle, ViReal64 RFLevel,
				ViReal64 levelLimit, ViInt32 levelUnit,
				ViReal64 levelOffset_in_dB,
				ViReal64 knobStep_in_dB);
ViStatus _VI_FUNC rssmiq_RFlevelAtRecall (ViSession instrumentHandle,
				ViInt32 RFLevelAtRecall);
ViStatus _VI_FUNC rssmiq_ALC (ViSession instrumentHandle, ViInt32 ALCMode,
				ViInt32 ALCOffMode, ViBoolean learnTable);
ViStatus _VI_FUNC rssmiq_userCorrection (ViSession instrumentHandle, ViInt32 action,
				ViString name,
				ViReal64 _VI_FAR frequencyArray[],
				ViReal64 _VI_FAR levelArray[],
				ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmiq_LFoutput (ViSession instrumentHandle, ViBoolean LFOutState,
				ViReal64 frequency_inHz, ViReal64 voltage_inV);
ViStatus _VI_FUNC rssmiq_modulationState (ViSession instrumentHandle,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_getPeakEnvelopePower (ViSession instrumentHandle,
				ViPInt32 peakEnvelopePower);
ViStatus _VI_FUNC rssmiq_BERT (ViSession instrumentHandle, ViBoolean state,
				ViBoolean sequence, ViInt32 type,
				ViBoolean dataPolarity, ViBoolean clockPolarity,
				ViInt32 masking, ViUInt32 count, ViUInt32 errors,
				ViInt32 externalRestart, ViInt32 ignore);
ViStatus _VI_FUNC rssmiq_setBERTAddParameters (ViSession instrumentHandle,
				ViInt32 dataEnableInput,
				ViInt32 unitOfErrorRate);
ViStatus _VI_FUNC rssmiq_BERTControl (ViSession instrumentHandle, ViInt32 BERTTest);
ViStatus _VI_FUNC rssmiq_GetBERTResults (ViSession instrumentHandle,
				ViPInt32 no_ofDataBits,
				ViPInt32 no_ofErrorBits,
				ViPReal64 bitErrorRate,
				ViPBoolean terminationStatus,
				ViPBoolean clockLineStatus,
				ViPBoolean dataLineStatus,
				ViPBoolean syncStatus);
ViStatus _VI_FUNC rssmiq_configureBLER (ViSession instrumentHandle, ViBoolean state,
				ViInt32 measurementType,
				ViUInt32 numberOfDataBlocks,
				ViUInt32 numberOfErrors,
				ViInt32 dataPolarity,
				ViInt32 clockSignalEdge,
				ViInt32 dataEnableInput,
				ViInt32 unitOfErrorRate);
ViStatus _VI_FUNC rssmiq_BLERControl (ViSession instrumentHandle, ViInt32 BLERTest);
ViStatus _VI_FUNC rssmiq_getBLERResults (ViSession instrumentHandle,
				ViPInt32 no_ofDataBlocks,
				ViPInt32 no_ofErrors, ViPReal64 errorRate,
				ViPBoolean terminationStatus,
				ViPBoolean clockLineStatus,
				ViPBoolean dataLineStatus,
				ViPBoolean syncStatus);
ViStatus _VI_FUNC rssmiq_getBLERType (ViSession instrumentHandle, ViPInt32 type);
ViStatus _VI_FUNC rssmiq_qRFfrequency (ViSession instrumentHandle,
				ViReal64 RFFrequency_inMHz,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qRFlevel (ViSession instrumentHandle,
				ViReal64 RFLevel_in_dBm, ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qRFlevOffset (ViSession instrumentHandle,
				ViReal64 levelOffset_in_dB,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qRFstartStopFreq (ViSession instrumentHandle,
				ViReal64 startFreq_inMHz,
				ViReal64 stopFreq_inMHz,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qRFcenterSpanFreq (ViSession instrumentHandle,
				ViReal64 centerFreq_inMHz,
				ViReal64 spanFreq_inMHz,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qRFsweepStep (ViSession instrumentHandle,
				ViReal64 stepWidth, ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qLFfreq (ViSession instrumentHandle,
				ViReal64 frequency_inHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qLFvolt (ViSession instrumentHandle, ViReal64 voltage_inV,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qAMmodDep (ViSession instrumentHandle,
				ViReal64 modulationDepth_in,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qFMdev (ViSession instrumentHandle, ViBoolean modulator,
				ViReal64 freqDeviation_inHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_qPHMdev (ViSession instrumentHandle, ViBoolean modulator,
				ViReal64 phaseDeviation_in_rad,
				ViBoolean checkRange);
ViStatus _VI_FUNC rssmiq_AM (ViSession instrumentHandle, ViBoolean state,
				ViReal64 modulationDepth_in, ViInt32 source,
				ViReal64 internalFreq_inHz, ViInt32 extCoupling);
ViStatus _VI_FUNC rssmiq_PULM (ViSession instrumentHandle, ViBoolean state,
				ViBoolean polarity);
ViStatus _VI_FUNC rssmiq_BBAM (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmiq_FM (ViSession instrumentHandle, ViBoolean state,
				ViBoolean modulator, ViReal64 freqDeviation_inHz,
				ViInt32 preemphasis, ViInt32 source,
				ViReal64 internalFreq_inHz, ViBoolean extCoupling);
ViStatus _VI_FUNC rssmiq_PHM (ViSession instrumentHandle, ViBoolean state,
				ViBoolean modulator, ViReal64 phaseDeviation_in_rad,
				ViInt32 source, ViReal64 internalFreq_inHz,
				ViBoolean extCoupling);
ViStatus _VI_FUNC rssmiq_RFsweep (ViSession instrumentHandle, ViBoolean mode,
				ViReal64 startCenterFreq_inMHz,
				ViReal64 stopSpanFreq_inMHz, ViBoolean spacing,
				ViReal64 stepWidth, ViReal64 dwellTime_in_ms);
ViStatus _VI_FUNC rssmiq_RFsweepMarkers (ViSession instrumentHandle,
				ViReal64 m1Frequency_inMHz,
				ViBoolean m1State, ViBoolean m1Ampl,
				ViReal64 m2Frequency_inMHz,
				ViBoolean m2State, ViBoolean m2Ampl,
				ViReal64 m3Frequency_inMHz,
				ViBoolean m3State, ViBoolean m3Ampl,
				ViReal64 m4Frequency_inMHz,
				ViBoolean m4State, ViBoolean m4Ampl);
ViStatus _VI_FUNC rssmiq_RFlevelSweep (ViSession instrumentHandle,
				ViReal64 startLevel, ViReal64 stopLevel,
				ViInt32 levelUnit, ViReal64 stepWidth_in_dB,
				ViReal64 dwellTime_in_ms);
ViStatus _VI_FUNC rssmiq_RFlevelSweepMarkers (ViSession instrumentHandle,
				ViReal64 m1Level, ViBoolean m1State,
				ViReal64 m2Level, ViBoolean m2State,
				ViReal64 m3Level, ViBoolean m3State,
				ViReal64 m4Level, ViBoolean m4State,
				ViInt32 levelUnit);
ViStatus _VI_FUNC rssmiq_LFsweep (ViSession instrumentHandle,
				ViReal64 startFreq_in_kHz,
				ViReal64 stopFreq_in_kHz, ViBoolean spacing,
				ViReal64 stepWidth, ViReal64 dwellTime_in_ms);
ViStatus _VI_FUNC rssmiq_LFsweepMarkers (ViSession instrumentHandle,
				ViReal64 m1Frequency_in_kHz,
				ViBoolean m1State,
				ViReal64 m2Frequency_in_kHz,
				ViBoolean m2State,
				ViReal64 m3Frequency_in_kHz,
				ViBoolean m3State,
				ViReal64 m4Frequency_in_kHz,
				ViBoolean m4State);
ViStatus _VI_FUNC rssmiq_LFsweepMarkerPolarity (ViSession instrumentHandle,
				ViInt32 marker, ViInt32 polarity);
ViStatus _VI_FUNC rssmiq_switchAllMarkersOff (ViSession instrumentHandle,
				ViInt32 source, ViInt32 markers);
ViStatus _VI_FUNC rssmiq_freqAndLevList (ViSession instrumentHandle, ViInt32 action,
				ViString name, ViReal64 dwellTime_in_ms,
				ViReal64 _VI_FAR freqArray[],
				ViReal64 _VI_FAR levelArray[],
				ViInt32 number_ofElements);
ViStatus _VI_FUNC rssmiq_memSequence (ViSession instrumentHandle, ViInt32 action,
				ViString name, ViInt32 _VI_FAR setupArray[],
				ViReal64 _VI_FAR dwellArray[],
				ViInt32 number_ofElements);
ViStatus _VI_FUNC rssmiq_cfgLstSweTrig (ViSession instrumentHandle,
				ViInt32 function, ViInt32 triggerMode);
ViStatus _VI_FUNC rssmiq_getCatalogList (ViSession instrumentHandle,
				ViInt32 typeOfList, ViInt32 size,
				ViChar _VI_FAR dataList[],
				ViPInt32 length);
ViStatus _VI_FUNC rssmiq_vectModulation (ViSession instrumentHandle,
				ViBoolean state, ViBoolean powerRamp);
ViStatus _VI_FUNC rssmiq_IQModImp (ViSession instrumentHandle,
				ViBoolean impairmentState, ViBoolean IQSwap,
				ViReal64 leakage_in, ViReal64 imbalance_in,
				ViReal64 quadOffset_in_deg);
ViStatus _VI_FUNC rssmiq_IQModLowACP (ViSession instrumentHandle,
				ViInt32 IQFilterMode);
ViStatus _VI_FUNC rssmiq_IQModParameters (ViSession instrumentHandle,
				ViReal64 crestFactor, ViInt32 transition);
ViStatus _VI_FUNC rssmiq_DmSetHighDynamic (ViSession instrumentHandle,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_digModulation (ViSession instrumentHandle, ViBoolean state,
				ViInt32 source, ViInt32 standard,
				ViInt32 modulation,
				ViReal64 FSKDeviation_in_kHz,
				ViInt32 coding, ViReal64 symbolRate_in_kSs,
				ViBoolean rateMode, ViInt32 filter,
				ViReal64 filterConst, ViBoolean filterMode,
				ViBoolean lowDistortion);
ViStatus _VI_FUNC rssmiq_digModLists (ViSession instrumentHandle, ViInt32 action,
				ViString name, ViBoolean type, ViString data,
				ViInt32 numberOfBytes, ViBoolean controlList);
ViStatus _VI_FUNC rssmiq_digModFilterLists (ViSession instrumentHandle,
				ViInt32 action, ViString name,
				ViInt32 pulseLength,
				ViInt32 oversampling,
				ViReal64 _VI_FAR i_values[],
				ViReal64 _VI_FAR q_values[],
				ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmiq_digModFormat (ViSession instrumentHandle, ViInt32 action,
				ViString name, ViInt32 modulation,
				ViBoolean qpathDelay,
				ViReal64 _VI_FAR i_values[],
				ViReal64 _VI_FAR q_values[],
				ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmiq_digModClock (ViSession instrumentHandle,
				ViInt32 modulationStandard, ViInt32 source,
				ViInt32 mode, ViReal64 delay_in_symbols,
				ViBoolean polarity);
ViStatus _VI_FUNC rssmiq_selectFilterFromList (ViSession instrumentHandle,
				ViInt32 standard, ViString name);
ViStatus _VI_FUNC rssmiq_digModExtIn (ViSession instrumentHandle, ViInt32 impedance,
				ViReal64 threshold_inV);
ViStatus _VI_FUNC rssmiq_confDigModStdTrig (ViSession instrumentHandle,
				ViInt32 modulationStandard,
				ViInt32 mode, ViBoolean source,
				ViInt32 extTrigDelay,
				ViInt32 trigOut1Delay,
				ViInt32 trigOut2Delay,
				ViInt32 trigOut2Period,
				ViInt32 extRetrigInhibit,
				ViInt32 trigOut1, ViBoolean trigOut1Pol,
				ViInt32 trigOut2,
				ViBoolean trigOut2Pol);
ViStatus _VI_FUNC rssmiq_digModStdPowRamp (ViSession instrumentHandle,
				ViInt32 modulationStandard, ViInt32 mode,
				ViBoolean shapeFunc, ViReal64 rampTime,
				ViReal64 rampDelay,
				ViReal64 attenuation_in_dB,
				ViInt32 riseOffset, ViInt32 fallOffset);
ViStatus _VI_FUNC rssmiq_getDigitalModFilterInfo (ViSession instrumentHandle,
				ViPInt32 freeMemorySpace,
				ViPInt32 numberOfSamples);
ViStatus _VI_FUNC rssmiq_getDigitalModulationDelay (ViSession instrumentHandle,
				ViPReal64 timeDelay);
ViStatus _VI_FUNC rssmiq_digModASKDepth (ViSession instrumentHandle, ViInt32 depth);
ViStatus _VI_FUNC rssmiq_digStdPHS (ViSession instrumentHandle, ViBoolean state,
				ViBoolean setToStd, ViReal64 symbolRate,
				ViBoolean filter, ViReal64 rollOffFactor,
				ViBoolean filterMode, ViBoolean lowDistortion,
				ViInt32 selectFrame, ViString userFrame,
				ViReal64 slotAttenuation);
ViStatus _VI_FUNC rssmiq_digStdIS95 (ViSession instrumentHandle, ViBoolean state,
				ViInt32 mode, ViBoolean setDefault,
				ViReal64 chipRate, ViInt32 fwdLinkFilter,
				ViInt32 revLinkFilter, ViReal64 rollOffFactor,
				ViBoolean filterMode, ViBoolean lowDistortion,
				ViInt32 selectMapping, ViString userMapping,
				ViBoolean revLinkRate, ViBoolean rLBurstRand,
				ViInt32 revLinkData);
ViStatus _VI_FUNC rssmiq_digStdIS95RevLinkCoded (ViSession instrumentHandle,
				ViInt32 mode,
				ViBoolean addFrameQualInd,
				ViInt32 data, ViString dataList,
				ViBoolean convolutionalEncoder,
				ViBoolean blockInterleaver,
				ViInt32 erasureBit);
ViStatus _VI_FUNC rssmiq_digitalStandardIS95Filter (ViSession instrumentHandle,
				ViString fwdLinkFilter,
				ViString revLinkFilter);
ViStatus _VI_FUNC rssmiq_digStdWCDMA (ViSession instrumentHandle, ViBoolean state,
				ViInt32 mode, ViBoolean setDefault,
				ViInt32 linkDirMPX, ViBoolean modType,
				ViInt32 chipRateVariation,
				ViBoolean lowDistortion, ViInt32 filter,
				ViReal64 rollOffFactor, ViBoolean filterMode,
				ViBoolean multicode, ViInt32 masterChannel,
				ViInt32 multicode_ofChannels,
				ViInt32 sequenceLength);
ViStatus _VI_FUNC rssmiq_digStdWCDMAClockFreq (ViSession instrumentHandle,
				ViInt32 clockFrequency);
ViStatus _VI_FUNC rssmiq_digStdNADC (ViSession instrumentHandle, ViBoolean state,
				ViBoolean setToStandard, ViReal64 symbolRate,
				ViBoolean filter, ViReal64 rollOffFactor,
				ViBoolean filterMode, ViBoolean lowDistortion,
				ViInt32 selectFrame, ViString userFrame,
				ViBoolean linkDir, ViInt32 rateConfig,
				ViReal64 slotAttenuation);
ViStatus _VI_FUNC rssmiq_digStdPDC (ViSession instrumentHandle, ViBoolean state,
				ViBoolean setDefault, ViReal64 symbolRate,
				ViBoolean filter, ViReal64 rollOffFactor,
				ViBoolean filterMode, ViBoolean lowDistortion,
				ViInt32 selectFrame, ViString userFrame,
				ViBoolean linkDir, ViInt32 rateConfig,
				ViReal64 slotAttenuation);
ViStatus _VI_FUNC rssmiq_digStdGSM (ViSession instrumentHandle, ViBoolean state,
				ViInt32 modulation,
				ViReal64 FSKDeviation_in_kHz,
				ViReal64 symbolRate, ViReal64 filterParameter,
				ViInt32 selectFrame, ViString userFrame,
				ViReal64 slotAttenuation);
ViStatus _VI_FUNC rssmiq_digStdGSMFiltType (ViSession instrumentHandle,
				ViInt32 filter);
ViStatus _VI_FUNC rssmiq_digStdDECT (ViSession instrumentHandle, ViBoolean state,
				ViInt32 modulation,
				ViReal64 FSKDeviation_in_kHz,
				ViReal64 symbolRate, ViBoolean DQPSKFilter,
				ViReal64 filterParameter,
				ViInt32 timingAdjustment,
				ViInt32 jitterSimulation, ViBoolean preamble,
				ViInt32 selectFrame, ViString userFrame,
				ViReal64 slotAttenuation);
ViStatus _VI_FUNC rssmiq_digStdDECTUserFilter (ViSession instrumentHandle,
				ViString filterName);
ViStatus _VI_FUNC rssmiq_digitalStandardGPS (ViSession instrumentHandle,
				ViBoolean state,
				ViInt32 modulationParameters,
				ViReal64 dopplerShift,
				ViReal64 symbolRate, ViInt32 code,
				ViInt32 dataSource, ViInt32 pattern,
				ViString dataList);
ViStatus _VI_FUNC rssmiq_GPSPresetRF (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_getGPSFrequency (ViSession instrumentHandle,
				ViPReal64 frequency);
ViStatus _VI_FUNC rssmiq_getGPSCurrentSymbolRate (ViSession instrumentHandle,
				ViPReal64 resultingSymbolRate);
ViStatus _VI_FUNC rssmiq_phsSlot (ViSession instrumentHandle, ViInt32 slot,
				ViInt32 burstType, ViInt32 level,
				ViBoolean setToDefault, ViBoolean CSIDScramble,
				ViInt32 CSIDScrambleCode, ViBoolean encryption,
				ViInt32 securityKey, ViInt32 uniqueWord,
				ViInt32 SACCH, ViString SACCHList, ViInt32 TCHVox,
				ViString TCHVoxList, ViString CSID, ViInt32 PSID,
				ViString idle);
ViStatus _VI_FUNC rssmiq_WCDMAChannels (ViSession instrumentHandle, ViInt32 channel,
				ViInt32 chSelect, ViInt32 chType,
				ViInt32 symbolRate, ViInt32 shortCode,
				ViInt32 upperWord, ViInt32 lowerDWord,
				ViInt32 longCodeOffset,
				ViInt32 LMSShortCode, ViInt32 source,
				ViString dataList, ViInt32 dataOffset,
				ViInt32 TPCData, ViString TPCDataList,
				ViReal64 power, ViBoolean state);
ViStatus _VI_FUNC rssmiq_is95Channels (ViSession instrumentHandle, ViInt32 channel,
				ViInt32 walshCode, ViReal64 power_in_dB,
				ViInt32 revLinkData, ViBoolean state);
ViStatus _VI_FUNC rssmiq_nadcSlot (ViSession instrumentHandle, ViInt32 slot,
				ViInt32 burstType, ViInt32 levelBurstState,
				ViBoolean setToDefault, ViInt32 data,
				ViString dataList, ViInt32 SACCH,
				ViString SACCHList, ViInt32 sync, ViInt32 CDVCC,
				ViInt32 RSVD);
ViStatus _VI_FUNC rssmiq_pdcSlot (ViSession instrumentHandle, ViInt32 slot,
				ViInt32 burstType, ViInt32 levelBurstState,
				ViBoolean setToDefault, ViBoolean scramble,
				ViInt32 scrambleStart, ViBoolean superFrame,
				ViInt32 RCHPosition, ViString preamble,
				ViInt32 syncWord, ViInt32 syncWord2,
				ViInt32 stealFlag, ViInt32 dataSync,
				ViString dataSyncList, ViInt32 SACCH,
				ViString SACCHList, ViInt32 RCH, ViString RCHList,
				ViString postamble, ViInt32 colorCode);
ViStatus _VI_FUNC rssmiq_gsmSlot (ViSession instrumentHandle, ViInt32 slot,
				ViInt32 burstType, ViInt32 level,
				ViBoolean setToDefault, ViInt32 stealingFlag,
				ViInt32 data, ViString dataList, ViInt32 TSC,
				ViString userTSC, ViBoolean hopTrigger);
ViStatus _VI_FUNC rssmiq_dectSlot (ViSession instrumentHandle, ViInt32 slot,
				ViInt32 slotType, ViInt32 level,
				ViBoolean setDefault, ViInt32 slotTimingShift,
				ViBoolean rampUp, ViInt32 rampData,
				ViInt32 preamble, ViInt32 sync,
				ViInt32 aFieldData, ViString aDataList,
				ViInt32 bFieldData, ViString bDataList,
				ViBoolean zField);
ViStatus _VI_FUNC rssmiq_getIS95Power (ViSession instrumentHandle, ViPReal64 power);
ViStatus _VI_FUNC rssmiq_dmIS95AdjustPower (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_getWCDMAPower (ViSession instrumentHandle,
				ViPReal64 power);
ViStatus _VI_FUNC rssmiq_dmWCDMAAdjustPower (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_w3gppState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppSetup (ViSession instrumentHandle, ViInt32 operation,
				ViString settingName);
ViStatus _VI_FUNC rssmiq_w3gppSetupCatalog (ViSession instrumentHandle,
				ViInt32 size, ViChar _VI_FAR catalog[],
				ViPInt32 listLength);
ViStatus _VI_FUNC rssmiq_w3gppTestModel (ViSession instrumentHandle,
				ViInt32 testModel);
ViStatus _VI_FUNC rssmiq_w3gppTestModelCatalog (ViSession instrumentHandle,
				ViInt32 station, ViInt32 size,
				ViChar _VI_FAR catalog[],
				ViPInt32 length);
ViStatus _VI_FUNC rssmiq_w3gppLink (ViSession instrumentHandle, ViInt32 link,
				ViInt32 sequenceLength, ViInt32 clippingLevel,
				ViReal64 chipRateVar, ViInt32 filterType,
				ViString userFilterName,
				ViReal64 filterParameter, ViInt32 filterMode);
ViStatus _VI_FUNC rssmiq_w3gppParametrization (ViSession instrumentHandle,
				ViBoolean synchronizeChannels,
				ViBoolean SCCPCHState,
				ViInt32 SCCPCHSymbolRate,
				ViInt32 DPCHChannelCount,
				ViInt32 DPCHSymbolRate,
				ViInt32 crestFactor);
ViStatus _VI_FUNC rssmiq_w3gppCopySettings (ViSession instrumentHandle,
				ViInt32 source, ViInt32 destination,
				ViInt32 offset);
ViStatus _VI_FUNC rssmiq_w3gppBStation (ViSession instrumentHandle,
				ViInt32 baseStation, ViInt32 scramblingCode,
				ViBoolean TFCIState, ViInt32 TFCI,
				ViInt32 secondSCG, ViInt32 TPCRead,
				ViBoolean TPCMisuse, ViReal64 TPCPowerStep,
				ViInt32 transmitDiversity,
				ViInt32 pageIndicatorChannel,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppAdjustPower (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_w3gppGetPower (ViSession instrumentHandle,
				ViPReal64 power);
ViStatus _VI_FUNC rssmiq_w3gppMultiChannel (ViSession instrumentHandle,
				ViInt32 startChannel,
				ViInt32 stopChannel, ViInt32 symbolRate,
				ViInt32 pilotFieldLength,
				ViInt32 channelizationCode,
				ViInt32 channelCodeStep,
				ViReal64 channelPower,
				ViReal64 channelPowerStep,
				ViInt32 dataSource,
				ViString dataPattern,
				ViInt32 timingOffset,
				ViInt32 timingOffsetStep,
				ViInt32 TPCDataSource,
				ViString TPCDataPattern,
				ViBoolean multicode, ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppMultiChannelExec (ViSession instrumentHandle,
				ViInt32 baseStation);
ViStatus _VI_FUNC rssmiq_w3gppBStationChannel (ViSession instrumentHandle,
				ViInt32 baseStation, ViInt32 channel,
				ViInt32 symbolRate,
				ViInt32 channelizationCode,
				ViReal64 channelPower,
				ViInt32 dataSource,
				ViString dataPattern,
				ViInt32 timingOffset,
				ViInt32 pilotFieldLength,
				ViInt32 TPCDataSource,
				ViString TPCDataPattern,
				ViBoolean multicode,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppGetDomainError (ViSession instrumentHandle,
				ViInt32 baseStation,
				ViPBoolean domainError);
ViStatus _VI_FUNC rssmiq_w3gppMStation (ViSession instrumentHandle,
				ViInt32 mobileStation, ViInt32 mode,
				ViInt32 scramblingCode,
				ViInt32 scramblingMode,
				ViInt32 TPCDataSource,
				ViString TPCDataPattern, ViInt32 TPCRead,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppMStationPRACHChannel (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViInt32 repetition,
				ViReal64 preamblePower,
				ViReal64 dataPower,
				ViReal64 controlPower,
				ViInt32 messagePartLength,
				ViInt32 signature,
				ViInt32 aSlot,
				ViInt32 symbolRate,
				ViInt32 dataSource,
				ViString dataPattern,
				ViInt32 TFCI);
ViStatus _VI_FUNC rssmiq_w3gppMStationPCPCHChannel (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViInt32 repetition,
				ViReal64 preamblePower,
				ViReal64 preamblePowerStep,
				ViReal64 dataPower,
				ViReal64 controlPower,
				ViInt32 scramblingCodeShared,
				ViInt32 messageLength,
				ViInt32 pwrControlPreambleLen,
				ViInt32 signature,
				ViInt32 aSlot, ViInt32 FBIMode,
				ViInt32 FBIDataSource,
				ViString FBIDataPattern,
				ViInt32 symbolRate,
				ViInt32 dataSource,
				ViString dataPattern,
				ViInt32 TFCI);
ViStatus _VI_FUNC rssmiq_w3gppMStationDPCCHChannel (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViReal64 power,
				ViBoolean TFCIState,
				ViInt32 TFCI, ViInt32 FBIMode,
				ViInt32 FBIDataSource,
				ViString FBIDataPattern,
				ViBoolean TPCMisuse,
				ViReal64 TPCPowerStep);
ViStatus _VI_FUNC rssmiq_w3gppMStationDPCCHToff (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViPInt32 timingOffset);
ViStatus _VI_FUNC rssmiq_w3gppMStationDPDCH (ViSession instrumentHandle,
				ViInt32 mobileStation, ViReal64 power,
				ViInt32 overallSymbolRate);
ViStatus _VI_FUNC rssmiq_w3gppMStationDPDCHChannel (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViInt32 channel,
				ViInt32 dataSource,
				ViString dataPattern);
ViStatus _VI_FUNC rssmiq_w3gppGetMStationDPDCHParam (ViSession instrumentHandle,
				ViInt32 mobileStation,
				ViInt32 channel,
				ViPInt32 symbolRate,
				ViPInt32 type,
				ViPInt32 channelizationCode);
ViStatus _VI_FUNC rssmiq_w3gppBStationEnhancedOverall (ViSession instrumentHandle,
				ViBoolean coding,
				ViInt32 codingType,
				ViBoolean codingInterleaver1,
				ViBoolean codingInterleaver2,
				ViBoolean extPowerControl,
				ViReal64 extPwrCtrlStep,
				ViReal64 extPwrCtrlRangeUp,
				ViReal64 extPwrCtrlRangeDown,
				ViInt32 radioFrameSeqLength,
				ViInt32 symbolRate,
				ViInt32 timingOffset,
				ViInt32 pilotFieldLength,
				ViBoolean errorInsertion,
				ViReal64 requiredBER,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppBStationEnhancedChannel (ViSession instrumentHandle,
				ViInt32 channel,
				ViInt32 channelizationCode,
				ViBoolean coding,
				ViReal64 startPower,
				ViInt32 powerControl,
				ViInt32 dataSource,
				ViString dataPattern,
				ViString dataList,
				ViInt32 TPCDataSource,
				ViString TPCDataPattern,
				ViString TPCDataList,
				ViBoolean multicode,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppMStationEnhancedOverall (ViSession instrumentHandle,
				ViBoolean coding,
				ViInt32 codingType,
				ViBoolean codingInterleaver1,
				ViBoolean codingInterleaver2,
				ViBoolean extPowerControl,
				ViReal64 DPCCHStartPower,
				ViReal64 DPDCHStartPower,
				ViReal64 extPwrCtrlStep,
				ViReal64 extPwrCtrlRangeUp,
				ViReal64 extPwrCtrlRangeDown,
				ViInt32 radioFrameSeqLength,
				ViInt32 overallSymbolRate,
				ViBoolean DPPCHState,
				ViBoolean errorInsertion,
				ViReal64 requiredBER,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppMStationEnhancedChannel (ViSession instrumentHandle,
				ViInt32 channel,
				ViInt32 dataSource,
				ViString dataPattern,
				ViString dataList);
ViStatus _VI_FUNC rssmiq_w3gppConfigureEnhancedChannel (ViSession instrumentHandle,
				ViInt32 station,
				ViInt32 channel,
				ViInt32 channelType,
				ViInt32 dataSource,
				ViInt32 pattern,
				ViChar _VI_FAR dataList[]);
ViStatus _VI_FUNC rssmiq_w3gppGetMStationEnhParam (ViSession instrumentHandle,
				ViInt32 channel,
				ViPInt32 symbolRate,
				ViPInt32 channelizationCode);
ViStatus _VI_FUNC rssmiq_w3gppGetFreeFrameMem (ViSession instrumentHandle,
				ViPInt32 freeFrames);
ViStatus _VI_FUNC rssmiq_w3gppGetActualBER (ViSession instrumentHandle,
				ViInt32 station, ViPReal64 actualBER);
ViStatus _VI_FUNC rssmiq_w3gppBaseStationOCNSState (ViSession instrumentHandle,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppBStationOCNS (ViSession instrumentHandle,
				ViInt32 symbolRate, ViInt32 count,
				ViInt32 crestFactor, ViReal64 OCNSPower,
				ViBoolean PCCPCHState,
				ViReal64 PCCPCHPower,
				ViReal64 enhancedChannelsPower);
ViStatus _VI_FUNC rssmiq_w3gppMStationAdditional (ViSession instrumentHandle,
				ViInt32 count,
				ViInt32 SCInitIncrement,
				ViReal64 powerOffset,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_w3gppGetGPP3Version (ViSession instrumentHandle,
				ViInt32 size,
				ViChar _VI_FAR version[],
				ViPInt32 length);
ViStatus _VI_FUNC rssmiq_w3gppGetChipRate (ViSession instrumentHandle,
				ViPInt32 chipRate);
ViStatus _VI_FUNC rssmiq_w3gppGetPCCPLength (ViSession instrumentHandle,
				ViPInt32 length);
ViStatus _VI_FUNC rssmiq_w3gppConfigureBitBlocksErrors (ViSession instrumentHandle,
				ViInt32 station,
				ViInt32 error,
				ViBoolean state,
				ViReal64 rate);
ViStatus _VI_FUNC rssmiq_w3gppGetResultingBER (ViSession instrumentHandle,
				ViInt32 station, ViInt32 error,
				ViInt32 channel, ViPReal64 rate);
ViStatus _VI_FUNC rssmiq_recalculatingFadingSignal (ViSession instrumentHandle,
				ViBoolean state);
ViStatus _VI_FUNC rssmiq_fadingGetExternCrestFactor (ViSession instrumentHandle,
				ViPReal64 crestFactor);
ViStatus _VI_FUNC rssmiq_fadingDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_fadingFineDelayDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_fadingFineDelay (ViSession instrumentHandle,
				ViBoolean state, ViInt32 standard,
				ViInt32 speedUnit);
ViStatus _VI_FUNC rssmiq_fadingFineDelayPath (ViSession instrumentHandle,
				ViInt32 path, ViBoolean state,
				ViInt32 profile, ViReal64 freqRatio,
				ViInt32 movingPar,
				ViReal64 speedDoplFreq,
				ViReal64 pathLoss_in_dB,
				ViReal64 delay_in_us);
ViStatus _VI_FUNC rssmiq_fadingMovingDelayDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_fadingMovingDelay (ViSession instrumentHandle,
				ViBoolean state,
				ViReal64 referenceSignalLoss,
				ViReal64 referenceSignalDelay,
				ViReal64 movingSignalLoss,
				ViReal64 movingMeanDelay,
				ViReal64 movingDelayVariation,
				ViInt32 movingVariationSpeed);
ViStatus _VI_FUNC rssmiq_fadingBirthDeathDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_fadingBirthDeath (ViSession instrumentHandle,
				ViBoolean state, ViInt32 insertionLoss,
				ViInt32 speedUnit);
ViStatus _VI_FUNC rssmiq_fadingBirthDeathDelayPath (ViSession instrumentHandle,
				ViInt32 path, ViInt32 profile,
				ViReal64 freqRatio,
				ViInt32 movingPar,
				ViReal64 speedDoplFreq,
				ViReal64 pathLoss_in_dB,
				ViReal64 delay,
				ViReal64 dwellTimeUp);
ViStatus _VI_FUNC rssmiq_fading (ViSession instrumentHandle, ViInt32 fading,
				ViInt32 mode, ViInt32 standard,
				ViBoolean insLossSetMode);
ViStatus _VI_FUNC rssmiq_fadingPath (ViSession instrumentHandle, ViInt32 path,
				ViBoolean state, ViInt32 profile,
				ViBoolean discreteComponent,
				ViReal64 powerRatio_in_dB, ViReal64 freqRatio,
				ViReal64 speedDoplFreq, ViBoolean movingPar,
				ViReal64 pathLoss_in_dB, ViReal64 delay_in_us,
				ViInt32 correlPath, ViReal64 correlAmpl,
				ViReal64 correlPhase_in_deg,
				ViBoolean logNormState, ViReal64 localConst,
				ViReal64 stdDev);
ViStatus _VI_FUNC rssmiq_fadingPhaseForCPHAS (ViSession instrumentHandle,
				ViInt32 path, ViReal64 phase_in_deg);
ViStatus _VI_FUNC rssmiq_noiseDistSim (ViSession instrumentHandle, ViBoolean noise,
				ViReal64 carrierNoise,
				ViReal64 systemBandwidth,
				ViBoolean distortion);
ViStatus _VI_FUNC rssmiq_distCharact (ViSession instrumentHandle, ViInt32 action,
				ViString name, ViReal64 _VI_FAR AMAM_xaxis[],
				ViReal64 _VI_FAR AMAM_yaxis[],
				ViInt32 num_ofAMAMElements,
				ViReal64 _VI_FAR AMPM_xaxis[],
				ViReal64 _VI_FAR AMPM_yaxis[],
				ViInt32 num_ofAMPMElements);
ViStatus _VI_FUNC rssmiq_distCatalog (ViSession instrumentHandle, ViInt32 size,
				ViChar _VI_FAR listOfCharacteristics[],
				ViPInt32 listLength);
ViStatus _VI_FUNC rssmiq_distMemInfo (ViSession instrumentHandle,
				ViBoolean modulation,
				ViPInt32 remainingCapacity,
				ViPInt32 occupiedCapacity,
				ViPInt32 outputValueLength,
				ViPInt32 inputValueLength);
ViStatus _VI_FUNC rssmiq_distMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmiq_distPolyCoef (ViSession instrumentHandle, ViInt32 mode,
				ViInt32 coeficient, ViReal64 value);
ViStatus _VI_FUNC rssmiq_distRecalculate (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_distLevCorrect (ViSession instrumentHandle, ViInt32 mode,
				ViReal64 levelCorrection);
ViStatus _VI_FUNC rssmiq_distInvFunc (ViSession instrumentHandle,
				ViBoolean inversion);
ViStatus _VI_FUNC rssmiq_setArb (ViSession instrumentHandle, ViBoolean state,
				ViInt32 sequence);
ViStatus _VI_FUNC rssmiq_arbWav (ViSession instrumentHandle, ViBoolean operation,
				ViString name);
ViStatus _VI_FUNC rssmiq_getArbCatalog (ViSession instrumentHandle,
				ViInt32 numberBytesToRead,
				ViPInt32 numberOfWaveforms,
				ViChar _VI_FAR listOfWaveforms[]);
ViStatus _VI_FUNC rssmiq_getArbMemInfo (ViSession instrumentHandle,
				ViPInt32 freeMemorySpace,
				ViPInt32 numberOfSamples);
ViStatus _VI_FUNC rssmiq_arbTrigger (ViSession instrumentHandle, ViBoolean source,
				ViInt32 delay, ViInt32 inhibit);
ViStatus _VI_FUNC rssmiq_arbTriggerOut (ViSession instrumentHandle, ViInt32 output,
				ViBoolean polarity, ViInt32 delay,
				ViString mode, ViInt32 onTime,
				ViInt32 offTime);
ViStatus _VI_FUNC rssmiq_getArbTriggOutCatalog (ViSession instrumentHandle,
				ViInt32 output,
				ViChar _VI_FAR listOfAllAvailableModes[],
				ViInt32 size, ViPInt32 listLength);
ViStatus _VI_FUNC rssmiq_arbAutoSetting (ViSession instrumentHandle,
				ViBoolean autosettingState,
				ViBoolean DMIQFilter, ViBoolean DMIQSwap,
				ViBoolean type_ofPRBS,
				ViBoolean triggerMode);
ViStatus _VI_FUNC rssmiq_arbClock (ViSession instrumentHandle, ViReal64 clock_inHz,
				ViBoolean source, ViReal64 delay);
ViStatus _VI_FUNC rssmiq_arbIQLevel (ViSession instrumentHandle, ViInt32 level,
				ViBoolean mode, ViReal64 IQSkew);
ViStatus _VI_FUNC rssmiq_rfOutput (ViSession instrumentHandle, ViBoolean state,
				ViInt32 attenuator);
ViStatus _VI_FUNC rssmiq_getRFLevelLimit (ViSession instrumentHandle, ViInt32 limit,
				ViPReal64 level);
ViStatus _VI_FUNC rssmiq_triggerAction (ViSession instrumentHandle, ViInt32 action,
				ViBoolean wait);
ViStatus _VI_FUNC rssmiq_operComplete (ViSession instrumentHandle, ViBoolean wait,
				ViPBoolean complete);
ViStatus _VI_FUNC rssmiq_loadWaveform (ViSession instrumentHandle, ViString name,
				ViReal64 _VI_FAR i[], ViReal64 _VI_FAR q[],
				ViInt32 size, ViPUInt32 bytesWritten);
ViStatus _VI_FUNC rssmiq_loadWaveformFile (ViSession instrumentHandle,
				ViString name);
ViStatus _VI_FUNC rssmiq_writeInstrData (ViSession instrumentHandle,
				ViString writeBuffer);
ViStatus _VI_FUNC rssmiq_readInstrData (ViSession instrumentHandle,
				ViInt32 numberBytesToRead,
				ViChar _VI_FAR readBuffer[],
				ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmiq_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_self_test (ViSession instrumentHandle,
				ViPInt16 selfTestResult,
				ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssmiq_error_query (ViSession instrumentHandle,
				ViPInt32 errorCode,
				ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmiq_error_message (ViSession instrumentHandle,
				ViStatus statusCode,
				ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmiq_revision_query (ViSession instrumentHandle,
				ViChar _VI_FAR instrumentDriverRevision[],
				ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmiq_saveRecallSetup (ViSession instrumentHandle,
				ViBoolean setupMode, ViInt32 setupNumber);
ViStatus _VI_FUNC rssmiq_instrOptions (ViSession instrumentHandle,
				ViPInt32 options);
ViStatus _VI_FUNC rssmiq_refOsc (ViSession instrumentHandle, ViBoolean source,
				ViBoolean intAdj, ViInt32 intAdjFreq,
				ViInt32 extOscFreq, ViReal64 deltaPhase);
ViStatus _VI_FUNC rssmiq_setPhaseReference (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmiq_auxIO (ViSession instrumentHandle, ViInt32 extTriggerSlope,
				ViInt32 blankMode, ViBoolean blankTime,
				ViBoolean blankPolarity, ViBoolean markerPolarity);
ViStatus _VI_FUNC rssmiq_beeper (ViSession instrumentHandle, ViBoolean beeper);
ViStatus _VI_FUNC rssmiq_calibrate (ViSession instrumentHandle, ViInt32 mode,
				ViPBoolean failed);
ViStatus _VI_FUNC rssmiq_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
