/*===========================================================================*/
/*= Rohde & Schwarz SMIQ Vector Signal Generator ============================*/
/* LabWindows/CVI 4.0.1 Instrument Driver                                    */
/* Original Release: December 1998                                           */
/* By: Jan Sima                                                              */
/*                                                                           */
/* Should you have any technical questions please contact the hotline of     */
/* Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center             */
/*                                                                           */
/* e-mail: CustomerSupport@rsd.rohde-schwarz.com                             */
/*                                                                           */
/*                                                                           */
/* Modification History:                                                     */
/*      January 2011: Jiri Kominek,  CVI 2009                                */
/*                      Rev. 2.4.3, 01/2011                                  */
/*                      Changed %Le to %le in all functions                  */
/*                                                                           */
/*      September 2004: Jiri Kominek,  CVI 7.0                               */
/*                      Rev. 2.4.2, 09/2004                                  */
/*                      - Fixed functions:                                   */
/*                        rssmiq_w3gppBStationEnhancedOverall                */
/*                        rssmiq_w3gppMStationEnhancedOverall                */
/*                                                                           */
/*      August 2004:    Martin Krcmar,  CVI 6.0                              */
/*                      Rev. 2.4.1, 08/2004                                  */
/*                      - Bug fixed in rssmiq_loadWaveformFile               */
/*                                                                           */
/*      May 2004:       Jiri Kominek,  CVI 7.0                               */
/*                      Rev. 2.4, 05/2004                                    */
/*                      - Implementation of partial SMU support              */
/*                      - Fully or partially compatible functions:           */
/*                        rssmiq_init                                        */
/*                        rssmiq_RFfrequency                                 */
/*                        rssmiq_RFlevel                                     */
/*                        rssmiq_RFlevelAtRecall                             */
/*                        rssmiq_ALC                                         */
/*                        rssmiq_userCorrection                              */
/*                        rssmiq_LFoutput                                    */
/*                        rssmiq_getPeakEnvelopePower                        */
/*                        rssmiq_BERT                                        */
/*                        rssmiq_setBERTAddParameters                        */
/*                        rssmiq_BERTControl                                 */
/*                        rssmiq_GetBERTResults                              */
/*                        rssmiq_configureBLER                               */
/*                        rssmiq_BLERControl                                 */
/*                        rssmiq_getBLERResults                              */
/*                        rssmiq_getBLERType                                 */
/*                        rssmiq_qRFfrequency                                */
/*                        rssmiq_qRFlevel                                    */
/*                        rssmiq_qRFlevOffset                                */
/*                        rssmiq_qRFstartStopFreq                            */
/*                        rssmiq_qRFcenterSpanFreq                           */
/*                        rssmiq_qRFsweepStep                                */
/*                        rssmiq_qLFfreq                                     */
/*                        rssmiq_qLFvolt                                     */
/*                        rssmiq_qAMmodDep                                   */
/*                        rssmiq_AM                                          */
/*                        rssmiq_PULM                                        */
/*                        rssmiq_BBAM                                        */
/*                        rssmiq_RFsweep                                     */
/*                        rssmiq_RFlevelSweep                                */
/*                        rssmiq_LFsweep                                     */
/*                        rssmiq_freqAndLevList                              */
/*                        rssmiq_vectModulation                              */
/*                        rssmiq_IQModImp                                    */
/*                        rssmiq_IQModParameters                             */
/*                        rssmiq_digModulation                               */
/*                        rssmiq_digModLists                                 */
/*                        rssmiq_confDigModStdTrig                           */
/*                        rssmiq_digModStdPowRamp                            */
/*                        rssmiq_getDigitalModulationDelay                   */
/*                        rssmiq_digModASKDepth                              */
/*                        rssmiq_digStdPHS                                   */
/*                        rssmiq_noiseDistSim                                */
/*                        rssmiq_setArb                                      */
/*                        rssmiq_arbWav                                      */
/*                        rssmiq_getArbMemInfo                               */
/*                        rssmiq_arbTrigger                                  */
/*                        rssmiq_arbTriggerOut                               */
/*                        rssmiq_getArbTriggOutCatalog                       */
/*                        rssmiq_arbClock                                    */
/*                        rssmiq_triggerAction                               */
/*                        rssmiq_operComplete                                */
/*                        rssmiq_loadWaveform                                */
/*                        rssmiq_loadWaveformFile                            */
/*                        rssmiq_writeInstrData                              */
/*                        rssmiq_readInstrData                               */
/*                        rssmiq_reset                                       */
/*                        rssmiq_self_test                                   */
/*                        rssmiq_error_query                                 */
/*                        rssmiq_error_message                               */
/*                        rssmiq_revision_query                              */
/*                        rssmiq_saveRecallSetup                             */
/*                        rssmiq_instrOptions                                */
/*                        rssmiq_refOsc                                      */
/*                        rssmiq_setPhaseReference                           */
/*                        rssmiq_beeper                                      */
/*                        rssmiq_calibrate                                   */
/*                        rssmiq_close                                       */
/*                                                                           */
/*                      - Incompatible functions                             */
/*                        rssmiq_modulationState                             */
/*                        rssmiq_qFMdev                                      */
/*                        rssmiq_qPHMdev                                     */
/*                        rssmiq_FM                                          */
/*                        rssmiq_PHM                                         */
/*                        rssmiq_RFsweepMarkers                              */
/*                        rssmiq_RFlevelSweepMarkers                         */
/*                        rssmiq_LFsweepMarkers                              */
/*                        rssmiq_LFsweepMarkerPolarity                       */
/*                        rssmiq_switchAllMarkersOff                         */
/*                        rssmiq_memSequence                                 */
/*                        rssmiq_cfgLstSweTrig                               */
/*                        rssmiq_getCatalogList                              */
/*                        rssmiq_IQModLowACP                                 */
/*                        rssmiq_DmSetHighDynamic                            */
/*                        rssmiq_digModFilterLists                           */
/*                        rssmiq_digModFormat                                */
/*                        rssmiq_digModClock                                 */
/*                        rssmiq_selectFilterFromList                        */
/*                        rssmiq_digModExtIn                                 */
/*                        rssmiq_getDigitalModFilterInfo                     */
/*                        rssmiq_digStdIS95                                  */
/*                        rssmiq_digStdIS95RevLinkCoded                      */
/*                        rssmiq_digitalStandardIS95Filter                   */
/*                        rssmiq_digStdWCDMA                                 */
/*                        rssmiq_digStdWCDMAClockFreq                        */
/*                        rssmiq_digStdNADC                                  */
/*                        rssmiq_digStdPDC                                   */
/*                        rssmiq_digStdGSM                                   */
/*                        rssmiq_digStdGSMFiltType                           */
/*                        rssmiq_digStdDECT                                  */
/*                        rssmiq_digStdDECTUserFilter                        */
/*                        rssmiq_digitalStandardGPS                          */
/*                        rssmiq_GPSPresetRF                                 */
/*                        rssmiq_getGPSFrequency                             */
/*                        rssmiq_getGPSCurrentSymbolRate                     */
/*                        rssmiq_phsSlot                                     */
/*                        rssmiq_WCDMAChannels                               */
/*                        rssmiq_is95Channels                                */
/*                        rssmiq_nadcSlot                                    */
/*                        rssmiq_pdcSlot                                     */
/*                        rssmiq_gsmSlot                                     */
/*                        rssmiq_dectSlot                                    */
/*                        rssmiq_getIS95Power                                */
/*                        rssmiq_dmIS95AdjustPower                           */
/*                        rssmiq_getWCDMAPower                               */
/*                        rssmiq_dmWCDMAAdjustPower                          */
/*                        rssmiq_w3gppState                                  */
/*                        rssmiq_w3gppSetup                                  */
/*                        rssmiq_w3gppSetupCatalog                           */
/*                        rssmiq_w3gppTestModel                              */
/*                        rssmiq_w3gppTestModelCatalog                       */
/*                        rssmiq_w3gppLink                                   */
/*                        rssmiq_w3gppParametrization                        */
/*                        rssmiq_w3gppCopySettings                           */
/*                        rssmiq_w3gppBStation                               */
/*                        rssmiq_w3gppAdjustPower                            */
/*                        rssmiq_w3gppGetPower                               */
/*                        rssmiq_w3gppMultiChannel                           */
/*                        rssmiq_w3gppMultiChannelExec                       */
/*                        rssmiq_w3gppBStationChannel                        */
/*                        rssmiq_w3gppGetDomainError                         */
/*                        rssmiq_w3gppMStation                               */
/*                        rssmiq_w3gppMStationPRACHChannel                   */
/*                        rssmiq_w3gppMStationPCPCHChannel                   */
/*                        rssmiq_w3gppMStationDPCCHChannel                   */
/*                        rssmiq_w3gppMStationDPCCHToff                      */
/*                        rssmiq_w3gppMStationDPDCH                          */
/*                        rssmiq_w3gppMStationDPDCHChannel                   */
/*                        rssmiq_w3gppGetMStationDPDCHParam                  */
/*                        rssmiq_w3gppBStationEnhancedOverall                */
/*                        rssmiq_w3gppBStationEnhancedChannel                */
/*                        rssmiq_w3gppMStationEnhancedOverall                */
/*                        rssmiq_w3gppMStationEnhancedChannel                */
/*                        rssmiq_w3gppConfigureEnhancedChannel               */
/*                        rssmiq_w3gppGetMStationEnhParam                    */
/*                        rssmiq_w3gppGetFreeFrameMem                        */
/*                        rssmiq_w3gppGetActualBER                           */
/*                        rssmiq_w3gppBaseStationOCNSState                   */
/*                        rssmiq_w3gppBStationOCNS                           */
/*                        rssmiq_w3gppMStationAdditional                     */
/*                        rssmiq_w3gppGetGPP3Version                         */
/*                        rssmiq_w3gppGetChipRate                            */
/*                        rssmiq_w3gppGetPCCPLength                          */
/*                        rssmiq_w3gppConfigureBitBlocksErrors               */
/*                        rssmiq_w3gppGetResultingBER                        */
/*                        rssmiq_recalculatingFadingSignal                   */
/*                        rssmiq_fadingGetExternCrestFactor                  */
/*                        rssmiq_fadingDefault                               */
/*                        rssmiq_fadingFineDelayDefault                      */
/*                        rssmiq_fadingFineDelay                             */
/*                        rssmiq_fadingFineDelayPath                         */
/*                        rssmiq_fadingMovingDelayDefault                    */
/*                        rssmiq_fadingMovingDelay                           */
/*                        rssmiq_fadingBirthDeathDefault                     */
/*                        rssmiq_fadingBirthDeath                            */
/*                        rssmiq_fadingBirthDeathDelayPath                   */
/*                        rssmiq_fading                                      */
/*                        rssmiq_fadingPath                                  */
/*                        rssmiq_fadingPhaseForCPHAS                         */
/*                        rssmiq_distCharact                                 */
/*                        rssmiq_distCatalog                                 */
/*                        rssmiq_distMemInfo                                 */
/*                        rssmiq_distMode                                    */
/*                        rssmiq_distPolyCoef                                */
/*                        rssmiq_distRecalculate                             */
/*                        rssmiq_distLevCorrect                              */
/*                        rssmiq_distInvFunc                                 */
/*                        rssmiq_arbAutoSetting                              */
/*                        rssmiq_arbIQLevel                                  */
/*                        rssmiq_auxIO                                       */
/*                      - new CHM help file added                            */
/*                      - added Agilent VISA workaround                      */
/*                                                                           */
/*      March 2004:     Werner Klotzsche,  CVI 6.0                           */
/*                      Rev. 2.34, 03/2004                                   */
/*                      Modifications:                                       */
/*                      - rssmiq_w3gppBStationChannel                        */
/*                       adding  timingOffset to channel 5 and 6             *
/*                                                                           */
/*      March 2004:     Werner Klotzsche,  CVI 6.0                           */
/*                      Rev. 2.33, 03/2004                                   */
/*                      Modifications:                                       */
/*                      - rssmiq_noiseDistSim                                */
/*                       carrier/noise: changed lower limit to -30dBse       */
/*                      - rssmiq_digModulation                               */
/*                       symbol rate:changed default value to 270833.333 S/s */
/*                                                                           */
/*      March 2003:     Jiri Kominek, CVI 6.0                                */
/*                      Rev. 2.32, 03/2003                                   */
/*                      Modifications:                                       */
/*                      Fixed bug in binary data transmission in functions:  */
/*                      - rssmiq_digModLists                                 */
/*                      - rssmiq_freqAndLevList                              */
/*                      - rssmiq_loadWaveform                                */
/*                      - rssmiq_loadWaveformFile                            */
/*                                                                           */
/*      January 2003:   Werner Klotzsche   CVI 6.0                           */
/*                      Rev. 2.31, 01/2003                                   */
/*                      Modifications:                                       */
/*                      - rssmiq_IQModParameters changed crest factor        */
/*                            to ViReal64                                    */
/*                      - rssmiq_arbWav                                      */
/*                                                                           */
/*      September 2002: P.Marcalik                                           */
/*                      Rev 2.3, 09/2002, CVI 5.5.1                          */
/*                      - Removed #include <cvidef.h> from header file       */
/*                      - Source code can be compiled with different         */
/*                        compilers as CVI.                                  */
/*                                                                           */
/*      August 2002:    Werner Klotzsche, Rohde & Schwarz                    */
/*                      Rev 2.21 08/2002, CVI 5.5.1                          */
/*                      - fixed Application Example                          */
/*                                                                           */
/*      April 2002:     Helena Sucha                                         */
/*                      Rev 2.2 4/2002, CVI 5.5.1                            */
/*                      - list of options added to user data attribute in    */
/*                        VISA session                                       */
/*                      - new function checkOption was added.                */
/*                      - the model for mobile station and TEST_4 for base   */
/*                        station and options checking were added into       */
/*                        w3gppTestModel                                     */
/*                      - the parameter ALL added into function calibrate    */
/*                      - the value EXT,INT added into parameter Source in   */
/*                        function AM. The Unit PCT added to command AM:DEPT */
/*                      - the value 7.5MHz and 10MHz are added into function */
/*                        IQModLowACP                                        */
/*                      - the value User added into filter in function       */
/*                        digModulation                                      */
/*                      - the configuration of GPS standard, GSM Output1     */
/*                        (Slot/Frame), Output1/2 polarity and PHS Output1   */
/*                        (Slot/Frame) added into confDigModStdTrig          */
/*                      - trigger BERT added to function Trigger Action      */
/*                      - the parameter CPHAS added to Profile in Fading Path*/
/*                      - the User added to filter types in Digital Standard */
/*                        IS95                                               */
/*                      - added new functions:                               */
/*                          configureBLER, BLERControl, getBLERResults,      */
/*                          getBLERType, setBERTAddParameters, BERTControl   */
/*                          digitalStandardGPS, GPSPresetRF, getGPSFrequency */
/*                          getGPSCurrentSymbolRate,                         */
/*                          getCatalogList, w3gppTestModelCatalog,           */
/*                          w3gppGetGPP3Version, w3gppGetChipRate,           */
/*                          w3gppGetMStationDPDCHParam, w3gppGetPCCPLength,  */
/*                          w3gppGetResultingBER,                            */
/*                          w3gppConfigureBitBlocksErrors,                   */
/*                          w3gppConfigureEnhancedChannel,                   */
/*                          w3gppBaseStationOCNSState,                       */
/*                          w3gppGetMStationEnhParam, getRFLevelLimit        */
/*                          digStdDECTUserFilter, IQModParameters,           */
/*                          digModFilterLists, getDigitalModFilterInfo       */
/*                          getDigitalModulationDelay                        */
/*                          digModASKDepth, recalculatingFadingSignal        */
/*                          fadingGetExternCrestFactor, fadingDefault        */
/*                          fadingPhaseForCPHAS, fadingFineDelay,            */
/*                          fadingFineDelayDefault, fadingFineDelayPath      */
/*                          fadingMovingDelay, fadingMovingDelayDefault      */
/*                          fadingBirthDeathDefault, fadingBirthDeath        */
/*                          fadingBirthDeathDelayPath,                       */
/*                          digStdGSMFiltType, digitalStandardIS95Filter,    */
/*                          getIS95Power, dmIS95AdjustPower,                 */
/*                          switchAllMarkersOff, modulationState,            */
/*                          selectFilterFromList, setPhaseReference,         */
/*                          RFlevelAtRecall, getPeakEnvelopePower,           */
/*                          digStdWCDMAClockFreq, getWCDMAPower,             */
/*                          dmWCDMAAdjustPower, LFsweepMarkerPolarity,       */
/*                          DMSetHighDynamic                                 */
/*                                                                           */
/*      October 2001:   Zdenek Rykala                                        */
/*                      Rev 2.13 10/2001, CVI 5.5.1                          */
/*                      - fixed rssmiq_instrOptions function.                */
/*                                                                           */
/*      April 2001:     Ottmar Gerlach, Rohde & Schwarz                      */
/*                      Rev 2.12 04/2001, CVI 5.5.1                          */
/*                      - removed bug in rssmiq_digModulation                */
/*                                                                           */
/*      October 2000:     Werner Klotzsche, Rohde & Schwarz                  */
/*                      Rev 2.1, 10/2000, CVI 5.5                            */
/*                      - added Offset reset to rssmiq_RFfrequency           */
/*                      - changed Max Frequency to 6.4 GHz for SMIQ 06       */
/*                      - removed bug in  rssmiq_PHM                         */
/*                      Rev 2.11, 10/2000, CVI 5.5                           */
/*                      - changed rssmiq_RFfrequency Knob Step unit to MHz   */
/*                                                                           */
/*   December 1999:      Rev 1.31, 12/1999, CVI 5.0.1                        */
/*                       - changed data type ViChar[] to ViString in function*/
/*                         rssmiq_digModLists.                               */
/* Modified by:          Zdenek Rykala                                       */
/*                                                                           */
/*   November 1999:      Rev 1.3, 11/1999, CVI 5.0.1                         */
/*                       - Removed warnings                                  */
/* Modified by:          Zdenek Rykala                                       */
/*                                                                           */
/*                                                                           */
/*       June 1999:      Rev 1.2, 06/1999, CVI 5.0.1                         */
/*                       Renamed utility functions and other minor fixes     */
/*                                                                           */
/* Modified by:          Jan Sima                                            */
/*                                                                           */
/*      March 1999:     Jan Sima                                             */
/*                      CVI 5.0.1                                            */
/*                      - new functions:                                     */
/*                      Added new class: Configuration Functions...          */
/*                      Quick Functions....                                  */
/*                                                                           */
/*                      qRFfrequency        RF Frequency                     */
/*                      qRFlevel            RF Level                         */
/*                      qRFlevOffset        RF Level Offset                  */
/*                      qRFstartStopFreq    RF Start Stop Frequency          */
/*                      qRFcenterSpanFreq   RF Center Span Frequency         */
/*                      qRFsweepStep        RF Sweep Step                    */
/*                      qLFfreq             LF Frequency                     */
/*                      qLFvolt             LF Voltage                       */
/*                      qAMmodDepth         AM Modulation Depth              */
/*                      qFMdev              FM Deviation                     */
/*                      qPHMdev             Phase Mod Deviation              */
/*                                                                           */
/*                      - removed bug in function rssmiq_RFlevel             */
/*                                                                           */
/*      July 2000:      Jan Sima                                             */
/*                      CVI 5.5                                              */
/*                                                                           */
/*                      - added W3GPP Digital Modulation functions           */
/*                                                                           */
/*                      - added BERT functions                               */
/*                                                                           */
/*                      - modified source code so that it is not using       */
/*                        Formatting and I/O library functions (Fmt, Scan..) */
/*                                                                           */
/*                      - added W-CDMA functions digStdWCDMA and             */
/*                        WCDMAChannel                                       */
/*                                                                           */
/*                      - removed the linefeed characters appended to the    */
/*                        and of each coomand string. This is now done by    */
/*                        VISA configured to do so in the Initialize function*/
/*                                                                           */
/*                      - added the crest factor and the IQ Filter parameters*/
/*                        to vectModulation function                         */
/*                                                                           */
/*                      - added DECT and WCDMA/W3GPP support into function   */
/*                        confDigModStrTrg                                   */
/*                                                                           */
/*                      - added DECT support to confDigModStdPowRamp         */
/*                                                                           */
/*                      - changed all "DLIST0" default values to "DLIST0"    */
/*                                                                           */
/*            - added the PN11 data source to digital standard               */
/*                        functions                                          */
/*                                                                           */
/*                      - added Slot Attenuation parameter to the PHS, NADC, */
/*                        PDC, GSM/EDGE and DECT digital standards functions */
/*                                                                           */
/*                      - added Arbitrary Waveform Generator functions.      */
/*                                                                           */
/*                      - in rssmiq_gsmSlot changed the "HOP" node to "HOPP" */
/*                                                                           */
/*===========================================================================*/
#include <visa.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <errno.h>
#include <time.h>

#if defined(_CVI_)
    #include <utility.h>   /* Delay */
#elif defined (_MSC_VER)
    #include    <windows.h>
    #define     Delay(timeout)  Sleep((ViUInt32)(timeout*1000.0))
#else
    #define     Delay(timeout)  rssmiq_delay(timeout)
#endif

#include "rssmiq.h"

/*= DEFINES =================================================================*/
/* The format for RSSMIQ_REVISION is a string with three fields separated by */
/* commas, the first field is the revision of the instrument driver, the     */
/* second field is the month and year of the version's release, and the third*/
/* field is the version of CVI used to write the current version.  Please    */
/* modify here and in the function panel help for the rssmiq_revisionQuery   */
/* function panel.                                                           */
/*===========================================================================*/

#define RSSMIQ_REVISION     "Rev 2.4.3, 01/2011" /*  Instrument driver revision */
#define BUFFER_SIZE         1024L         /* File I/O buffer size */

/*= Macros ==================================================================*/
#define CHECKERR(fCal) if (rssmiq_status = (fCal), rssmiq_status < VI_SUCCESS) \
              return rssmiq_status; else


#define CHECKPARM(fCal, errCode) if (rssmiq_status = (fCal), rssmiq_status < VI_SUCCESS) \
                                    if ((rssmiq_status>VI_ERROR_PARAMETER1) && (rssmiq_status<VI_ERROR_INSTR_PARAMETER12)) \
                                        return errCode; \
                                    else \
                                        return rssmiq_status; }\
                                 else


/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS =====================================*/
/*****************************************************************************/
static ViString levUnitArr[] = {"DBM", "DBUV", "MV", "UV"};
static ViString alcModeArr[] = {":SOUR:POW:ALC OFF", ":SOUR:POW:ALC AUTO",
                                ":SOUR:POW:ALC ON"};
static ViString alcOffModeArr[] = {";:SOUR:POW:ALC:SEAR OFF",
                                   ";:SOUR:POW:ALC:SEAR ONCE",
                                   ";:SOUR:POW:ALC:SEAR ON"};
static ViString offOnArr[] = {"OFF", "ON",VI_NULL};
static ViString PRBSArr[] = {"PRBS9","PRBS11","PRBS15","PRBS16","PRBS20",
              "PRBS21","PRBS23", VI_NULL};
static ViString BERTDataPolarArr[] = {"INV","NORM", VI_NULL};
static ViString BERTClockPolarArr[] = {"FALL","RIS", VI_NULL};
static ViString BERTMaskArr[] = {"OFF","HIGH","LOW"};
static ViString BERTIgnArr[] = {"OFF", "ONE", "ZERO"};
static ViString BERTRestartArr[] = {"INT","EXT", VI_NULL};

static ViString int1extArr[] = {"INT1", "EXT", "EXT,INT1", VI_NULL};
static ViString smu_intextArr[] = {"INT", "EXT", "EXT,INT", VI_NULL};
static ViString acDcArr[] = {"AC", "DC"};
static ViString normInvArr[] = {"NORM", "INV"};
static ViString intExt12Arr[] = {"INT", "EXT1", "EXT2"};
static ViString preEmpArr[] = {"0", "50us", "75us"};
static ViString linLogArr[] = {"LIN", "LOG"};
static ViString levUnitSweArr[] = {"DBM", "DBW", "DBMW", "DBUW", "DBV", "DBMV", "DBUV", "V"};
static ViString lstTrgModeArr[] =
 {":SOUR:FREQ:MODE CW",
  ":SOUR:FREQ:MODE SWE;:SOUR:SWE:MODE AUTO;:TRIG:SOUR AUTO",
  ":SOUR:FREQ:MODE SWE;:SOUR:SWE:MODE AUTO;:TRIG:SOUR SING",
  ":SOUR:FREQ:MODE SWE;:SOUR:SWE:MODE STEP;:TRIG:SOUR SING",
  ":SOUR:FREQ:MODE SWE;:SOUR:SWE:MODE AUTO;:TRIG:SOUR EXT",
  ":SOUR:FREQ:MODE SWE;:SOUR:SWE:MODE STEP;:TRIG:SOUR EXT",
  "",
  ":SOUR:POW:MODE CW",
  ":SOUR:POW:MODE SWE;:SOUR:SWE:POW:MODE AUTO;:TRIG:SOUR AUTO",
  ":SOUR:POW:MODE SWE;:SOUR:SWE:POW:MODE AUTO;:TRIG:SOUR SING",
  ":SOUR:POW:MODE SWE;:SOUR:SWE:POW:MODE STEP;:TRIG:SOUR SING",
  ":SOUR:POW:MODE SWE;:SOUR:SWE:POW:MODE AUTO;:TRIG:SOUR EXT",
  ":SOUR:POW:MODE SWE;:SOUR:SWE:POW:MODE STEP;:TRIG:SOUR EXT",
  "",
  ":SOUR:FREQ:MODE CW",
  ":SOUR2:FREQ:MODE SWE;:SOUR2:SWE:MODE AUTO;:TRIG:SOUR AUTO",
  ":SOUR2:FREQ:MODE SWE;:SOUR2:SWE:MODE AUTO;:TRIG:SOUR SING",
  ":SOUR2:FREQ:MODE SWE;:SOUR2:SWE:MODE STEP;:TRIG:SOUR SING",
  ":SOUR2:FREQ:MODE SWE;:SOUR2:SWE:MODE AUTO;:TRIG:SOUR EXT",
  ":SOUR2:FREQ:MODE SWE;:SOUR2:SWE:MODE STEP;:TRIG:SOUR EXT",
  "",
  ":SOUR:FREQ:MODE CW",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE AUTO;:TRIG:LIST:SOUR AUTO",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE AUTO;:TRIG:LIST:SOUR SING",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE STEP;:TRIG:LIST:SOUR SING",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE AUTO;:TRIG:LIST:SOUR EXT",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE STEP;:TRIG:LIST:SOUR EXT",
  ":SOUR:FREQ:MODE LIST;:SOUR:LIST:MODE STEP;:TRIG:LIST:SOUR HOP",
  ":SYST:MODE FIX",
  ":SYST:MODE MSEQ;:SYST:MSEQ:MODE AUTO;:TRIG:MSEQ:SOUR AUTO",
  ":SYST:MODE MSEQ;:SYST:MSEQ:MODE AUTO;:TRIG:MSEQ:SOUR SING",
  ":SYST:MODE MSEQ;:SYST:MSEQ:MODE STEP;:TRIG:MSEQ:SOUR SING",
  ":SYST:MODE MSEQ;:SYST:MSEQ:MODE AUTO;:TRIG:MSEQ:SOUR EXT",
  ":SYST:MODE MSEQ;:SYST:MSEQ:MODE STEP;:TRIG:MSEQ:SOUR EXT",
  ""};
static ViString offAExtArr[] = {"OFF", "AEXT"};
static ViString dmSourArr[] = {"PAR", "SER", "PATT;:SOUR:DM:PATT ZERO",
                 "PATT;:SOUR:DM:PATT ONE","PATT;:SOUR:DM:PATT ALT",
                 "PRBS;:SOUR:DM:PRBS 9", "PRBS;:SOUR:DM:PRBS 15",
                 "PRBS;:SOUR:DM:PRBS 16", "PRBS;:SOUR:DM:PRBS 20",
                 "PRBS;:SOUR:DM:PRBS 21", "PRBS;:SOUR:DM:PRBS 23",
                 "SDATA", "DLIST"};
static ViString dmStdArr[] = {"USER", "APCF", "APCQ", "CDPD", "CT2", "DECT",
                "GSM", "IRID", "NADC", "PDC", "PHS", "TETRA",
                "TFTS", "PWT", "ICOB", "ICOG", "ICOQ", "WORL", "ASK", "BLU",
                "GSME", "FIS95", "RIS95", "QWCD"};
static ViString dmModArr[] = {"", "BPSK", "QPSK", "QIS95", "QINM", "QICO", "OQPS",
                "OIS95", "P4QPSK", "P4DQ", "PSK8", "GMSK", "GFSK",
                "FSK2", "FSK4", "AFSK4", "QAM16", "QAM32",
                "QAM64", "QAM256", "USER", "ASK", "QWCD", "PSKE8"};
static ViString dmCodArr[] = {"", "OFF", "DIFF", "DPHS", "DGR", "GSM", "NADC",
                "PDC", "PHS", "TETRA", "APCO25", "PWT", "TFTS",
                "INM" , "VDL"};
static ViString dmFltArr[] = {"", "SCOS", "COS", "GAUS", "BESS1", "BESS2", "IS95",
                "EIS95", "APCO", "TETR", "WCDM", "RECT", "SPH", "USER"};
static ViString fltModeArr[] = {"LACP", "LEVM"};
static ViString digStdArr[] = {"DM", "PHS", "IS95", "WCDM", "NADC", "PDC", "GSM", "DECT", "W3GP", "GPS"};
static ViString digClkSrcArr[] = {"INT", "COUP", "EXT"};
static ViString digClkModeArr[] = {"BIT", "SYMB", "CHIP", "CHIP4", "CHIP8", "CHIP16"};
static ViString digExtImpArr[] = {"G1K", "G50", "ECL"};
static ViString digTrgModeArr[] = {"AUTO", "RETR", "AAUT", "ARET", "SING"};
static ViString intExtArr[] = {"INT", "EXT"};
static ViString is95trgOutArr[] = {"TFR", "SSR", "SFR", "ESEC", "GATE", "SLOT", "RFR", "CSP", "CODE", "NBIT", "NWOR", "SFR", "FRAM"};
static ViString negPosArr[] = {"NEG", "POS"};
static ViString pRampModeArr[] = {"OFF", "ON;:SOUR:DM:PRAMP:SOUR CLIST",
                  "ON;:SOUR:DM:PRAMP:SOUR AEXT",
                  "ON;:SOUR:DM:PRAMP:SOUR DEXT"};
static ViString linCosArr[] = {"LIN", "COS"};
static ViString scosCosArr[] = {"SCOS", "COS"};

static ViString linkDirArr[] = {"FLIN18", "FLIN64", "RLIN", "RLC"};
static ViString is95FltArr[] = {"SCOS", "COS", "IS95", "EIS95", "USER"};
static ViString fullHalfArr[] = {"FULL", "HALF"};
static ViString revLnkDataArr[] = {"ZERO", "ONE", "ALT", "PRBS"};
static ViString downUpArr[] = {"DOWN", "UP"};
static ViString nadcRateArr[] = {"AHAL", "FULL1", "FULL2", "FULL3", "FULL12",
                 "FULL13", "FULL23", "AFUL"};
static ViString pdcRateArr[] = {"AHAL", "FULL0", "FULL1", "FULL2", "FULL10",
                 "FULL20", "FULL21", "AFUL"};
static ViString gsmModArr[] = {"", "GMSK", "GFSK"};
static ViString wcdmaModArr[] = {"CHAN4", "CHAN8", "CHAN15"};
static ViString wcdmaChArr[] = {"", "I:", "Q:"};
static ViString wcdmaChTypeArr[] = {"PERC", "CCPC", "DPCH", "ALLD", "DPDC", "DPCC"};
static ViString wcdmaSRatArr[] = {"D16", "D32", "D64", "D128", "D256", "D512", "D1024"};
static ViString wcdmaSourArr[] = {"PN9", "PN11", "PN15", "PN16", "DLIS"};
static ViString wcdmaTPCDataArr[] = {"ZERO", "ONE", "ALT", "DLIS"};
static ViString dectFrameTypeArr[] = {"", "\"DNFULL\"", "\"UPFULL\"", "\"FULL_0\"",
                    "\"DOUB_0\"", "\"PWT_FP\"", "\"PWT_PP\""};
static ViString singAutoArr[] = {"SING", "AUTO"};
static ViString delSelArr[] = {"DEL", "SEL"};
static ViString dectSlotTypeArr[] = {"FULL", "DOUB", "ADAT"};
static ViString dectLevelArr[] = {"OFF", "FULL", "ATT"};
static ViString dectFieldArr[] = {"PN9", "PN11", "PN15", "PN16", "PN20", "PN21",
                "PN23", "SDAT", "DLIS"};
static ViString dataPolyArr[] = {"DATA", "POLY"};


static ViString chRateArr[] = {"R4M", "R8M"};
static ViString wcdmaLinkDirArr[] = {"DOWN", "UP", "UPM"};
static ViString wcdmaModTypeArr[] = {"OQPSK", "QPSK"};
static ViString filterArr[] = {"SCOS", "COS", "WCDM"};



static ViString phsSlotTypeArr[] = {"TCHF", "TCHH", "SYNC", "VOX", "ADAT"};
static ViString slotAttArr[] = {"OFF", "FULL", "ATT"};
static ViString dataSourceArr[] = {"PN9", "PN11", "PN15", "PN16", "PN20", "PN21",
                "PN23", "SDATA", "DLIS"};
static ViString revLinkDataArr[] = {"ZERO", "ONE", "ALT", "PRBS"};
static ViString nadcSlotTypeArr[] = {"TCH", "ADAT", "SHOR"};
static ViString pdcSlotTypeArr[] = {"TCH", "ADAT", "SYNC", "VOX"};
static ViString gsmSlotTypeArr[] = {"NORM", "DUMM", "ADAT", "EDGE"};
static ViString tscArr[] = {"T0", "T1", "T2", "T3", "T4", "T5", "T6", "T7", "USER"};
static ViString fadingConfArr[] = {"OFF", "ON;:SOUR:FSIM:CONF S6P",
                   "ON;:SOUR:FSIM:CONF S12P",
                   "ON;:SOUR:FSIM:CONF D6P"};
static ViString fadingModeArr[] = {"STOP", "RUN", ":RES"};
static ViString fadingStdArr[] = {"CDMA8", "CDMA30", "CDMA100", "NADC8", "NADC50",
                  "NADC100", "G6TU3", "GTU3", "G6TU50", "GTU50",
                  "G6HT100", "GHT100", "GRA250", "GET50", "GET100",
                  "P6TU1", "PTU1", "P6TU50", "PTU50", "P6HT100",
                  "PHT100", "PRA130", "PET50", "PET100", "TTU",
                  "THT", "TET"};
static ViString fadingILossArr[] = {"NORM", "LACP"};
static ViString fadProfArr[] = {"PDOP", "RAYL", "RICE", "CPH"};
static ViString correlPathAtt[] = {"0", "7", "8", "9", "10", "11", "12"};
static ViString outAttModeArr[] = {"AUTO", "FIX", "ELEC"};
static ViString trigActionArr[] = {":TRIG1:SWE:IMM;*WAI", ":TRIG2:SWE:IMM;*WAI",
                   ":ABORT:SWE;*WAI", ":TRIG:LIST:IMM;*WAI",
                   ":ABORT:LIST;*WAI", ":TRIG:MSEQ:IMM;*WAI",
                   ":ABORT:MSEQ;*WAI", ":TRIG:DM:IMM;*WAI",
                   ":TRIG:BERT:IMM;*WAI"};
static ViString setModeArr[] = {"*SAV", "*RCL"};
static ViString normLongArr[] = {"NORM", "LONG"};
static ViString trigSlopArr[] = {"POS", "NEG", "EITH"};
static ViString calModeArr[] = {":CAL:VMOD?", ":CAL:LEV:STAT ON",
                                ":CAL:LEV:STAT OFF", ":CAL:LATT?",
                                ":CAL:FSIM?", ":CAL:NDS?"};
static ViString oneOrTwo[] = {"1", "2"};

static ViString arbSeqArr[] = {"AUTO", "RETR", "AAUTO", "ARET"};

static ViString sRateArr[] = {"D7K5", "D15K", "D30K", "D60K", "D120K", "D240K", "D480K", "D960K", "X2", "X3", "X4", "X5", "X6"};
static ViString dSourArr[] = {"PN9", "PN11", "PN15", "PN16", "ZERO", "ONE", "PATT", "DLIS",VI_NULL};
static ViString dataEnableArr[] = {"LOW", "HIGH", "OFF", VI_NULL};
static ViString unitArr[] = {"ENG", "SCI", "PCT", "PPM", VI_NULL};
static ViString retBLERTypeArr[] = {"CRC16", VI_NULL};
static ViString dGPSSourceArr[] = {"PATT", "DLIST", VI_NULL};
static ViString stationArr[] = {"BST", "MST", VI_NULL};
static ViString errTypeArr[] = {"BIT", "BLOC", VI_NULL};
static ViString w3gpchanTypeArr[] = {"DTCH", "DCCH", "DPCH", "DPDC", VI_NULL};
static ViString afixedRangeArr[] = {"LOW", "UPP", VI_NULL};
static ViString iqTransitionArr[] = {"NORM", "FAST", VI_NULL};
static ViString fsimStandardArr[] = {"G3C1", "G3C2", "G3C3", "G3C4", "G3UEC1", "G3UEC2", "G3UEC3", "G3UEC4","G3UEC5","G3UEC6", VI_NULL};
static ViString speedUnitArr[] = {"MPS", "KMPH", "MPH", VI_NULL};
static ViString sourceArr[] = {"SOUR", "SOUR2", VI_NULL};
static ViString sweepArr[]  = {"FSW", "PSW", VI_NULL};
static ViString GSMFilterArr[] = {"USER", "GAUS", VI_NULL};
static ViString filtStdArr[] = {"NADC", "PDC", "PHS", "WCDM", VI_NULL};
static ViString RFLevRecalArr[] = {"EXCL", "INCL", VI_NULL};

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rssmiq_stringValPair is used in the rssmiq_errorMessage function          */
/* rssmiq_statusDataRanges is used to track session dependent status & ranges*/
/*===========================================================================*/
typedef struct  rssmiq_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rssmiq_tStringValPair;

struct rssmiq_statusDataRanges {
    ViBoolean   errorChecking;
    ViChar      instrDriverRevision[BUFFER_SIZE];
    ViInt32     options;
    ViInt32     instrType; // 0 - SMIQ, 1 - SMU
};

typedef struct rssmiq_statusDataRanges *rssmiq_instrRange;

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
ViBoolean rssmiq_invalidViBooleanRange (ViBoolean val);
ViBoolean rssmiq_invalidViInt16Range (ViInt16 val, ViInt16 min, ViInt16 max);
ViBoolean rssmiq_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssmiq_invalidViUInt8Range (ViUInt8 val, ViUInt8 min, ViUInt8 max);
ViBoolean rssmiq_invalidViUInt16Range (ViUInt16 val, ViUInt16 min, ViUInt16 max);
ViBoolean rssmiq_invalidViUInt32Range (ViUInt32 val, ViUInt32 min, ViUInt32 max);
ViBoolean rssmiq_invalidViReal32Range (ViReal32 val, ViReal32 min, ViReal32 max);
ViBoolean rssmiq_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max);
ViStatus rssmiq_initCleanUp (ViSession openRMSession, ViPSession openinstrumentHandle,
                                    ViStatus currentStatus);
ViStatus rssmiq_defaultInstrSetup (ViSession openinstrumentHandle);
ViStatus rssmiq_checkStatus (ViSession instrumentHandle);
ViUInt32 rssmiq_swapViUInt32 (ViUInt32 val);
ViStatus rssmiq_getIndexFromString (ViSession instrumentHandle, ViString string,
                                     ViString *list, ViInt32 *index);
ViStatus rssmiq_checkOption (ViSession instrumentHandle, ViInt32 option);
ViStatus rssmiq_getDMFormat(ViSession instrumentHandle, ViInt32 *format);
static void rssmiq_delay (ViReal64 delay);

/*****************************************************************************/
/*------ INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINE DECLARATIONS HERE ------*/
/*****************************************************************************/


/*****************************************************************************/
/*====== USER-CALLABLE FUNCTIONS (Exportable Functions) =====================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrumentHandle)
{
    ViStatus            rssmiq_status = VI_SUCCESS;
    ViSession           rmSession = 0;
    ViUInt32            retCnt = 0;
    ViByte              rdBuffer[BUFFER_SIZE];
    ViUInt16            intfType;
    rssmiq_instrRange   instrPtr;
    ViUInt16            oldEndCharIn = VI_ASRL_END_TERMCHAR;
    ViUInt16            oldEndCharOut = VI_ASRL_END_TERMCHAR;
    ViBoolean           oldTermChar = VI_TRUE;
    ViUInt16  			oldFlowControl = VI_ASRL_FLOW_RTS_CTS;
    ViUInt16            oldWriteBuffer = VI_FLUSH_ON_ACCESS;
    ViUInt16            oldReadBuffer = VI_FLUSH_ON_ACCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (IDQuery))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (resetDevice))
        return VI_ERROR_PARAMETER3;

    /*- Open instrument session ---------------------------------------------*/
    if ((rssmiq_status = viOpenDefaultRM (&rmSession)) < 0)
        return rssmiq_status;

    if ((rssmiq_status = viOpen (rmSession, resourceName, VI_LOAD_CONFIG, VI_NULL, instrumentHandle)) < 0) {
        viClose (rmSession);
        return rssmiq_status;
    }

    /*- Configure VISA Formatted I/O ----------------------------------------*/
    if ((rssmiq_status = viGetAttribute (*instrumentHandle, VI_ATTR_INTF_TYPE, &intfType)) < 0)
        return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    if (intfType == VI_INTF_ASRL) {
      if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_TERMCHAR, '\n')) < 0)
        return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar)) < 0)
      return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndCharIn)) < 0)
      return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_ASRL_END_OUT, oldEndCharOut)) < 0)
      return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
        if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_ASRL_FLOW_CNTRL, oldFlowControl)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
    }
    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_TMO_VALUE, 10000)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    if ((rssmiq_status = viSetBuf (*instrumentHandle, VI_READ_BUF|VI_WRITE_BUF, 4000)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_WR_BUF_OPER_MODE,
                            oldWriteBuffer)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    if ((rssmiq_status = viSetAttribute (*instrumentHandle, VI_ATTR_RD_BUF_OPER_MODE,
                            oldReadBuffer)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

  /* To initialize the instrument communication we first must send \n      */
    if ((rssmiq_status = viWrite (*instrumentHandle, (ViBuf)"\n", 1, &retCnt)) < 0)
        return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery) {
        if ((rssmiq_status = viQueryf (*instrumentHandle, "\n*IDN?\n", "%s", rdBuffer)) < 0)
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
    if (strncmp ((ViChar *)rdBuffer, "Rohde&Schwarz,SM", 16))
          return rssmiq_initCleanUp (rmSession, instrumentHandle, VI_ERROR_FAIL_ID_QUERY);
    }

    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice) {
        if ((rssmiq_status = rssmiq_reset (*instrumentHandle)) < 0) {
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
        }
    }
    else { /*- Send Default Instrument Setup ---------------------------------*/
        if ((rssmiq_status = rssmiq_defaultInstrSetup (*instrumentHandle)) < 0) {
            return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);
        }
    }

    // get pointer to instrument session user data
    if ((rssmiq_status = viGetAttribute (*instrumentHandle, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rssmiq_initCleanUp (rmSession, instrumentHandle, rssmiq_status);

    // set instrument type: 1 - SMU, 0 - Other
    instrPtr->instrType = (strncmp ((ViChar *)rdBuffer, "Rohde&Schwarz,SMU", 17) == 0);

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Application Example                                             */
/* Purpose:  This function is an example that shows how to use the functions */
/*           of the driver. This example configures the instrument to        */
/*           generate a digitally modulated signal according to GSM standard.*/
/*           The user can change the data frame, RF frequency, signal level  */
/*           and turn the RF output on of off.                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_applicationExample (ViSession instrumentHandle,
                    ViReal64 frequency, ViReal64 level, ViBoolean rfOut,
                    ViString predefinedFrame)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 error = 0;
    ViChar message[256];

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (frequency, 0.3, 6400.0))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (level, -144.0, 16.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (rfOut))
        return VI_ERROR_PARAMETER4;
    if ((rssmiq_status = rssmiq_reset (instrumentHandle)) < 0)
        return rssmiq_status;

  Delay (1.0);

    CHECKERR (rssmiq_digStdGSM (instrumentHandle, VI_TRUE, 0, 0.1, 2.708333E+5, 0.3, VI_FALSE, predefinedFrame, 15.0));
    CHECKERR (rssmiq_confDigModStdTrig (instrumentHandle, 6, 0, VI_FALSE, 0, 0, 0,
                                        1, 1, 5, VI_TRUE, 3, VI_TRUE));
    CHECKERR (rssmiq_RFfrequency (instrumentHandle, frequency, 0.0, 0.0));
    CHECKERR (rssmiq_RFlevel (instrumentHandle, level, 16.0, 0, 0.0, 1.0));
    CHECKERR (rssmiq_ALC (instrumentHandle, 1, 0, VI_FALSE));
    CHECKERR (rssmiq_rfOutput (instrumentHandle, rfOut, 0));
    CHECKERR (rssmiq_error_query (instrumentHandle, &error, message));

    return error;
}

/*===========================================================================*/
/* Function: RF Frequency                                                    */
/* Purpose:  This function configures the frequency of the RF output signal. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFfrequency (ViSession instrumentHandle, ViReal64 RFFrequency,
                    ViReal64 RFOffset, ViReal64 knobStep)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (RFFrequency, 0.3, 6400.0))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (RFOffset, -50000.0, 50000.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (knobStep, 0.0, 1000.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR (viPrintf (instrumentHandle,
              "\n:SOUR:FREQ:OFFS 0MHZ;:SOUR:FREQ %fMHZ;:SOUR:FREQ:OFFS %fMHZ;:SOUR:FREQ:STEP %fMHZ\n",
                RFFrequency, RFOffset,  knobStep));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Level                                                        */
/* Purpose:  This function configures the level of the RF output signal.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFlevel (ViSession instrumentHandle, ViReal64 RFLevel,
                    ViReal64 levelLimit, ViInt32 levelUnit,
                    ViReal64 levelOffset, ViReal64 knobStep)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (levelUnit == 0) {
      /* Check only for default level unit dBm*/
      if (rssmiq_invalidViReal64Range (RFLevel, -144.0, 16.0))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViReal64Range (levelLimit, -144.0, 16.0))
          return VI_ERROR_PARAMETER3;
    }
    if (rssmiq_invalidViInt32Range (levelUnit, 0, 3))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (levelOffset, -100.0, 100.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (knobStep, 0.1, 10.0))
        return VI_ERROR_PARAMETER6;

    CHECKERR (viPrintf (instrumentHandle,
              "\n:POW:LIM %f%s;:SOUR:POW:OFFS %le;:SOUR:POW %f%s;POW:STEP %le\n",
              levelLimit, levUnitArr[levelUnit],levelOffset,RFLevel,levUnitArr[levelUnit],knobStep));

    return rssmiq_status;
}
/*===========================================================================*/
/* Function: RF Level At Recall                                              */
/* Purpose:  This function determines the effect of the recall function on   */
/*           the RF level.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFlevelAtRecall (ViSession instrumentHandle,
                                          ViInt32 RFLevelAtRecall)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (RFLevelAtRecall, 0, 1))
        return VI_ERROR_PARAMETER2;

    if (instrPtr->instrType)
    {
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:POW:RCL %s\n", RFLevRecalArr[RFLevelAtRecall]));
    }
    else
    {
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:POW:LEV:IMM:AMPL:RCL %s\n", RFLevRecalArr[RFLevelAtRecall]));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: ALC Configuration                                               */
/* Purpose:  Controls the Automatic Level Control system of the instrument.  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_ALC (ViSession instrumentHandle, ViInt32 alcMode,
                    ViInt32 alcOffMode, ViBoolean learnTable)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar  buffer[BUFFER_SIZE];
    ViUInt32 timeout;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (alcMode, 0, 2))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (alcOffMode, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (learnTable))
        return VI_ERROR_PARAMETER4;

    CHECKERR (viPrintf (instrumentHandle, "\n%s%s%s\n", alcModeArr[alcMode],
                (alcMode == 0) ? alcOffModeArr[alcOffMode] : "",
                (alcMode == 0 && learnTable == VI_TRUE) ? ";:SOUR:POW:ALC:TABL?" : ""));

    if (alcMode == 0 && learnTable == VI_TRUE) {
        /* Readout of the calibration result*/
        /* Timeout is changed to 100 s temporarily*/
        CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, &timeout));
        CHECKERR (viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 100000));
        CHECKERR (viRead (instrumentHandle, buffer, 512, 0));
        CHECKERR (viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, timeout));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: User Correction                                                 */
/* Purpose:  This function generates and activates lists, in which level     */
/* correction values may be assigned to any RF frequencies.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_userCorrection (ViSession instrumentHandle,
                     ViInt32 action,
                     ViString name,
                     ViReal64 _VI_FAR frequencyArray[],
                     ViReal64 _VI_FAR levelArray[],
                     ViInt32 numOfElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViString buffer = VI_NULL;
    ViInt32 i;
    ViString p2data;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 4))
        return VI_ERROR_PARAMETER2;
  if (strlen (name) > 8)
    return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (numOfElements, 0, 160))
        return VI_ERROR_PARAMETER6;

    switch (action) {
        case 0:
        case 1:
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:CORR:STATE %s\n", action ? "ON" : "OFF"));
        break;
        case 2:
        case 4:
            /* Select or delete correction list*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:CORR:CSET:SEL \"%s\"\n",
                              (action == 2) ? "SEL" : "DEL", name));
        break;
        default:
            /* Create correction list*/
            /* Because the size of the command string in this case can be very long*/
            /* and depends on the Freq and Level arrays size, the buffer to hold the */
            /* command string is allocated dynamically. Its length is 83 chars for the */
            /* commands plus number of array elements x ( 17 (freq) + 14 (level can be */
            /* also negative) )minus 2 (commas do not occur at the end of of data blocks.*/
            if ((buffer = malloc (85+34*numOfElements-2)) == 0)
                return VI_ERROR_ALLOC;

            p2data = buffer + sprintf (buffer, "\n:SOUR:CORR:CSET:SEL \"%s\";:SOUR:CORR:CSET:DATA:FREQ ", name);

            for (i=0; i<numOfElements; i++) {
                p2data += sprintf (p2data, "%.9e,", 1.e6*frequencyArray[i]);
            }
      *(--p2data) = 0;


            p2data += sprintf (p2data, ";:SOUR:CORR:CSET:DATA:POW ");

            for (i=0; i<numOfElements; i++) {
                p2data += sprintf (p2data, "%.9e,", levelArray[i]);
            }
      *p2data = 0;
      *(p2data-1) = '\n';

            /* Write allocated long buffer*/
          rssmiq_status = viWrite (instrumentHandle, buffer, p2data - buffer, 0);
      if (buffer) free (buffer);
      CHECKERR (rssmiq_status);
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: LF Output                                                       */
/* Purpose:  This function configures the internal low-frequency generator.  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_LFoutput (ViSession instrumentHandle, ViBoolean lfOutState,
                    ViReal64 frequency, ViReal64 voltage)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (lfOutState))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (frequency, 0.1, 1000000.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (voltage, 0.0, 3.999))
        return VI_ERROR_PARAMETER4;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:LFO %s;:SOUR:LFO:VOLT %fV;:SOUR:LFO:FREQ %fHZ\n",
                          offOnArr[lfOutState], voltage, frequency));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:OUTP2:STAT %s;:OUTP2:VOLT %fV;:SOUR2:FREQ %fHZ\n",
                          offOnArr[lfOutState], voltage, frequency));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Modulation State                                                */
/* Purpose:  This function activates/deactivates all types of modulation.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_modulationState (ViSession instrumentHandle,
                                          ViBoolean state)
{
    ViStatus            rssmiq_status;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
       return VI_ERROR_PARAMETER2;

    return (viPrintf(instrumentHandle, "\n:SOUR:MOD:ALL:STAT %s\n", offOnArr[state]));
}

/*===========================================================================*/
/* Function: Get Peak Envelope Power                                         */
/* Purpose:  This function returns the peak envelope power in dBm.           */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getPeakEnvelopePower (ViSession instrumentHandle,
                                               ViInt32 *peakEnvelopePower)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (!peakEnvelopePower)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:POW:PEP?\n"));
    CHECKERR(viScanf(instrumentHandle, "%ld", peakEnvelopePower));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: BERT                                                      */
/* Purpose:  This function configures BERT parameters of the instrument.   */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_BERT (ViSession instrumentHandle,
                 ViBoolean state,
                 ViBoolean sequence,
                 ViInt32 PRBSLength,
                 ViBoolean dataPolarity,
                 ViBoolean clockPolarity,
                 ViInt32 masking,
                 ViUInt32 count,
                 ViUInt32 errors,
                 ViInt32 restartSource,
                 ViInt32 ignore)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (rssmiq_invalidViBooleanRange (state))
       return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (sequence))
       return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (PRBSLength, 0, 6))
       return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (dataPolarity))
       return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (clockPolarity))
       return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViUInt32Range (count, 1, 4294967295))
       return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViUInt32Range (errors, 1, 4294967295))
       return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (restartSource, 0, 1))
       return VI_ERROR_INSTR_PARAMETER10;

    if (!state)
        CHECKERR (viPrintf (instrumentHandle, "\n:BERT:STAT OFF\n"));
    else
    {
        if (instrPtr->instrType)
        {
            CHECKERR (viPrintf (instrumentHandle, "\n:BERT:SEQ %s"
                              ";:BERT:SET:TYPE %s"
                              ";:BERT:SET:CLOC %s"
                              ";:BERT:SET:DATA %s"
                              ";:BERT:SET:MCO %lu"
                              ";:BERT:SET:MERR %lu"
                              ";:BERT:SET:REST %s"
                              ";:BERT:SET:IGN %s"
                              ";:BERT:STAT ON\n",

                              singAutoArr[sequence],
                              PRBSArr[PRBSLength],
                              BERTClockPolarArr[clockPolarity],
                              BERTDataPolarArr[dataPolarity],
                              count,
                              errors,
                              BERTRestartArr[restartSource],
                              BERTIgnArr[ignore]));
        }
        else
        {
            if (rssmiq_invalidViInt32Range (masking, 0, 2))
               return VI_ERROR_PARAMETER7;

            CHECKERR (viPrintf (instrumentHandle, "\n:BERT:SEQ %s"
                              ";:BERT:SET:TYPE %s"
                              ";:BERT:SET:CLOC %s"
                              ";:BERT:SET:DATA %s"
                              ";:BERT:SET:MASK %s"
                              ";:BERT:SET:MCO %lu"
                              ";:BERT:SET:MERR %lu"
                              ";:BERT:SET:REST %s"
                              ";:BERT:SET:IGN %s"
                              ";:BERT:STAT ON\n",

                              singAutoArr[sequence],
                              PRBSArr[PRBSLength],
                              BERTClockPolarArr[clockPolarity],
                              BERTDataPolarArr[dataPolarity],
                              BERTMaskArr[masking],
                              count,
                              errors,
                              BERTRestartArr[restartSource],
                              BERTIgnArr[ignore]));
        }
    }
  return rssmiq_status;
}

/*===========================================================================*/
/* Function: Set BERT Additional Parameters                                  */
/* Purpose:  This function the BER additional parameters e.g. data enable    */
/*           input and unit.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_setBERTAddParameters (ViSession instrumentHandle,
                                               ViInt32 dataEnableInput,
                                               ViInt32 unit)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Option checking -----------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));

    if (rssmiq_invalidViInt32Range (unit, 0, 3))
        return VI_ERROR_PARAMETER3;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:BERT:UNIT %s\n",
                                                unitArr[unit]));
    }
    else
    {
        if (rssmiq_invalidViInt32Range (dataEnableInput, 0, 2))
            return VI_ERROR_PARAMETER2;

        CHECKERR (viPrintf (instrumentHandle, "\n:BERT:SET:DEN %s;:BERT:UNIT %s\n",
                                                dataEnableArr[dataEnableInput],
                                                unitArr[unit]));
    }
    return rssmiq_status;
}
/*===========================================================================*/
/* Function: BERT Control                                                    */
/* Purpose:  This function starts/stops the bit error rate test.             */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_BERTControl (ViSession instrumentHandle,
                                      ViInt32 BERTTest)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Option checking -----------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));

    if (rssmiq_invalidViInt32Range (BERTTest, 0, 1))
        return VI_ERROR_PARAMETER2;

    if (BERTTest == RSSMIQ_BER_START)
        CHECKERR (viPrintf(instrumentHandle, "\n:BERT:STAR\n"));
    else
        CHECKERR (viPrintf(instrumentHandle, "\n:BERT:STOP\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get BERT Results                                                */
/* Purpose:  This function gets result of the last BER measurement..         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_GetBERTResults (ViSession instrumentHandle, ViPInt32 dataBits,
                               ViPInt32 errorBits, ViPReal64 errorRate,
                               ViPBoolean termStatus, ViPBoolean clockLineStatus,
                               ViPBoolean dataLineStatus, ViPBoolean syncStatus)
{
    ViStatus  rssmiq_status = VI_SUCCESS;

    if (!dataBits) return VI_ERROR_PARAMETER2;
    if (!errorBits) return VI_ERROR_PARAMETER3;
    if (!errorRate) return VI_ERROR_PARAMETER4;
    if (!termStatus) return VI_ERROR_PARAMETER5;
    if (!clockLineStatus) return VI_ERROR_PARAMETER6;
    if (!dataLineStatus) return VI_ERROR_PARAMETER7;
    if (!syncStatus) return VI_ERROR_PARAMETER8;

    CHECKERR (viQueryf (instrumentHandle, "\n:BERT:RES?", "%ld,%ld,%le,%hu,%hu,%hu,%hu\n",
                      dataBits, errorBits, errorRate, termStatus,
                      clockLineStatus, dataLineStatus, syncStatus));

    return rssmiq_status;
}


/*===========================================================================*/
/* Function: Configure BLER                                                  */
/* Purpose:  This function configures the BLER (Block Error Test) system.    */
/*           The option SMIQB21 is reqired                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_configureBLER (ViSession instrumentHandle,
                                        ViBoolean state,
                                        ViInt32 measurementType,
                                        ViUInt32 numberOfDataBlocks,
                                        ViUInt32 numberOfErrors,
                                        ViInt32 dataPolarity,
                                        ViInt32 clockSignalEdge,
                                        ViInt32 dataEnableInput,
                                        ViInt32 unitOfErrorRate)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));
    }

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (measurementType, 0, 1))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViUInt32Range (numberOfDataBlocks, 1, 4294967294))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViUInt32Range (numberOfErrors, 1, 4294967294))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (dataPolarity, 0, 1))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (clockSignalEdge, 0, 1))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (dataEnableInput, 0, 1))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (unitOfErrorRate, 0, 3))
        return VI_ERROR_INSTR_PARAMETER9;


    if (state)
        CHECKERR(viPrintf (instrumentHandle, "\n:BLER:SEQ %s;"
                                               ":BLER:SET:MCO %ld;"
                                               ":BLER:SET:MERR %ld;"
                                               ":BLER:SET:DATA:POL %s;"
                                               ":BLER:SET:CLOC:POL %s;"
                                               ":BLER:SET:DEN %s;"
                                               ":BLER:UNIT %s;"
                                               ":BLER:STAT %s\n",
                                               singAutoArr[measurementType],
                                               numberOfDataBlocks,
                                               numberOfErrors,
                                               BERTDataPolarArr[dataPolarity],
                                               BERTClockPolarArr[clockSignalEdge],
                                               dataEnableArr[dataEnableInput],
                                               unitArr[unitOfErrorRate],
                                               offOnArr[state]));
    else
        CHECKERR (viPrintf (instrumentHandle, "\n:BLER:STAT %s\n", offOnArr[state]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: BLER Control                                                    */
/* Purpose:  This function starts/stops the  block error rate measurement.   */
/*           The option SMIQB21 is required                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_BLERControl (ViSession instrumentHandle,
                                        ViInt32 BLERTest)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));
    }

    if (rssmiq_invalidViInt32Range (BLERTest, 0, 1))
        return VI_ERROR_PARAMETER2;

    if (BLERTest == RSSMIQ_BER_START)
        CHECKERR (viPrintf(instrumentHandle, "\n:BLER:STAR\n"));
    else
        CHECKERR (viPrintf(instrumentHandle, "\n:BLER:STOP\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get BLER Result                                                 */
/* Purpose:  This function result of the last BLER measurement.              */
/*           The option SMIQ21 is required                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getBLERResults (ViSession instrumentHandle,
                                         ViPInt32 dataBlocks,
                                         ViPInt32 errorBlocks,
                                         ViPReal64 errorRate,
                                         ViPBoolean terminationStatus,
                                         ViPBoolean clockLineStatus,
                                         ViPBoolean dataLineStatus,
                                         ViPBoolean syncStatus)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));
    }
    if (!dataBlocks) return VI_ERROR_PARAMETER2;
    if (!errorBlocks) return VI_ERROR_PARAMETER3;
    if (!errorRate) return VI_ERROR_PARAMETER4;
    if (!terminationStatus) return VI_ERROR_PARAMETER5;
    if (!clockLineStatus) return VI_ERROR_PARAMETER6;
    if (!dataLineStatus) return VI_ERROR_PARAMETER7;
    if (!syncStatus) return VI_ERROR_PARAMETER8;

    CHECKERR (viPrintf(instrumentHandle, "\n:BLER:RES?\n"));
    CHECKERR (viScanf(instrumentHandle, "%ld,%ld,%le,%hu,%hu,%hu,%hu",
                     dataBlocks, errorBlocks, errorRate, terminationStatus, clockLineStatus,
                     dataLineStatus, syncStatus));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get BLER Type                                                   */
/* Purpose:  This function gets the type of measurement.                     */
/*           The option SMIQ21 is required                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getBLERType (ViSession instrumentHandle, ViPInt32 type)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B21));
    }

    if (!type) return VI_ERROR_PARAMETER2;
    CHECKERR (viPrintf(instrumentHandle, "\n:BLER:SET:TYPE?\n"));
    CHECKERR (viScanf(instrumentHandle, "%s", buffer));
    CHECKERR (rssmiq_getIndexFromString (instrumentHandle, buffer, retBLERTypeArr, type));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Frequency                                              */
/* Purpose:  This function sets the frequency of the RF output signal.       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFfrequency (ViSession instrumentHandle,
                    ViReal64 freq, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (freq, 0.3, 6400.0))
            return VI_ERROR_PARAMETER2;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FREQ %Lf\n", 1.0e6*freq));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Level                                                  */
/* Purpose:  This function sets the level of the RF output signal.           */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFlevel (ViSession instrumentHandle,
                    ViReal64 level, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (level, -144.0, 16.0))
            return VI_ERROR_PARAMETER2;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:POW %le\n", level));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Level Offset                                           */
/* Purpose:  This function sets the level offset of the RF output signal.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFlevOffset (ViSession instrumentHandle,
                    ViReal64 offset, ViBoolean checkRange)

{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (offset, -100.0, 100.0))
            return VI_ERROR_PARAMETER2;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:POW:OFFS %le\n", offset));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Start Stop Frequency                                   */
/* Purpose:  This function sets the start and stop frequencies of the RF     */
/*           sweep.                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFstartStopFreq (ViSession instrumentHandle,
                    ViReal64 startFreq, ViReal64 stopFreq, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (startFreq, 0.3, 6400.0))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (stopFreq, 0.3, 6400.0))
            return VI_ERROR_PARAMETER3;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FREQ:STAR %Lf;STOP %Lf\n", 1.0e6*startFreq, 1.0e6*stopFreq));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Center Span Frequency                                  */
/* Purpose:  This function sets the center and span frequencies of the RF    */
/*           sweep.                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFcenterSpanFreq (ViSession instrumentHandle,
                    ViReal64 centerFreq, ViReal64 spanFreq, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (centerFreq, 0.3, 6400.0))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (spanFreq, 0.3, 6400.0))
            return VI_ERROR_PARAMETER3;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FREQ:CENT %Lf;SPAN %Lf\n", 1.0e6*centerFreq, 1.0e6*spanFreq));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick RF Sweep Step                                             */
/* Purpose:  This function sets the RF sweep step in MHz.                    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qRFsweepStep (ViSession instrumentHandle,
                    ViReal64 step, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        if (rssmiq_invalidViReal64Range (step, 0.0, 1000.0))
            return VI_ERROR_PARAMETER2;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:SWE:STEP %le\n", 1.0e6*step));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick LF Frequency                                              */
/* Purpose:  This function sets the LF output frequency.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qLFfreq (ViSession instrumentHandle,
                    ViReal64 freq, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (checkRange)
    {
        if (rssmiq_invalidViReal64Range (freq, 0.1, 1000000.0))
            return VI_ERROR_PARAMETER3;
    }

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:LFO:FREQ %LfHZ\n", freq));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR2:FREQ %Lf\n", freq));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick LF Voltage                                                */
/* Purpose:  This function sets the LF output voltage.                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qLFvolt (ViSession instrumentHandle, ViReal64 volt,
                    ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (checkRange)
    {
        if (rssmiq_invalidViReal64Range (volt, 0.0, 3.999))
            return VI_ERROR_PARAMETER2;
    }

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:LFO:VOLT %Lf\n", volt));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:OUTP2:VOLT %le\n", volt));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick AM Modulation Depth                                       */
/* Purpose:  This function sets the AM modulation depth.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qAMmodDep (ViSession instrumentHandle,
                    ViReal64 modDepth, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if (checkRange) {
        /*- Check input parameter ranges ------------------------------------*/
        if (rssmiq_invalidViReal64Range (modDepth, 0.0, 100.0))
            return VI_ERROR_PARAMETER2;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:AM:DEPT %le\n", modDepth));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick FM Deviation                                              */
/* Purpose:  This function sets the FM Deviation.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qFMdev (ViSession instrumentHandle, ViBoolean modulator,
                    ViReal64 freqDev, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (checkRange) {
        if (rssmiq_invalidViBooleanRange (modulator))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (freqDev, 0.0, 1000000.0))
            return VI_ERROR_PARAMETER3;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FM%s:DEV %le\n", oneOrTwo[modulator], freqDev));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Quick Phase Mod Deviation                                       */
/* Purpose:  This function sets the PHM Deviation.                           */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_qPHMdev (ViSession instrumentHandle, ViBoolean modulator,
                    ViReal64 phaseDev, ViBoolean checkRange)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (checkRange) {
        if (rssmiq_invalidViBooleanRange (modulator))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (phaseDev, 0.0, 20.0))
            return VI_ERROR_PARAMETER3;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:PM%s:DEV %le\n", oneOrTwo[modulator], phaseDev));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Amplitude Modulation                                            */
/* Purpose:  This function configures the amplitude modulation. The different*/
/*           modulation modes disable each other.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_AM (ViSession instrumentHandle, ViBoolean state, ViReal64 modDepth,
                    ViInt32 source, ViReal64 intFreq, ViInt32 extCoup)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (modDepth, 0.0, 100.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (intFreq, 0.1, 1000000.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (extCoup, 0, 1))
        return VI_ERROR_PARAMETER6;

    p2data = buffer + sprintf (buffer, "\n:SOUR:AM:DEPT %lePCT;:SOUR:AM:SOUR %s",
                                       modDepth,
                                       instrPtr->instrType ? smu_intextArr[source] : int1extArr[source]);

    switch (source){
        case 0:
            /* Internal modulation source*/
             p2data += sprintf (p2data, ";:SOUR:AM:INT:FREQ %LfHz", intFreq);
             break;
        case 1:
            /* External modulation source*/
            p2data += sprintf (p2data, ";:SOUR:AM:EXT:COUP %s", acDcArr[extCoup]);
            break;
        case 2:
            /*Both modulation source*/
            p2data += sprintf (p2data, ";:SOUR:AM:INT:FREQ %LfHz", intFreq);
            p2data += sprintf (p2data, ";:SOUR:AM:EXT:COUP %s", acDcArr[extCoup]);
            break;
    }
    p2data += sprintf (p2data, ";:SOUR:AM:STAT %s\n", offOnArr[state]);

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Pulse Modulation                                                */
/* Purpose:  This function configures and enables pulse modulation of the    */
/*           instrument's RF output.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_PULM (ViSession instrumentHandle, ViBoolean state,
                ViBoolean polarity)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (polarity))
        return VI_ERROR_PARAMETER3;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:PULM:POL %s;:SOUR:PULM:STAT %s%s\n",
                      normInvArr[polarity], offOnArr[state],
                      state ? ";:SOUR:PULM:SOUR EXT" : ""));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Broadband Amplitude Modulation                                  */
/* Purpose:  This function enables/disables the broadband amplitude          */
/*           modulation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_BBAM (ViSession instrumentHandle, ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:AM:BBAND:STAT %s\n", offOnArr[state]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Frequency Modulation                                            */
/* Purpose:  This function configures and enables frequency modulation of the*/
/*           instrument's RF output. Frequency modulation is available only  */
/*           on the instrument equipped with the option SM-B5.               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_FM (ViSession instrumentHandle, ViBoolean state,
                    ViBoolean modulator, ViReal64 freqDev, ViInt32 preemphasis,
                    ViInt32 source, ViReal64 intFreq, ViBoolean extCoup)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (modulator))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (freqDev, 0.0, 1000000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (preemphasis, 0, 2))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (intFreq, 0.1, 1000000.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (extCoup))
        return VI_ERROR_PARAMETER8;

    p2data = buffer + sprintf (buffer, "\n:SOUR:FM%hd:STAT %s;SOUR %s;DEV %fHz;PRE %s",
                      modulator+1, offOnArr[state], intExt12Arr[source],
                      freqDev, preEmpArr[preemphasis]);
    if (source) {
        /* External modulation signal source*/
        p2data += sprintf (p2data, ";EXT%ld:COUP %s\n", source, acDcArr[extCoup]);
    }
    else {
        /* Internal modulation signal source*/
        p2data += sprintf (p2data, ";INT:FREQ %fHz\n", intFreq);
    }

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Phase Modulation                                                */
/* Purpose:  This function configures and enables phase modulation of the    */
/*           instrument's RF output. Phase modulation is available only on   */
/*           the instrument equipped with the option SM-B5.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_PHM (ViSession instrumentHandle, ViBoolean state,
                    ViBoolean modulator, ViReal64 phaseDev, ViInt32 source,
                    ViReal64 intFreq, ViBoolean extCoup)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (modulator))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (phaseDev, 0.0, 20.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (intFreq, 0.1, 1000000.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (extCoup))
        return VI_ERROR_PARAMETER7;

    p2data = buffer + sprintf (buffer, "\n:SOUR:PM%hd:STAT %s;SOUR %s;DEV %le",
                      modulator+1, offOnArr[state], intExt12Arr[source],
                      phaseDev);
    if (source) {
        /* External modulation signal source*/
        p2data += sprintf (p2data, ";EXT%ld:COUP %s\n", source, acDcArr[extCoup]);
    }
    else {
        /* Internal modulation signal source */
        p2data += sprintf (p2data, ";INT:FREQ %fHz\n", intFreq);
    }

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Sweep                                                        */
/* Purpose:  This function configures and enables frequency sweep of the     */
/*           instrument's RF output.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFsweep (ViSession instrumentHandle, ViBoolean mode,
                    ViReal64 startCenterF, ViReal64 stopSpanF,
                    ViBoolean spacing, ViReal64 stepWidth, ViReal64 dwellTime)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (mode))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (startCenterF, 0.3, 6400.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (stopSpanF, 0.3, 6400.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (spacing))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (stepWidth, 0.0, 1000.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (dwellTime, 1.0, 5000.0))
        return VI_ERROR_PARAMETER7;

    if (mode) {
        /* Sweep range is specified by means of start and stop frequencies*/
        p2data = buffer + sprintf (buffer, "\n:SOUR:FREQ:STAR %fMHZ;:SOUR:FREQ:STOP %fMHZ",
                          startCenterF, stopSpanF);
    }
    else {
        /* Sweep range is specified by means of center frequency and freq span*/
        p2data = buffer + sprintf (buffer, "\n:SOUR:FREQ:CENT %fMHZ;:SOUR:FREQ:SPAN %fMHZ",
                          startCenterF, stopSpanF);
    }
    p2data += sprintf (p2data, ";:SOUR:SWE:DWEL %fMS;:SOUR:SWE:SPAC %s;:SOUR:SWE:STEP:%s %f%s\n",
                    dwellTime, linLogArr[spacing], linLogArr[spacing], stepWidth,
                    (!spacing) ? "MHZ":"");

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Sweep Markers                                                */
/* Purpose:  This function configures and enables frequency sweep markers.   */
/*           A sweep marker output becomes active when the sweep run has     */
/*           reached the frequency of the marker. Up to three markers can be */
/*           configured.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFsweepMarkers (ViSession instrumentHandle, ViReal64 m1Freq,
                    ViBoolean m1State, ViBoolean m1Ampl, ViReal64 m2Freq,
                    ViBoolean m2State, ViBoolean m2Ampl, ViReal64 m3Freq,
                    ViBoolean m3State, ViBoolean m3Ampl, ViReal64 m4Freq,
                    ViBoolean m4State, ViBoolean m4Ampl)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (m1Freq, 0.3, 6400.0))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (m1State))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (m1Ampl))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (m2Freq, 0.3, 6400.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (m2State))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (m2Ampl))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (m3Freq, 0.3, 6400.0))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViBooleanRange (m3State))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (m3Ampl))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViReal64Range (m4Freq, 0.3, 6400.0))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViBooleanRange (m4State))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViBooleanRange (m4Ampl))
        return VI_ERROR_INSTR_PARAMETER13;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:MARK1:AMPL %s;:SOUR:MARK1:FREQ %fMHZ;:SOUR:MARK1:STAT %s"
                     ";:SOUR:MARK2:AMPL %s;:SOUR:MARK2:FREQ %fMHZ;:SOUR:MARK2:STAT %s"
                     ";:SOUR:MARK3:AMPL %s;:SOUR:MARK3:FREQ %fMHZ;:SOUR:MARK3:STAT %s"
                     ";:SOUR:MARK4:AMPL %s;:SOUR:MARK4:FREQ %fMHZ;:SOUR:MARK4:STAT %s\n",
                     offOnArr[m1Ampl], m1Freq, offOnArr[m1State],
                     offOnArr[m2Ampl], m2Freq, offOnArr[m2State],
                     offOnArr[m3Ampl], m3Freq, offOnArr[m3State],
                     offOnArr[m4Ampl], m4Freq, offOnArr[m4State]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Level Sweep                                                  */
/* Purpose:  This function configures and enables a level sweep of the       */
/*           instrument's RF output.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFlevelSweep (ViSession instrumentHandle, ViReal64 startLev,
                    ViReal64 stopLev, ViInt32 levelUnit, ViReal64 stepWidth,
                    ViReal64 dwellTime)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (levelUnit == 0) {
        /* Checking level range only for level unit = dBm*/
        if (rssmiq_invalidViReal64Range (startLev, -144.0, 16.0))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (stopLev, -144.0, 16.0))
            return VI_ERROR_PARAMETER3;
    }
    if (rssmiq_invalidViInt32Range (levelUnit, 0, 7))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (stepWidth, 0.0, 160.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (dwellTime, 1.0, 5000.0))
        return VI_ERROR_PARAMETER6;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:POW:START %f%s;:SOUR:POW:STOP %f%s;:SOUR:SWE:POW:"
                        "STEP:LOG %fDB;:SOUR:SWE:POW:DWEL %fMS\n", startLev,
                        levUnitSweArr[levelUnit], stopLev, levUnitSweArr[levelUnit],
                        stepWidth, dwellTime));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Level Sweep Markers                                          */
/* Purpose:  This function configures and enables level sweep markers.       */
/*           A sweep marker output becomes active when the sweep run has     */
/*           reached the level of the marker. Up to three markers can be     */
/*           configured.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_RFlevelSweepMarkers (ViSession instrumentHandle,
                                              ViReal64 m1Level,
                                              ViBoolean m1State,
                                              ViReal64 m2Level,
                                              ViBoolean m2State,
                                              ViReal64 m3Level,
                                              ViBoolean m3State,
                                              ViReal64 m4Level,
                                              ViBoolean m4State,
                                              ViInt32 levelUnit)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (levelUnit == 0) {
        /* Checking level range only for level unit = dBm*/
        if (rssmiq_invalidViReal64Range (m1Level, -144.0, 16.0))
            return VI_ERROR_PARAMETER2;
    }
    if (rssmiq_invalidViBooleanRange (m1State))
        return VI_ERROR_PARAMETER3;

    if (levelUnit == 0) {
        /* Checking level range only for level unit = dBm*/
        if (rssmiq_invalidViReal64Range (m2Level, -144.0, 16.0))
            return VI_ERROR_PARAMETER4;
    }
    if (rssmiq_invalidViBooleanRange (m2State))
        return VI_ERROR_PARAMETER5;

    if (levelUnit == 0) {
        /* Checking level range only for level unit = dBm*/
        if (rssmiq_invalidViReal64Range (m3Level, -144.0, 16.0))
            return VI_ERROR_PARAMETER6;
    }
    if (rssmiq_invalidViBooleanRange (m3State))
        return VI_ERROR_PARAMETER7;

    if (levelUnit == 0) {
        /* Checking level range only for level unit = dBm*/
        if (rssmiq_invalidViReal64Range (m4Level, -144.0, 16.0))
            return VI_ERROR_PARAMETER8;
    }
    if (rssmiq_invalidViBooleanRange (m3State))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (levelUnit, 0, 7))
        return VI_ERROR_INSTR_PARAMETER10;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:MARK1:PSW:POW %f%s;:SOUR:MARK1:PSW:STAT %s"
                      ";:SOUR:MARK2:PSW:POW %f%s;:SOUR:MARK2:PSW:STAT %s"
                      ";:SOUR:MARK3:PSW:POW %f%s;:SOUR:MARK3:PSW:STAT %s"
                      ";:SOUR:MARK4:PSW:POW %f%s;:SOUR:MARK4:PSW:STAT %s\n",
                      m1Level, levUnitSweArr[levelUnit], offOnArr[m1State],
                      m2Level, levUnitSweArr[levelUnit], offOnArr[m2State],
                      m3Level, levUnitSweArr[levelUnit], offOnArr[m3State],
                      m4Level, levUnitSweArr[levelUnit], offOnArr[m4State]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: LF Sweep                                                        */
/* Purpose:  This function configures and enables Low-Frequency sweep of the */
/*           instrument.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_LFsweep (ViSession instrumentHandle, ViReal64 startFreq,
                    ViReal64 stopFreq, ViBoolean spacing, ViReal64 stepWidth,
                    ViReal64 dwellTime)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (startFreq, 0.0001, 1000.0))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (stopFreq, 0.0001, 1000.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (dwellTime, 1.0, 5000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (spacing))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (stepWidth, 0.01, 1000.0))
        return VI_ERROR_PARAMETER6;

    if (!spacing) {
        /* In linear spacing mode, the stepWidth must be converted from MHz to Hz*/
        stepWidth *= 1.0e3;
    }

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR2:FREQ:START %fKHZ"
                      ";:SOUR2:FREQ:STOP %fKHZ"
                      ";:SOUR2:SWE:DWEL %fMS"
                      ";:SOUR2:SWE:SPAC %s"
                      ";:SOUR2:SWE:STEP:%s"
                      " %le\n",

                      startFreq,
                      stopFreq,
                      dwellTime,
                      linLogArr[spacing],
                      linLogArr[spacing],
                      stepWidth));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: LF Sweep Markers                                                */
/* Purpose:  This function configures and enables Low-Frequency sweep        */
/*           markers. A sweep marker output becomes active when the sweep run*/
/*           has reached the frequency of the marker. Up to three markers can*/
/*           be configured.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_LFsweepMarkers (ViSession instrumentHandle, ViReal64 m1Freq,
                    ViBoolean m1State, ViReal64 m2Freq, ViBoolean m2State,
                    ViReal64 m3Freq, ViBoolean m3State, ViReal64 m4Freq, ViBoolean m4State)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (m1Freq, 0.1, 1000.0))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (m1State))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (m2Freq, 0.1, 1000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (m2State))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (m3Freq, 0.1, 1000.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (m3State))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (m4Freq, 0.1, 1000.0))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViBooleanRange (m4State))
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR2:MARK1:FREQ %fKHZ;:SOUR2:MARK1:STAT %s"
                     ";:SOUR2:MARK2:FREQ %fKHZ;:SOUR2:MARK2:STAT %s"
                     ";:SOUR2:MARK3:FREQ %fKHZ;:SOUR2:MARK3:STAT %s"
                     ";:SOUR2:MARK4:FREQ %fKHZ;:SOUR2:MARK4:STAT %s\n",
                     m1Freq, offOnArr[m1State],
                     m2Freq, offOnArr[m2State],
                     m3Freq, offOnArr[m3State],
                     m4Freq, offOnArr[m4State]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: LF Sweep Marker Polarity                                        */
/* Purpose:  This function switches all selected markers off.                */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_LFsweepMarkerPolarity (ViSession instrumentHandle,
                                                ViInt32 marker, ViInt32 polarity)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (marker, 1, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (polarity, 0, 1))
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR2:MARK%ld:POL %s\n", marker, normInvArr[polarity]));

    return rssmiq_status;


}

/*===========================================================================*/
/* Function: Switch All MArkers Off                                          */
/* Purpose:  This function switches all selected markers off.                */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_switchAllMarkersOff (ViSession instrumentHandle,
                                              ViInt32 source, ViInt32 markers)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (source, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (markers, 0, 1))
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:%s:MARK:%s:AOFF\n", sourceArr[source], sweepArr[markers]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Freq&Level List                                                 */
/* Purpose:  This function works with Freq & Level Lists. You can create list*/
/*           from Frequency and Level arrays passed to this function as well */
/*           as from spreadsheet file. You can also delete lists with this   */
/*           function.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_freqAndLevList (ViSession instrumentHandle, ViInt32 action,
                    ViString name, ViReal64 dwellTime, ViReal64 _VI_FAR freqArray[],
                    ViReal64 _VI_FAR levelArray[], ViInt32 numOfElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViUInt32 retCnt = 0;
    ViByte line[BUFFER_SIZE];
    ViString buffer = VI_NULL;
    ViChar listName[256];
    FILE *fh = NULL;
    ViPReal64 tmpFreq = VI_NULL;
    ViPReal64 tmpLev = VI_NULL;
    ViInt32 size;
    ViReal64 tmpDwell;
    ViString  p2data;
    ViInt32   byteCnt;
    ViString  p2name;
    ViInt32 block = 8000;
    ViUInt16    interface_type = VI_INTF_GPIB;
    rssmiq_instrRange   instrPtr;
    ViUInt16  oldEndChar = VI_ASRL_END_NONE;
    ViBoolean oldTermChar = VI_FALSE;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (dwellTime, 0.1, 5000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (numOfElements, 0, 100000))
        return VI_ERROR_PARAMETER7;

  tmpFreq = freqArray;
  tmpLev = levelArray;
  strcpy (listName, name);

    switch (action) {
        case 0:
            /* Select list*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FREQ:MODE CW;:SOUR:LIST:SEL \"%s\";"
                                ":SOUR:LIST:LEAR;*WAI\n", name));
        break;
        case 2:
            /* Create list from file*/
            /* List name to be created in the instrument is same as the filename*/
            /* Extension is cut off, max length is 7 chars*/
      p2name = strrchr (name, '\\');
      strcpy (listName, p2name ? 1+p2name : name);
      if (strchr (listName, '.')) (*strchr (listName, '.')) = 0;
      if (strlen (listName) > 7) listName[7] = 0;

            /* Allocate memory for storing freq and level values*/
            size = block;
            if ((tmpFreq = malloc (size)) == 0)
                return VI_ERROR_ALLOC;
            if ((tmpLev = malloc (size)) == 0) {
              rssmiq_status = VI_ERROR_ALLOC;
              goto Error;
            }

            /* Reading the file ===============================================*/
            if ((fh = fopen (name, "r")) == VI_NULL) {
              rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
              goto Error;
            }

            numOfElements = 0;
            while (fgets (line, BUFFER_SIZE, fh)) {
                /* If number of elements is greater than currently allocated*/
                /* temporary buffers, reallocate*/
                if (numOfElements > size/8) {
                    size += block;
                    if ((tmpFreq = realloc (tmpFreq, size)) == 0) {
                      rssmiq_status = VI_ERROR_ALLOC;
                            goto Error;
                    }
                    if ((tmpLev = realloc (tmpLev, size)) == 0) {
                        rssmiq_status = VI_ERROR_ALLOC;
                        goto Error;
          }
                }
                retCnt = sscanf (line, "%le\t%le\t%le", &tmpFreq[numOfElements],
                                     &tmpLev[numOfElements],
                                     &tmpDwell);

                if (numOfElements == 0 && retCnt == 3) {
                    /* First data row contains dwell value*/
                    dwellTime = tmpDwell;
                }
                if (retCnt >= 2) {
                    numOfElements++;
                }
            }
            if (errno) {
                rssmiq_status = VI_ERROR_INSTR_FILE_READ;
                goto Error;
            }
            fclose (fh);
            fh = VI_NULL;
        case 1:
            /* Create list from buffers*/
            byteCnt = 8*numOfElements;
            if ((buffer = malloc (170+2*byteCnt)) == 0)
                return VI_ERROR_ALLOC;

      byteCnt = 8*numOfElements;

      sprintf (line, "%ld", byteCnt);

            p2data = buffer + sprintf (buffer, "\n:SOUR:FREQ:MODE CW;:SOUR:LIST:SEL \"%s\";"
                                 ":FORM:DATA %s;BORD NORM", listName, instrPtr->instrType ? "PACK" : "REAL64");

            p2data += sprintf (p2data, ";:SOUR:LIST:FREQ #%ld%ld", strlen (line), byteCnt);
            memcpy (p2data, tmpFreq, byteCnt);
            p2data += byteCnt;

            p2data += sprintf (p2data, ";:SOUR:LIST:POW #%ld%ld", strlen (line), byteCnt);
            memcpy (p2data, tmpLev, byteCnt);
            p2data += byteCnt;

            p2data += sprintf (p2data, ";:SOUR:LIST:DWEL %.3f;:SOUR:LIST:LEAR;*WAI\n", dwellTime/1000.0);

            if (interface_type == VI_INTF_ASRL)
                {
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar));
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar));
                }
            else
                CHECKERR(viPrintf(instrumentHandle,"\n:SYST:COMM:GPIB:LTER EOI\n"));

            if ((rssmiq_status = viWrite (instrumentHandle, buffer, p2data - buffer, 0)) < 0)
                goto Error;

            if (interface_type == VI_INTF_ASRL)
                {
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar));
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar));
                }
            else
                CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER STAN"));
        break;
        case 3:
            /* Delete list*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:LIST:DEL \"%s\"\n", name));
        break;
        case 4:
            /* Delete all lists*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:FREQ:MODE CW;:SOUR:LIST:DEL:ALL\n"));
        break;
    }

Error:
  if (fh) fclose (fh);
  if (buffer) free (buffer);
  if (tmpFreq != 0 && tmpFreq != freqArray) free (tmpFreq);
  if (tmpLev != 0 && tmpLev != levelArray) free (tmpLev);
  return rssmiq_status;
}

/*===========================================================================*/
/* Function: Memory Sequence                                                 */
/* Purpose:  This function manipulates the memory sequences. You can select  */
/*           an existing sequence as well as create a new sequence. You can  */
/*           also delete one or all sequences with this function.            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_memSequence (ViSession instrumentHandle, ViInt32 action,
                              ViString name, ViInt32 _VI_FAR setupArray[],
                              ViReal64 _VI_FAR dwellArray[], ViInt32 numOfElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViString buffer = VI_NULL,
         p2data;
    ViInt32 i;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (numOfElements, 0, 256))
        return VI_ERROR_PARAMETER6;

    switch (action) {
        case 0:
        case 2:
            /* Select memory sequence*/
            CHECKERR (viPrintf ( instrumentHandle, "\n:SYST:MSEQ:%s \"%s\"\n",
                              (action == 0) ? "SEL" : "DEL", name));
        break;
        case 3:
            /* Delete all memory sequences*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SYST:MSEQ:DEL:ALL\n"));
        break;
        default:
            /* Create memory sequence*/
            /* Because the size of the command string in this case can be very long*/
            /* and depends on the Freq and Level arrays size, the buffer to hold the command*/
            /* string is allocated dynamically. Its length is 59 chars for the commands*/
            /* plus number of array elements x ( 3 (setup num) + 7 (dwell time) )*/
            /* minus 2 (commas do not occur at the end of of data blocks.*/

            if ((buffer = malloc (57+10*numOfElements)) == 0)
                return VI_ERROR_ALLOC;

            p2data = buffer + sprintf (buffer, "\n:SYST:MSEQ:SEL \"%s\";:SYST:MSEQ:RCL ", name);

      for (i=0; i<numOfElements; i++) {
        p2data += sprintf (p2data, "%ld,", setupArray[i]);
      }
      *(--p2data) = 0;

            p2data += sprintf (p2data, ";:SYST:MSEQ:DWEL ");

      for (i=0; i<numOfElements; i++) {
        p2data += sprintf (p2data, "%.3f,", dwellArray[i]);
      }
      *(p2data-1) = '\n';
      *p2data = 0;

          if ((rssmiq_status = viWrite (instrumentHandle, buffer, p2data - buffer, 0)) < 0)
            goto Error;
        break;
    }
Error:
  if (buffer) free (buffer);
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Config List&SweepTrigger                                        */
/* Purpose:  This function configures the triggering mode of the following   */
/*           instrument functions: Frequency Sweep, Level Sweep, LF Sweep,   */
/*           Frequency & Level List and Memory Sequence.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_cfgLstSweTrig (ViSession instrumentHandle, ViInt32 function,
                    ViInt32 triggerMode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (function, 0, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (triggerMode, 0, 6))
        return VI_ERROR_PARAMETER3;

    CHECKERR (viPrintf (instrumentHandle, "\n%s\n", lstTrgModeArr[7*function+triggerMode]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Catalog List                                                */
/* Purpose:  This function returns a list of selected type.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getCatalogList (ViSession instrumentHandle,
                                         ViInt32 typeOfList, ViInt32 size,
                                         ViChar dataList[], ViInt32 *length)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 num_of_chars = size;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViInt32Range (typeOfList, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (!dataList)
        return VI_ERROR_PARAMETER4;


    switch (typeOfList){
        case RSSMIQ_LISTS_GPS:
            CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:GPS:DLIS:CAT?\n"));
            break;
        case RSSMIQ_LISTS_DMFILTER:
            CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:CAT?\n"));
            break;
    }
    CHECKERR(viScanf(instrumentHandle, "%#s", &num_of_chars, dataList));
    if (length)
        *length = strlen(dataList);

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Vector Modulation                                               */
/* Purpose:  This function controls the overall I/Q modulator settings.      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_vectModulation (ViSession instrumentHandle, ViBoolean state,
                     ViBoolean powerRamp)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (powerRamp))
        return VI_ERROR_PARAMETER3;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR1:IQ:STAT %s\n",
                            offOnArr[state]));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:IQ:STAT %s"
                          ";:SOUR:DM:IQ:PRAM %s\n",

                            offOnArr[state],
                            offAExtArr[powerRamp]));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: IQ Modulation Impairment                                        */
/* Purpose:  This function controls the global I/Q impairment settings       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_IQModImp (ViSession instrumentHandle, ViBoolean impairmentState,
                   ViBoolean iqSwap, ViReal64 leakage,
                   ViReal64 imbalance, ViReal64 quadOffset)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/

    if (rssmiq_invalidViBooleanRange (impairmentState))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (iqSwap))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (leakage, 0.0, 50.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (imbalance, -12.0, 12.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (quadOffset, -10.0, 10.0))
        return VI_ERROR_PARAMETER6;


    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR1:IQ:IMP %s"
                            ";:SOUR1:IQ:IMP:LEAK:I %fPCT"
                            ";:SOUR1:IQ:IMP:LEAK:Q %fPCT"
                            ";:SOUR1:IQ:IMP:IQR %fPCT"
                            ";:SOUR1:IQ:IMP:QUAD %fDEG"
                            ";:SOUR1:IQ:SWAP %s\n",

                            offOnArr[impairmentState],
                            leakage,
                            leakage,
                            imbalance,
                            quadOffset,
                            offOnArr[iqSwap]));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:IQ:IMP:STAT %s"
                            ";:SOUR:DM:LEAK %fPCT"
                            ";:SOUR:DM:IQR %fPCT"
                            ";:SOUR:DM:QUAD:ANGL %fDEG"
                            ";:SOUR:DM:IQSW:STAT %s\n",

                            offOnArr[impairmentState],
                            leakage,
                            imbalance,
                            quadOffset,
                            offOnArr[iqSwap]));
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: IQ Modulation Low ACP Filter                                    */
/* Purpose:  This function controls the Low Adjacent Channel Power Filter    */
/*       settings.                                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_IQModLowACP (ViSession instrumentHandle, ViInt32 filterMode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViString ffreqCmd[] = {"", ";FREQ 850KHZ", ";FREQ 2.5MHZ", ";FREQ 5MHZ", ";FREQ 7.5MHZ", ";FREQ 10MHZ"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Option checking -----------------------------------------------------*/
    if ((rssmiq_status = rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B47))) < VI_SUCCESS)
        CHECKERR(rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B46)));


    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (filterMode, 0, 5))
        return VI_ERROR_PARAMETER2;

    /*The frequency 7.5MHz and 10MHz are available only for option SMIQB57*/
    if (filterMode > 3)
        CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B57));

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:IQ:FILT:STAT %s\n"
                        "%s",

                        (filterMode != 0) ? "ON" : "OFF",
                        ffreqCmd[filterMode]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: IQ Modulation Parameters                                        */
/* Purpose:  This function configures IQ modulation parameters.              */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_IQModParameters (ViSession instrumentHandle,
                                          ViReal64 crestFactor,
                                          ViInt32 transitionState)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
    {
        /*- Check input parameter ranges ----------------------------------------*/
        if (rssmiq_invalidViInt32Range (crestFactor, 0, 30))
            return VI_ERROR_PARAMETER2;

        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:IQ:CRES %f\n",
                          crestFactor));
    }
    else
    {
        /*- Option checking -----------------------------------------------------*/
        if ((rssmiq_status = rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B47))) < VI_SUCCESS)
            CHECKERR(rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B46)));

        /*- Check input parameter ranges ----------------------------------------*/
        if (rssmiq_invalidViInt32Range (crestFactor, 0, 30))
            return VI_ERROR_PARAMETER2;
        if (rssmiq_invalidViReal64Range (transitionState, 0, 1))
            return VI_ERROR_PARAMETER3;

        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:IQ:CRES %f;:SOUR:DM:IQ:TRAN %s\n",
                          crestFactor, iqTransitionArr[transitionState]));
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Set High Dynamic                                                */
/* Purpose:  This function turns On/OFF the spectral measurements with high  */
/*           dynamic.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_DmSetHighDynamic (ViSession instrumentHandle,
                                           ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Option checking -----------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B57)));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:IQ:HACL:STAT %s\n", offOnArr[state]));

    return rssmiq_status;

}

/*===========================================================================*/
/* Function: Digital Modulation                                              */
/* Purpose:  This function controls the digital modulation settings found on */
/*           the instrument in the menu DIGITAL MOD.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModulation (ViSession instrumentHandle, ViBoolean state,
                    ViInt32 source, ViInt32 standard, ViInt32 modulation,
                    ViReal64 fskDeviation, ViInt32 coding, ViReal64 symbolRate,
                    ViBoolean rateMode, ViInt32 filter, ViReal64 filterConst,
                    ViBoolean filterMode, ViBoolean lowDistortion)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViChar bb_string [4];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    strcpy (bb_string, instrPtr->instrType ? "BB:" : "");

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (source, 0, 12))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (standard, 0, 23))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (modulation, 0, 23))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (fskDeviation, 0.1, 2500.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (coding, 0, 14))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (symbolRate, 1.0, 7000.0))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViBooleanRange (rateMode))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (filter, 0, 13))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViReal64Range (filterConst, 0.1, 1.0))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViBooleanRange (lowDistortion))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, ";:SOUR:%sDM:STATE %s;:SOUR:%sDM:SOUR %s",
                    bb_string, offOnArr[state], bb_string, dmSourArr[source]);

    if (standard == 0) {
        /* User defined modulation scheme*/
        if (modulation) {
            p2data += sprintf (p2data, ";:SOUR:%sDM:FORM %s", bb_string, dmModArr[modulation]);
        }
        if (modulation >=12 && modulation < 16) {
            p2data += sprintf (p2data, ";:SOUR:%sDM:FSK:DEV %le", bb_string, 1000.0*fskDeviation);
        }
        if (rateMode) {
            p2data += sprintf (p2data, ";:SOUR:%sDM:SRAT %le", bb_string, 1000.0*symbolRate);
        }
        if (coding) {
            p2data += sprintf (p2data, ";:SOUR:%sDM:COD %s", bb_string, dmCodArr[coding]);
        }
        if (filter) {
            p2data += sprintf (p2data, ";:SOURCE:%sDM:FILT:TYPE %s;:SOUR:%sDM:FILT:PAR %le;"
                            ":SOUR:%sDM:FILT:MODE %s",
                            bb_string, dmFltArr[filter], bb_string, filterConst,
                            bb_string, fltModeArr[filterMode]);
        }
        p2data += sprintf (p2data, ";:SOUR:%sDM:LDIS %s", bb_string, offOnArr[lowDistortion]);
    } else {
/*    p2data = buffer + sprintf (buffer, ";:SOUR:DM:STAN %s", dmStdArr[standard]); */
      p2data += sprintf (p2data, ";:SOUR:%sDM:STAN %s", bb_string, dmStdArr[standard]);
    }

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Modulation Lists                                        */
/* Purpose:  This function manipulates the digital modulation data lists.    */
/*           The list contains data bits. The lists can be creaded only if   */
/*           the instrument is equipped with Data Generator option SMIQ-B11. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModLists (ViSession instrumentHandle, ViInt32 action,
                    ViString name, ViBoolean type, ViString data,
                    ViInt32 numOfBytes, ViBoolean controlList)
{
    ViStatus    rssmiq_status = VI_SUCCESS;
    ViChar      *buffer = VI_NULL;
    ViUInt32    *tmpData = VI_NULL;
    ViUInt32    tmpVal1, tmpVal2;
    ViUInt32    i;
    FILE        *fh = VI_NULL;
    ViChar      listName[256];
    ViChar      bb_string[4];
    ViUInt32    size;
    ViString    p2data,
                p2name;
    ViChar      str[10];
    ViUInt16    interface_type = VI_INTF_GPIB;
    rssmiq_instrRange   instrPtr;
    ViUInt16    oldEndChar = VI_ASRL_END_NONE;
    ViBoolean   oldTermChar = VI_FALSE;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    strcpy (bb_string, instrPtr->instrType ? "BB:" : "");

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (type))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (numOfBytes, 0, 250000))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (controlList))
        return VI_ERROR_PARAMETER7;

    strcpy (listName, name);

    switch (action) {
        case 0:
            /* Select list*/
            if (type) {
                /* Selecting a control list*/
                if (instrPtr->instrType)
                {
                    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:BB:DM:CLIST:SEL \"%s\"\n",
                                     name));
                }
                else
                {
                    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:CLIST:SEL \"%s\";:SOUR:DM:CLIST:CONT %s\n",
                                     name, offOnArr[controlList]));
                }
            } else {
                CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:%sDM:DLIST:SEL \"%s\"\n", bb_string, name));
            }
        break;
        case 2:
            /* Create list from file*/

            /* Reading the file ===============================================*/
            if ((fh = fopen (name, "rb")) == VI_NULL) {
              rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
              goto Error;
            }

      if (fseek (fh, 0, SEEK_END) != 0) {
        rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
        goto Error;
      }

      if ((int)(size = ftell (fh)) < 0) {
        rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
        goto Error;
      }

      if (fseek (fh, 0, SEEK_SET) != 0) {
        rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
        goto Error;
      }

            /* Read the file content into a temporary buffer*/
            /* Allocate temporary buffer*/
            if ((tmpData = malloc (size+1)) == 0) {
        rssmiq_status = VI_ERROR_ALLOC;
        goto Error;
            }

      if (fread (tmpData, sizeof (ViUInt32), size/sizeof (ViUInt32), fh) != size) {
        rssmiq_status = VI_ERROR_INSTR_FILE_OPEN;
        goto Error;
      }

      fclose (fh);
      fh = VI_NULL;

            numOfBytes = size;

            /* List name to be created in the instrument is same as the filename*/
            /* Extension is cut off, max length is 7 chars*/
      p2name = strrchr (name, '\\');
      strcpy (listName, p2name ? 1+p2name : name);
      if (strchr (listName, '.')) (*strchr (listName, '.')) = 0;
      if (strlen (listName) > 7) listName[7] = 0;
        case 1:
            /* Create list from buffer*/
            /* Because the size of the command string in this case can be very long*/
            /* and depends on the data array size, the buffer to hold the command*/
            /* string is allocated dynamically. Its length is 85 chars for the commands*/
            /* plus number of array elements*/
            if ((buffer = malloc (81+numOfBytes)) == 0) return VI_ERROR_ALLOC;

            sprintf (str, "%ld", numOfBytes);

            if (type) {
                /* Creating a control list*/
                p2data = buffer + sprintf (buffer, "\n:SOUR:%sDM:CLIST:SEL \"%s\";"
                    ":FORM:DATA PACK;BORD NORM;:SOUR:%sDM:CLIST:DATA #%ld%ld",
                    bb_string, listName, bb_string, strlen (str), numOfBytes);
            } else {
                /* Creating a data list*/
                p2data = buffer + sprintf (buffer, "\n:SOUR:%sDM:DLIST:SEL \"%s\";"
                    ":FORM:DATA PACK;BORD NORM;:SOUR:%sDM:DLIST:DATA #%ld%ld",
                    bb_string, listName, bb_string, strlen (str), numOfBytes);
            }

            /* Allocate temporary buffer. It will be used to*/
            /* hold bit data. This prevents this input data buffer*/
            /* from being changed when doing bit shifts before sending it*/
            /* to the instrument.*/
            if (tmpData == VI_NULL) {
              if ((tmpData = malloc (numOfBytes)) == 0)
                  return VI_ERROR_ALLOC;
              memcpy (tmpData, data, numOfBytes);
          }

            if (type) {
                /* Control List: Need to reverse the symbol - data order*/
                for (i=0; i<numOfBytes/sizeof (ViUInt32); i++) {
                    tmpVal1 = rssmiq_swapViUInt32 (tmpData[i]);

                    tmpVal2 = tmpVal1;
                    tmpVal1 >>= 6;
                    tmpVal1 &= 0x03FFFFFF;
                    tmpVal1--;
                    tmpVal2 &= 0x0000003F;
                    tmpVal2 <<= 26;
                    tmpVal1 |= tmpVal2;

                    tmpData[i] = rssmiq_swapViUInt32 (tmpVal1);
                }
            }

            memcpy (p2data, tmpData, numOfBytes);
            p2data += numOfBytes;

            CHECKERR(viGetAttribute (instrumentHandle, VI_ATTR_INTF_TYPE, &interface_type));
            if (interface_type == VI_INTF_ASRL)
                {
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar));
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar));
                }
            else
                CHECKERR(viPrintf(instrumentHandle,"\n:SYST:COMM:GPIB:LTER EOI\n"));

            if ((rssmiq_status = viWrite (instrumentHandle, buffer, p2data - buffer, 0)) < 0) {
              goto Error;
            }

            if (interface_type == VI_INTF_ASRL)
                {
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar));
                CHECKERR(viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar));
                }
            else
                CHECKERR(viPrintf(instrumentHandle,"\n:SYST:COMM:GPIB:LTER STAN\n"));

            free (tmpData);
            tmpData = VI_NULL;
            free (buffer);
            buffer = VI_NULL;
        break;
        case 3:
          /* Delete list*/
            if (type) {
                /* Selecting a control list*/
                CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:%sDM:CLIST:DEL \"%s\"\n", bb_string, name));
            } else {
                CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:%sDM:DLIST:DEL \"%s\"\n", bb_string, name));
            }
        break;
    }

Error:
    if (fh) fclose (fh);
    if (tmpData) free (tmpData);
    if (buffer) free (buffer);
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Modulation Filter Lists                                 */
/* Purpose:  This function manipulates the digital modulation filter data    */
/*           lists.                                                          */
/*           This function required the  Data Generator option SMIQ-B11.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModFilterLists (ViSession instrumentHandle,
                                            ViInt32 action, ViString name,
                                            ViInt32 pulseLength,
                                            ViInt32 oversampling,
                                            ViReal64 _VI_FAR i_values[],
                                            ViReal64 _VI_FAR q_values[],
                                            ViInt32 numberOfElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViReal64 tmpArray[512];         /*Size is 2*max. value numberOfElements*/
    ViInt32 tmpElements;
    ViInt32 activeFormat;
    ViInt32 i;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        /*- Check option --------------------------------------------------------*/
        CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B11));
    }
    else
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range(action, 0, 2))
        return VI_ERROR_PARAMETER2;
    if (!strlen(name))
        return VI_ERROR_PARAMETER3;
    if ((pulseLength != 8) && (pulseLength != 16))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range(oversampling, 2, 32))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range(numberOfElements, 0, 256))
        return VI_ERROR_PARAMETER8;
    switch (action){
        case RSSMIQ_DMLIST_SEL:
            CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:SEL '%s'\n", name));
            break;
        case RSSMIQ_DMLIST_CRE:
            if (instrPtr->instrType)
                return RSSMIQ_ERROR_INSTRUMENT_ERROR;
            CHECKERR(rssmiq_getDMFormat(instrumentHandle, &activeFormat));
            /*Create tmpArray from I1,Q1,I2,Q2 ... or I1,I2 ... (in case the format is FSK)*/
            if (activeFormat>11 && activeFormat<16)
                for (i = 0; i < numberOfElements-1; i++)
                {
                    tmpArray[i] = i_values[i];
                    tmpElements = numberOfElements;
                }
            else
                for (i=0; i < numberOfElements-1;i++)
                {
                    tmpArray[2*i] = i_values[i];
                    tmpArray[2*i+1] = q_values[i];
                    tmpElements = 2* numberOfElements;
                }
           /*Create format string, num. of array elements is tmpElements*/
/*            viSPrintf(instrumentHandle, tmpBuff, "\n:SOUR:DM:FLIS:SEL '%%s';:SOUR:DM:FLIS:DATA %%ld,%%ld,6,70,%%,%ld%%le", tmpElements);        */
            CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:SEL '%s';:SOUR:DM:FLIS:DATA %ld,%ld,6,70,%*Le\n",
                                                name, pulseLength, oversampling, tmpElements, tmpArray));
            break;
        case RSSMIQ_DMLIST_DEL:
            CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:DEL '%s'\n", name));
            break;
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Modulation Format                                       */
/* Purpose:  This function controls the user defined digital modulation      */
/*           format. Use this function to specify your own modulation        */
/*           schemes, if you specified User Defined Modulation in            */
/*           rssmiq_digModulation function.                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModFormat (ViSession instrumentHandle, ViInt32 action,
                    ViString name, ViInt32 modulation, ViBoolean QpathDelay,
                    ViReal64 _VI_FAR Ivals[], ViReal64 _VI_FAR Qvals[],
                    ViInt32 numOfElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViString buffer = VI_NULL,
         p2data;
    ViInt32 i;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 2))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (modulation, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (QpathDelay))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (numOfElements, 0, 1024))
        return VI_ERROR_PARAMETER8;

    switch (action) {
        case 0:
            /* Select memory sequence*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:MLIST:SEL \"%s\"\n", name));
        break;
        case 1:
            if (instrPtr->instrType)
                return RSSMIQ_ERROR_INSTRUMENT_ERROR;
            /* Create modulation format*/
            /* Because the size of the command string in this case can be very long*/
            /* and depends on the Freq and Level arrays size, the buffer to hold the command*/
            /* string is allocated dynamically. Its length is 59 chars for the commands*/
            /* plus number of array elements x ( 3 (setup num) + 7 (dwell time) )*/
            /* minus 2 (commas do not occur at the end of of data blocks.*/

            if ((buffer = malloc (64+20*numOfElements)) == 0)
                return VI_ERROR_ALLOC;
            p2data = buffer + sprintf (buffer, "\n:SOUR:DM:MLIST:SEL \"%s\";:SOUR:DM:MLIST:DATA %ld,"
                                "%ld,%ld,0,0,0", name, modulation+1,
                                (ViInt32)(0.5 + (log(numOfElements)/log (2.0))),
                                QpathDelay);

            for (i=0; i<numOfElements; i++) {
                p2data += sprintf (p2data, ",%.6f,%.6f", Ivals[i], Qvals[i]);
            }

          strcat (buffer, "\n");
          if ((rssmiq_status = viWrite (instrumentHandle, buffer, strlen (buffer), 0)) < 0) {
              goto Error;
            }
        break;
        case 2:
            /* Delete modulation format*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:MLIST:DEL \"%s\"\n", name));
        break;
    }
Error:
  if (buffer) free (buffer);
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Modulation Clock                                        */
/* Purpose:  This function controls the clock system of digital modulation   */
/*           and digital standards.                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModClock (ViSession instrumentHandle, ViInt32 modStd,
                    ViInt32 source, ViInt32 mode, ViReal64 delay, ViBoolean polarity)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));
    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (modStd, 0, 8))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (source, 0, 12))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (delay, 0.0, 0.99))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (polarity))
        return VI_ERROR_PARAMETER6;
        if (rssmiq_invalidViInt32Range (mode, 0, 5))
            return VI_ERROR_PARAMETER4;

    p2data = buffer + sprintf (buffer, "\n");

    switch (modStd) {
        case 0:
        case 1: /* PHS*/
        case 2: /* IS95*/
        case 4: /* NADC*/
        case 5: /* PDC*/
            p2data += sprintf (p2data, ":SOUR:%s"
                           ":CLOC:MODE %s;",

                       digStdArr[modStd],
                       digClkModeArr[mode]);
        case 8: /* W3GPP*/
        case 6: /* GSM*/
        case 7: /* DECT*/
                p2data += sprintf (p2data, ":SOUR:%s"
                               ":CLOC:DEL %le;",
                           digStdArr[modStd],
                           delay);
        case 3: /* WCDMA        */
            p2data += sprintf (p2data, ":SOUR:%s"
                           ":CLOC:SOUR %s;",

                            digStdArr[modStd],
                            digClkSrcArr[source]);
        break;
    }
    if (source == 2) {
        /* In the EXT source mode select the input clk polarity*/
        p2data += sprintf (p2data, ":SOUR:DM:CLOC:POL %s\n", normInvArr[polarity]);
    }
    else
        p2data += sprintf (p2data, "\n");

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Select Filter From List                                         */
/* Purpose:  This function accepts the phase set using Reference Oscillator  */
/*           as a new reference phase.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_selectFilterFromList (ViSession instrumentHandle,
                                               ViInt32 standard, ViString name)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (standard, 0, 2))
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:%s:FILT:SEL '%s';:SOUR:%s:FILT:TYPE USER\n", filtStdArr[standard],name,filtStdArr[standard]));

    return rssmiq_status;

}

/*===========================================================================*/
/* Function: Dig Modulation External Inputs                                  */
/* Purpose:  This function controls the parameters of the external digital   */
/*           data and clock inputs.                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModExtIn (ViSession instrumentHandle, ViInt32 impedance,
                    ViReal64 threshold)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (threshold, -2.5, 2.5))
        return VI_ERROR_PARAMETER3;

    if (rssmiq_invalidViInt32Range (impedance, 0, 2))
        return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DM:INP:IMP %s;:SOUR:DM:THR %le\n",
                        digExtImpArr[impedance], threshold));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Config Digital Mod/Std Trigger                                  */
/* Purpose:  This function configures the digital triggering system of the   */
/*           instrument.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_confDigModStdTrig (ViSession instrumentHandle, ViInt32 modStd,
                    ViInt32 mode, ViBoolean source, ViInt32 extTrigDelay,
                    ViInt32 trigOut1Delay, ViInt32 trigOut2Delay,ViInt32 trigOut2Per,
                    ViInt32 extRetrigInh,ViInt32 trigOut1, ViBoolean trigOut1Pol,
                    ViInt32 trigOut2,ViBoolean trigOut2Pol)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (modStd, 0, 9))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (mode, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (extTrigDelay, 0, 65535))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (trigOut1Delay, 0, 6137999))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (trigOut2Delay, 0, 6137999))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (trigOut2Per, 1, 67108863))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (extRetrigInh, 0, 67108863))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (trigOut1, 0, 13))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViBooleanRange (trigOut1Pol))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (trigOut2, 0, 12))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViBooleanRange (trigOut2Pol))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, "\n:SOUR:%s:SEQ %s;:SOUR:%s:TRIG:SOUR %s;:SOUR:%s:TRIG:DEL %ld;"
        ":SOUR:%s:TRIG:INH %ld",
        digStdArr[modStd], digTrgModeArr[mode], digStdArr[modStd],
        intExtArr[source], digStdArr[modStd], extTrigDelay,
        digStdArr[modStd], extRetrigInh);

    switch (modStd) {
        case 0: /* Digital modulation*/

        break;
        case 4: /* NADC*/
        case 5: /* PDC*/
        case 7: /* DECT*/
            p2data += sprintf (p2data, ";:SOUR:%s"
                           ":TRIG:OUTP:DEL %ld"
                           ";:SOUR:%s"
                           ":TRIG:OUTP:PER %ld\n",

                            digStdArr[modStd],
                            trigOut2Delay,
                            digStdArr[modStd],
                            trigOut2Per);
        break;
        case 1: /* PHS*/
        case 6: /* GSM*/
            if ((trigOut1 != 5) && (trigOut1 != 12))
                return VI_ERROR_INSTR_PARAMETER10;
            p2data += sprintf (p2data, ";:SOUR:%s"
                           ":TRIG:OUTP:DEL %ld"
                           ";:SOUR:%s"
                           ":TRIG:OUTP:PER %ld"
                           ";:SOUR:%s:TRIG:OUTP %s"
                           ";:SOUR:%s:TRIG:OUTP1:POL %s"
                           ";:SOUR:%s:TRIG:OUTP2:POL %s\n",

                            digStdArr[modStd],
                            trigOut2Delay,
                            digStdArr[modStd],
                            trigOut2Per,
                            digStdArr[modStd], is95trgOutArr[trigOut1],
                            digStdArr[modStd], negPosArr[trigOut1Pol],
                            digStdArr[modStd], negPosArr[trigOut2Pol]);
        break;

        case 2: /* IS 95*/
        case 3: /* WCDMA*/
        case 8: /* W3GPP*/
            p2data += sprintf (p2data, ";:SOUR:%s"
                           ":TRIG:OUTP1 %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP2 %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP1:POL %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP2:POL %s"
                     ";:SOUR:%s"
                     ":TRIG:OUTP1:DEL %ld"
                     ";:SOUR:%s"
                     ":TRIG:OUTP2:DEL %ld\n",

                    digStdArr[modStd],
                            is95trgOutArr[trigOut1],
                            digStdArr[modStd],
                            is95trgOutArr[trigOut2],
                            digStdArr[modStd],
                            negPosArr[trigOut1Pol],
                            digStdArr[modStd],
                            negPosArr[trigOut2Pol],
                            digStdArr[modStd],
                            trigOut1Delay,
                            digStdArr[modStd],
                            trigOut2Delay);
        break;
        case 9: /* GPS  */
            /*- Check option --------------------------------------------------------*/
            CHECKERR (rssmiq_checkOption (instrumentHandle, (RSSMIQ_OPT_B20 | RSSMIQ_OPT_B51)));
            p2data += sprintf (p2data, ";:SOUR:%s"
                           ":TRIG:OUTP1 %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP2 %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP1:POL %s"
                           ";:SOUR:%s"
                           ":TRIG:OUTP2:POL %s"
                     ";:SOUR:%s"
                     ":TRIG:OUTP1:DEL %ld"
                     ";:SOUR:%s"
                     ":TRIG:OUTP2:DEL %ld\n",

                    digStdArr[modStd],
                            is95trgOutArr[trigOut1],
                            digStdArr[modStd],
                            is95trgOutArr[trigOut2],
                            digStdArr[modStd],
                            negPosArr[trigOut1Pol],
                            digStdArr[modStd],
                            negPosArr[trigOut2Pol],
                            digStdArr[modStd],
                            trigOut1Delay,
                            digStdArr[modStd],
                            trigOut2Delay);
        break;
    }

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Mod/Std Power Ramp                                      */
/* Purpose:  This function controls the power ramp settings of               */
/*           the instrument.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModStdPowRamp (ViSession instrumentHandle, ViInt32 modStd,
                    ViInt32 mode, ViBoolean shapeFunc, ViReal64 rampTime,
                    ViReal64 rampDelay, ViReal64 attenuation, ViInt32 riseOffset,
                    ViInt32 fallOffset)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/

    if (rssmiq_invalidViInt32Range (modStd, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (instrPtr->instrType)
    {
        if ((modStd != 0) && (modStd != 6))
            return VI_ERROR_PARAMETER2;
    }
    if (rssmiq_invalidViInt32Range (mode, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (shapeFunc))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (rampTime, 0.25, 32.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (rampDelay, -1.0, 5.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (attenuation, 0.0, 70.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (riseOffset, -9, 9))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (fallOffset, -9, 9))
        return VI_ERROR_INSTR_PARAMETER9;

    strcpy (buffer, "\n");

    p2data = buffer + 1;

    if (instrPtr->instrType)
    {
        switch (modStd) {
            case 0: /* Digital modulation*/
                p2data += sprintf (p2data, ":SOUR:BB:DM:PRAM:STAT %s", pRampModeArr[mode]);
            case 6: /* GSM*/
                p2data += sprintf (p2data, ";:SOUR:GSM:PRAM:SHAP %s;:SOUR:GSM:PRAM:TIME %le;"
                    ":SOUR:GSM:PRAM:DEL %le",
                    linCosArr[shapeFunc],rampTime,rampDelay);
                if (modStd == 0)
                {
                    p2data += sprintf (p2data, ";:SOUR:BB:DM:PRAM:ATT %le", attenuation);
                }
                else
                {
                    p2data += sprintf (p2data, ";:SOUR:GSM:SLOT:ATT %le;:SOUR:GSM:PRAM:ROFF %ld;"
                        ":SOUR:GSM:PRAMP:FOFF %ld",
                        attenuation,riseOffset,fallOffset);
                }
                break;
            }
    }
    else
    {
        switch (modStd) {
            case 0: /* Digital modulation*/
                p2data += sprintf (p2data, ":SOUR:DM:PRAMP:STAT %s", pRampModeArr[mode]);
            case 1: /* PHS*/
            case 4: /* NADC*/
            case 5: /* PDC*/
            case 6: /* GSM*/
            case 7: /* DECT*/
                p2data += sprintf (p2data, ";:SOUR:%s:PRAMP:SHAP %s;:SOUR:%s:PRAMP:TIME %le;"
                    ":SOUR:%s:PRAMP:DEL %le",
                    digStdArr[modStd], linCosArr[shapeFunc], digStdArr[modStd],
                    rampTime, digStdArr[modStd], rampDelay);
                if (modStd == 0) {
                    p2data += sprintf (p2data, ";:SOUR:DM:PRAMP:ATT %le", attenuation);
                }
                else {
                    p2data += sprintf (p2data, ";:SOUR:%s:SLOT:ATT %le;:SOUR:%s:PRAMP:ROFF %ld;"
                        ":SOUR:%s:PRAMP:FOFF %ld",
                        digStdArr[modStd], attenuation, digStdArr[modStd], riseOffset,
                        digStdArr[modStd], fallOffset);
                }
            break;
            case 2: /* IS 95*/
            case 3: /* IS 95*/
                /* There is no power-ramping in IS 95*/

            break;
            }
    }

    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Digital Modulation Filter Info                              */
/* Purpose:  This function queries for free memory space and for the number  */
/*           of values of the currently selected filter list.                */
/*           This function requires the option SMIQB11.                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getDigitalModFilterInfo (ViSession instrumentHandle,
                                                  ViInt32 *freeMemorySpace,
                                                  ViInt32 *numberOfSamples)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B11));

    /*- Check input parameter ranges ----------------------------------------*/
    if (!freeMemorySpace)
        return VI_ERROR_PARAMETER2;
    if (!numberOfSamples)
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:FREE?\n"));
    CHECKERR(viScanf(instrumentHandle, "%ld", freeMemorySpace));
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FLIS:POIN?\n"));
    CHECKERR(viScanf(instrumentHandle, "%ld", numberOfSamples));

    return rssmiq_status;
}
/*===========================================================================*/
/* Function: Get Digital Modulation Delay                                    */
/* Purpose:  This function returns the time delay of digital modulation      */
/*           between data input/output and RF output of the SMIQ.            */
/*           This function requires the option SMIQB11.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getDigitalModulationDelay (ViSession instrumentHandle,
                                                    ViReal64 *timeDelay)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!instrPtr->instrType)
    {
        /*- Check option --------------------------------------------------------*/
        CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B11));
    }

    /*- Check input parameter ranges ----------------------------------------*/
    if (!timeDelay)
        return VI_ERROR_PARAMETER2;
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:MDEL?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", timeDelay));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Modulation ASK Depth                                    */
/* Purpose:  This function sets the input value for the ASK modulation depth.*/
/*           This function required the  Data Generator option SMIQ-B11.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digModASKDepth (ViSession instrumentHandle,
                                         ViInt32 depth)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
    {
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR1:BB:DM:ASK:DEPT %d\n", depth));
    }
    else
    {
        /*- Check option --------------------------------------------------------*/
        CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B11));
        /*- Check input parameter ranges ----------------------------------------*/
        if (rssmiq_invalidViInt32Range(depth, 0, 100))
            return VI_ERROR_PARAMETER2;
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:ASK:DEPT %d\n", depth));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard PHS                                            */
/* Purpose:  This function controls the Digital Standard PHS signal          */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdPHS (ViSession instrumentHandle,
                  ViBoolean state,
                  ViBoolean setToStd,
                  ViReal64 symbolRate,
                  ViBoolean filter,
                  ViReal64 rollOffFactor,
                  ViBoolean filterMode,
                  ViBoolean lowDist,
                  ViInt32 frameType,
                  ViString frame,
                  ViReal64 slotAttenuation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (symbolRate, 1000.0, 200000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (filter))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (rollOffFactor, 0.1, 0.7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (lowDist))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (frameType, 0, 4))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViReal64Range (slotAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER11;

    p2data = buffer + sprintf (buffer, "\n:SOUR:PHS:STATE %s", offOnArr[state]);

    if (setToStd) {
        p2data += sprintf (p2data, ";:SOUR:PHS:STAN");
    }
    else {
        p2data += sprintf (p2data, ";:SOUR:PHS:SRAT %le"
                       ";:SOURCE:PHS:FILT:TYPE %s"
                       ";:SOUR:PHS:FILT:PAR %le"
                       ";:SOUR:PHS:FILT:MODE %s"
                       ";:SOUR:PHS:LDIS %s"
                       ";:SOUR:PHS:SLOT:ATT %le",

                       symbolRate,
                       scosCosArr[filter],
                       rollOffFactor,
                       fltModeArr[filterMode],
                       offOnArr[lowDist],
                       slotAttenuation);
    }
  switch (frameType)
    {
    case 0:
        p2data += sprintf (p2data, "\n");
      break;
    case 1:
        p2data += sprintf (p2data, ";:SOUR:PHS:FLIST:SEL \"DN1SYNC\"\n");
      break;
    case 2:
        p2data += sprintf (p2data, ";:SOUR:PHS:FLIST:SEL \"DN1TCH\"\n");
      break;
    case 3:
        p2data += sprintf (p2data, ";:SOUR:PHS:FLIST:SEL \"UP1TCH\"\n");
      break;
    case 4:
        p2data += sprintf (p2data, ";:SOUR:PHS:FLIST:LOAD \"%s\"\n", frame);
      break;
    }

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard IS95                                           */
/* Purpose:  This function controls the Digital Standard IS-95 signal        */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdIS95 (ViSession instrumentHandle, ViBoolean state,
                    ViInt32 mode, ViBoolean setToStd, ViReal64 chipRate,
                    ViInt32 fwdLinkFilter, ViInt32 revLinkFilter, ViReal64 rollOffFactor,
                    ViBoolean filterMode, ViBoolean lowDist, ViInt32 mappingType,
                    ViString mapping, ViBoolean revlLinkRate, ViBoolean rlBurstRand,
                    ViInt32 revLinkData)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (mode, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (chipRate, 1000.0, 7000000.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (fwdLinkFilter, 0, 4))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (revLinkFilter, 0, 4))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (rollOffFactor, 0.1, 0.7))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (lowDist))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (mappingType, 0, 5))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViBooleanRange (revlLinkRate))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViBooleanRange (rlBurstRand))
        return VI_ERROR_INSTR_PARAMETER15;
    if (rssmiq_invalidViInt32Range (revLinkData, 0, 3))
        return RSSMIQ_ERROR_INSTR_PARAMETER16;

    p2data = buffer + sprintf (buffer, "\n:SOUR:IS95:MODE %s",

                       linkDirArr[mode]);

    if (setToStd) {
        p2data += sprintf (p2data, ";:SOUR:IS95:PRESET");
    } else {
        p2data += sprintf (p2data, ";:SOUR:IS95:CRAT %le"
                       ";:SOUR:IS95:FILT:FTYPE %s"
                       ";:SOUR:IS95:FILT:RTYPE %s"
                       ";:SOUR:IS95:FILT:PAR %le"
                       ";:SOUR:IS95:FILT:MODE %s"
                       ";:SOUR:IS95:LDIS %s",

                        chipRate,
                        is95FltArr[fwdLinkFilter],
                        is95FltArr[revLinkFilter],
                        rollOffFactor,
                        fltModeArr[filterMode],
                        offOnArr[lowDist]);
        if (mode == 2) {
            /* Reverse link settings*/
            p2data += sprintf (p2data, ";:SOUR:IS95:RATE %s"
                           ";:SOUR:IS95:RAND %s"
                           ";:SOURCE:IS95:DATA %s",

                           fullHalfArr[revlLinkRate],
                           offOnArr[rlBurstRand],
                           revLnkDataArr[revLinkData]);
        }
        else {
          switch (mappingType) {
        case 0:
            p2data += sprintf (p2data,"\n");
          break;
        case 1:
            p2data += sprintf (p2data, ";:SOUR:IS95:MAPP:SEL:PRED 'PILOT'\n");
          break;
        case 2:
            p2data += sprintf (p2data, ";:SOUR:IS95:MAPP:SEL:PRED '09CHAN'\n");
          break;
        case 3:
            p2data += sprintf (p2data, ";:SOUR:IS95:MAPP:SEL:PRED '09BAT'\n");
          break;
        case 4:
            p2data += sprintf (p2data, ";:SOUR:IS95:MAPP:SEL:PRED '18CHAN'\n");
          break;
        case 5:
            p2data += sprintf (p2data, ";:SOUR:IS95:MAPP:LOAD '%s'\n", mapping);
          break;
      }
        }
    }

    /*p2data += sprintf (p2data, ";:SOUR:IS95:STATE %s", offOnArr[state]);*/

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    CHECKERR (viPrintf (instrumentHandle, ":SOUR:IS95:STATE %s\n", offOnArr[state]));

    return rssmiq_status;
}

ViStatus _VI_FUNC rssmiq_digStdIS95RevLinkCoded (ViSession instrumentHandle,
                                                ViInt32 mode,
                                                ViBoolean addFrameQualInd,
                                                ViInt32 source,
                                                ViString dataList,
                                                ViBoolean convolutionalEncoder,
                                                ViBoolean blockInterleaver,
                                                ViInt32 erasureBit)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    ViString modeCmd[] = {"TRAF14400", "TRAF7200", "TRAF3600", "TRAF1800",
                "ACC4800", "TRAF9600", "TRAF4800", "TRAF2400", "TRAF1200"};
  ViString dataSourceArr[] = {"PN9", "PN11", "PN15", "PN16", "PN20", "PN21", "PN23", "DLIS"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;


    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (mode, 0, 8))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (addFrameQualInd))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (source, 0, 7))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (convolutionalEncoder))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (blockInterleaver))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (erasureBit, 0, 1))
        return VI_ERROR_PARAMETER8;

    p2data = buffer + sprintf (buffer, "\n:SOUR:IS95:RLC:CTYP %s"
                       ";DATA %s"
                       ";FQIN %s"
                       ";CENC %s"
                       ";BINT %s"
                       ";EBIT %ld",

                       modeCmd[mode],
                       dataSourceArr[source],
                       offOnArr[addFrameQualInd],
                       offOnArr[convolutionalEncoder],
                       offOnArr[blockInterleaver],
                       erasureBit);

    if (source == 7) {
    p2data += sprintf (p2data, ";DLIS \"%s\"", dataList);
  }

    strcat (buffer, "\n");

    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;

}

/*===========================================================================*/
/* Function: Digital Standard IS95 Filter                                    */
/* Purpose:  This function sets the filters from list for standard IS95.     */
/*           This action has effect only if user defined filter is selected. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digitalStandardIS95Filter (ViSession instrumentHandle,
                                                    ViString fwdLinkFilter,
                                                    ViString revLinkFilter)
{
    ViStatus            rssmiq_status;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;
    else
        return (viPrintf(instrumentHandle, "\n:SOUR:IS95:FILT:FSEL '%s';:SOUR:IS95:FILT:RSEL '%s'\n", fwdLinkFilter,  revLinkFilter));
}

/*===========================================================================*/
/* Function: Digital Standard WCDMA                                          */
/* Purpose:  This function controls the Digital Standard WCDMA signal        */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdWCDMA (ViSession instrumentHandle,
                    ViBoolean state,
                    ViInt32 mode,
                    ViBoolean setToStd,
                    ViInt32 linkDir,
                    ViBoolean modType,
                    ViInt32 chipRateVar,
                    ViBoolean lowDist,
                    ViInt32 filter,
                    ViReal64 rollOffFact,
                    ViBoolean filterMode,
                    ViBoolean multicode,
                    ViInt32 masterChan,
                    ViInt32 multicodeOfChan,
                    ViInt32 sequenceLength)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    ViInt32 esr = 0;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (mode, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (linkDir, 0, 2))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (modType))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (chipRateVar, 100, 8500000))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (lowDist))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (filter, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViReal64Range (rollOffFact, 0.1, 0.7))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViBooleanRange (multicode))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViInt32Range (masterChan, 0, 3))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViInt32Range (multicodeOfChan, 0, 32767))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViInt32Range (sequenceLength, 1, 255))
        return VI_ERROR_INSTR_PARAMETER15;

    p2data = buffer + sprintf (buffer, "\n:SOUR:WCDM:MODE %s", wcdmaModArr[mode]);

    if (setToStd)
        p2data += sprintf (p2data, ";:SOUR:WCDM:PRES\n");
    else {
      p2data += sprintf (p2data, ";:SOUR:WCDM:LINK %s;:SOUR:WCDM:FORM %s"
                     ";:SOUR:WCDM:CRAT:VAR %ld;:SOUR:WCDM:FILT:TYPE %s",
                     wcdmaLinkDirArr[linkDir],
                     wcdmaModTypeArr[modType], chipRateVar, filterArr[filter]);
      if (filter != 2)
        p2data += sprintf (p2data, ";:SOUR:WCDM:FILT:PAR %le",rollOffFact);

      if (filterMode)
        p2data += sprintf (p2data, ";:SOUR:WCDM:FILT:MODE LEVM");
      else
        p2data += sprintf (p2data, ";:SOUR:WCDM:FILT:MODE LACP");

    p2data += sprintf (p2data, ";:SOUR:WCDM:LDIS %s", offOnArr[lowDist]);

    if ((linkDir == 2)&&(multicode))
      p2data += sprintf (p2data, ";:SOUR:WCDM:MULT:STAT ON"
                    ";:SOUR:WCDM:MULT:MAST %ld"
                    ";:SOUR:WCDM:MULT:CHAN #H%x",
                    masterChan, multicodeOfChan);
    p2data += sprintf (p2data, ";:SOUR:WCDM:SLEN %ld\n",sequenceLength);
  }

  CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

  CHECKERR (viPrintf (instrumentHandle, "*CLS;:SOUR:WCDM:STAT %s;*OPC\n", offOnArr[state]));

    if (state) {
      Delay (2.0);
      while ((esr & 1) == 0) {
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
      }
    }


    return rssmiq_status;
}

/*===========================================================================*/
/* Function: WCDMA Clock Frequency                                           */
/* Purpose:  This function selects the chip clock frequency.                 */
/*           The option SMIQB48 is required                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdWCDMAClockFreq (ViSession instrumentHandle,
                                               ViInt32 clockFrequency)
{

    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B45));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (clockFrequency, 0, 1))
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:WCDM:CRAT %s\n", chRateArr[clockFrequency]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard NADC                                           */
/* Purpose:  This function controls the Digital Standard NADC signal         */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdNADC (ViSession instrumentHandle, ViBoolean state,
                    ViBoolean setToStd, ViReal64 symbolRate, ViBoolean filter,
                    ViReal64 rollOffFactor, ViBoolean filterMode, ViBoolean lowDist,
                    ViInt32 frameType, ViString frame, ViBoolean linkDir,
                    ViInt32 rateConfig, ViReal64 slotAttenuation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (symbolRate, 1000.0, 200000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (filter))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (rollOffFactor, 0.1, 0.7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (lowDist))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (frameType, 0, 4))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (linkDir))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (rateConfig, 0, 7))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViReal64Range (slotAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, "\n:SOUR:NADC:STATE %s", offOnArr[state]);

    if (setToStd) {
        p2data += sprintf (p2data, ";:SOUR:NADC:STAN");
    }
    else {
        p2data += sprintf (p2data, ";:SOUR:NADC:SRAT %le"
                       ";:SOURCE:NADC:FILT:TYPE %s"
                         ";:SOUR:NADC:FILT:PAR %le"
                         ";:SOUR:NADC:FILT:MODE %s"
                         ";:SOUR:NADC:LDIS %s"
                         ";:SOUR:NADC:SLOT:ATT %le",

                        symbolRate,
                        scosCosArr[filter],
                        rollOffFactor,
                        fltModeArr[filterMode],
                        offOnArr[lowDist],
                        slotAttenuation);
    }
  switch (frameType)
    {
    case 0:
      break;
    case 1:
        p2data += sprintf (p2data, ";:SOUR:NADC:FLIST:SEL \"DNTCH\"");
      break;
    case 2:
        p2data += sprintf (p2data, ";:SOUR:NADC:FLIST:SEL \"UP1TCH\"");
      break;
    case 3:
        p2data += sprintf (p2data, ";:SOUR:NADC:FLIST:SEL \"UP_ALL\"");
      break;
    case 4:
        p2data += sprintf (p2data, ";:SOUR:NADC:FLIST:LOAD \"%s\"", frame);
      break;
    }
    p2data += sprintf (p2data, ";:SOUR:NADC:LINK %s;:SOUR:NADC:RCON %s", downUpArr[linkDir],
                                         nadcRateArr[rateConfig]);

    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard PDC                                            */
/* Purpose:  This function controls the Digital Standard PDC signal          */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdPDC (ViSession instrumentHandle, ViBoolean state,
                    ViBoolean setToStd, ViReal64 symbolRate, ViBoolean filter,
                    ViReal64 rollOffFactor, ViBoolean filterMode, ViBoolean lowDist,
                    ViInt32 frameType, ViString frame, ViBoolean linkDir,
                    ViInt32 rateConfig, ViReal64 slotAttenuation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (symbolRate, 1000.0, 200000.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (filter))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (rollOffFactor, 0.1, 0.7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (filterMode))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (lowDist))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (frameType, 0, 4))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (linkDir))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (rateConfig, 0, 7))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViReal64Range (slotAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, "\n:SOUR:PDC:STATE %s", offOnArr[state]);
    if (setToStd) {
        p2data += sprintf (p2data, ";:SOUR:PDC:STAN");
    }
    else {
    p2data += sprintf (p2data, ";:SOUR:PDC:SRAT %le"
                   ";:SOURCE:PDC:FILT:TYPE %s"
                     ";:SOUR:PDC:FILT:PAR %le"
                     ";:SOUR:PDC:FILT:MODE %s"
                     ";:SOUR:PDC:LDIS %s"
                     ";:SOUR:PDC:SLOT:ATT %le",

                    symbolRate,
                    scosCosArr[filter],
                    rollOffFactor,
                    fltModeArr[filterMode],
                    offOnArr[lowDist],
                    slotAttenuation);
    }
  switch (frameType)
    {
    case 0:
      break;
    case 1:
        p2data += sprintf (p2data, ";:SOUR:PDC:FLIST:PRED:LOAD \"DN_TCH\"");
      break;
    case 2:
        p2data += sprintf (p2data, ";:SOUR:PDC:FLIST:PRED:LOAD \"UP0TCH\"");
      break;
    case 3:
        p2data += sprintf (p2data, ";:SOUR:PDC:FLIST:PRED:LOAD \"UP_ALL\"");
      break;
    case 4:
        p2data += sprintf (p2data, ";:SOUR:PDC:FLIST:LOAD \"%s\"", frame);
      break;
    }
    p2data += sprintf (p2data, ";:SOUR:PDC:LINK %s;:SOUR:PDC:RCON %s\n", downUpArr[linkDir],
                                         pdcRateArr[rateConfig]);

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard GSM                                            */
/* Purpose:  This function controls the Digital Standard GSM signal          */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdGSM (ViSession instrumentHandle, ViBoolean state,
                    ViInt32 modulation, ViReal64 fskDeviation,
                    ViReal64 symbolRate, ViReal64 filterParameter,
                    ViInt32 frameType, ViString frame, ViReal64 slotAttenuation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (modulation, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (fskDeviation, 0.1, 2500.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (symbolRate, 1000.0, 300000.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (filterParameter, 0.1, 0.7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (frameType, 0, 6))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (slotAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER9;

    p2data = buffer + sprintf (buffer, "\n:SOUR:GSM:STATE %s", offOnArr[state]);
    if (!modulation) {
        /* Set to standard*/
        p2data += sprintf (p2data, ";:SOUR:GSM:STAN");
    }
    else {
        p2data += sprintf (p2data, ";:SOUR:GSM:FORM %s"
                       ";:SOUR:GSM:SRAT %le"
                       ";:SOUR:GSM:FILT:PAR %le"
                       ";:SOUR:GSM:SLOT:ATT %le",

                        gsmModArr[modulation],
                        symbolRate,
                        filterParameter,
                        slotAttenuation);
        if (modulation == 2) {
            /* GFSK modulation*/
            p2data += sprintf (p2data, ";:SOUR:GSM:FSK:DEV %fKHZ", fskDeviation);
        }
    }
  switch (frameType)
    {
    case 0:
      break;
    case 1:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:PRED:LOAD \"NB0\"");
      break;
    case 2:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:PRED:LOAD \"NB_ALL\"");
      break;
    case 3:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:LOAD \"%s\"", frame);
      break;
    case 4:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:PRED:LOAD \"EDGE0\"");
      break;
    case 5:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:PRED:LOAD \"EDGE_ALL\"");
      break;
    case 6:
        p2data += sprintf (p2data, ";:SOUR:GSM:FLIST:PRED:LOAD \"GSM_EDGE\"");
      break;
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard GSM Filter Type                                */
/* Purpose:  This function controls the Digital Standard DECT signal         */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdGSMFiltType (ViSession instrumentHandle,
                                            ViInt32 filter)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (filter, 1, 1))
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:GSM:FILT:TYPE %s\n", GSMFilterArr[filter]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard DECT                                           */
/* Purpose:  This function controls the Digital Standard DECT signal         */
/*           generation.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdDECT (ViSession instrumentHandle, ViBoolean state,
                    ViInt32 modulation, ViReal64 fskDeviation, ViReal64 symbolRate,
                    ViBoolean dqpskFilter, ViReal64 filterParameter,
                    ViInt32 timingAdjust, ViInt32 jitterSimul, ViBoolean preamble,
                    ViInt32 frameType, ViString frame, ViReal64 slotAttenuation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (modulation, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (fskDeviation, 100.0, 1200.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (symbolRate, 100.0, 1200000.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (dqpskFilter))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (filterParameter, 0.2, 0.7))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (timingAdjust, -4, 4))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (jitterSimul, 0, 4))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (preamble))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (frameType, 0, 7))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViReal64Range (slotAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, "\n:SOUR:DECT:STATE %s", offOnArr[state]);

  switch (modulation)
    {
    case 0:
      p2data += sprintf (p2data, ";:SOUR:DECT:STAN");
      break;
    case 1:
      p2data += sprintf (p2data, ";:SOUR:DECT:FORM GFSK;:SOUR:DECT:FSK:DEV %leKHZ"
                     ";:SOUR:DECT:SRAT %le;:SOUR:DECT:FILT:PAR %le",
                    fskDeviation, symbolRate, filterParameter);
      break;
    case 2:
      p2data += sprintf (p2data, ";:SOUR:DECT:FORM P4DQ;:SOUR:DECT:SRAT %le"
                     ";:SOUR:DECT:FILT:TYPE %s;:SOUR:DECT:FILT:PAR %le",symbolRate,
                    scosCosArr[dqpskFilter], filterParameter);
      break;
    }

  p2data += sprintf (p2data, ";:SOUR:DECT:SIM:TADJ %ld"
                 ";:SOUR:DECT:SIM:JITT %ld"
                 ";:SOUR:DECT:SLOT:ATT %le",

                 timingAdjust,
                 jitterSimul,
                 slotAttenuation);

  if (preamble)
    p2data += sprintf (p2data, ";:SOUR:DECT:PRE:TYPE PROL");
  else
        p2data += sprintf (p2data, ";:SOUR:DECT:PRE:TYPE NORM");

  switch (frameType)
    {
        case 0:   /*none*/
      break;
        case 7:   /*user*/
        p2data += sprintf (p2data, ";:SOUR:DECT:FLIS:LOAD \"%s\"",frame);
      break;
    default:
      p2data += sprintf (p2data, ";:SOUR:DECT:FLIS:PRED:LOAD %s", dectFrameTypeArr[frameType]);
      break;
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    CHECKERR (viPrintf (instrumentHandle, ":SOUR:DECT:PRE:TYPE %s\n", preamble ? "PROL" : "NORM"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard DECT User Filter                               */
/* Purpose:  This function sets the Digital Standard DECT filter to selected */
/*           filter from list.                                               */
/*           Required options SMIQB11, SMIQB20                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digStdDECTUserFilter (ViSession instrumentHandle,
                                               ViString filterName)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Option checking -----------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B11 | RSSMIQ_OPT_B20)));

    /*- Parameters checking -------------------------------------------------*/
    if (!filterName)
        return VI_ERROR_PARAMETER2;
    CHECKERR(viPrintf(instrumentHandle,"\n:SOUR:DECT:FILT:SEL '%s';:SOUR:DECT:FILT:TYPE USER\n", filterName));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Digital Standard GPS                                            */
/* Purpose:  This function controls the Digital Standard GPS signal          */
/*           generation.                                                     */
/*           Required options SMIQB11, SMIQB20, SMIQB51                      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_digitalStandardGPS (ViSession instrumentHandle,
                                             ViBoolean state,
                                             ViInt32 modulationParameters,
                                             ViReal64 dopplerShift,
                                             ViReal64 symbolRate, ViInt32 code,
                                             ViInt32 dataSource, ViInt32 pattern,
                                             ViString dataList)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar   buffer[BUFFER_SIZE];
    ViChar   tmpBuff[BUFFER_SIZE];
    ViChar   tmpPattern[30];
    ViUInt32 bit;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B51));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange(state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range(modulationParameters, 0, 1))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range(dopplerShift, -10.0E3, 10.0E3))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range(symbolRate, 500000.0, 1500000.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range(code, 1, 37))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range(dataSource, 0, 1))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range(pattern, 0x0, 0xFFFFFF))
        return VI_ERROR_PARAMETER8;


    if (modulationParameters == RSSMIQ_GPS_STANDARD)
        sprintf(buffer,"\n:SOUR:GPS:PRES:STAN");
    else
    {

        sprintf(buffer, "\n:SOUR:GPS:DSH %le;"
                        ":SOUR:GPS:SRAT %le;"
                        ":SOUR:GPS:CODE %ld;"
                        ":SOUR:GPS:DATA %s",
                        dopplerShift, symbolRate, code, dGPSSourceArr[dataSource]);
        if (dataSource == RSSMIQ_GPS_DATASOUR_PATTERN)
        {
            sprintf(tmpPattern, "%X", pattern);
            for(bit = 0;bit < 32; bit++)
                if(pattern&(1<<(31-bit)))
                    break;
            sprintf(tmpBuff, ";:SOUR:GPS:DATA:PATT #H%s,%ld", tmpPattern, 32-bit);
        }
        else
        {
            if (dataList == "")
                return VI_ERROR_INSTR_PARAMETER9;
            sprintf (tmpBuff, ";:SOUR:GPS:DATA:DLIS '%s'", dataList);
        }
        strcat (buffer, tmpBuff);
    }
    CHECKERR (viPrintf(instrumentHandle, "%s;:SOUR:GPS:STAT %s\n", buffer, offOnArr[state]));
    return rssmiq_status;
}
/*===========================================================================*/
/* Function: GPS Preset RF                                                   */
/* Purpose:  This function sets the RF-parameter frequency to 1.57542 GHz    */
/*           and level to 125 dBm generation.                               */
/*           Required options SMIQB11, SMIQB20, SMIQB51                      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_GPSPresetRF (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, (RSSMIQ_OPT_B11 | RSSMIQ_OPT_B20 | RSSMIQ_OPT_B51)));
    CHECKERR (viPrintf(instrumentHandle, "\n:SOUR:GPS:PRES:RF\n"));

    return rssmiq_status;

}

/*===========================================================================*/
/* Function: Get GPS Frequency                                               */
/* Purpose:  This function returns the GPS physically output carrier         */
/*           frequency.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getGPSFrequency (ViSession instrumentHandle,
                                          ViReal64 *frequency)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, (RSSMIQ_OPT_B51)));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:GPS:CURR:FREQ?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", frequency));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get GPS Current Symbol Rate                                     */
/* Purpose:  This function returns the GPS resulting symbol rate.            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getGPSCurrentSymbolRate (ViSession instrumentHandle,
                                                  ViReal64 *resultingSymbolRate)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, (RSSMIQ_OPT_B51)));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:GPS:CURR:SRAT?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", resultingSymbolRate));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: PHS Slot                                                        */
/* Purpose:  This function specifies the parameters of a single PHS slot.    */
/*           All slots can be independently configured by multiple calls to  */
/*           this function.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_phsSlot (ViSession instrumentHandle, ViInt32 slot,
                    ViInt32 burstType, ViInt32 level, ViBoolean setToDefault,
                    ViBoolean csidScramble, ViInt32 csidScrambleCode,
                    ViBoolean encryption, ViInt32 securityKey, ViInt32 uniqueWord,
                    ViInt32 sacch, ViString sacchList, ViInt32 tchVox,
                    ViString tchVoxList, ViString csid, ViInt32 psid,
                    ViString idle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (slot, 1, 8))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (burstType, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (level, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (setToDefault))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (csidScramble))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (csidScrambleCode, 0, 511))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (encryption))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (securityKey, 0, 65535))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (sacch, 0, 8))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (tchVox, 0, 8))
        return VI_ERROR_INSTR_PARAMETER13;

    p2data = buffer + sprintf (buffer, "\n:SOUR:PHS:SLOT%ld:TYPE %s;:SOUR:PHS:SLOT%ld:LEV %s",
                        slot, phsSlotTypeArr[burstType], slot, slotAttArr[level]);

    if (burstType == 4) {
        /* All data burst type, it has no default setting*/
        p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:TCH %s", slot,
                        dataSourceArr[tchVox]);
        if (tchVox == 8) {
            /* Data List source*/
            p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:TCH:DLIS \"%s\"",
                            slot, tchVoxList);
        }
    }
    else {
        /* Other than all data slot types*/
        if (setToDefault) {
            /* Set to default*/
            p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:PRES", slot);
        }
        else {
            /* User settings*/
            p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SCR:STAT %s;"
                            ":SOUR:PHS:SLOT%ld:SCR:CODE #H%x",
                            slot, offOnArr[csidScramble], slot, csidScrambleCode);
            if (burstType == 2) {
                /* Sync burst type settings*/
                p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:CSID #H%s;"
                                ":SOUR:PHS:SLOT%ld:PSID #H%x;:SOUR:PHS:SLOT%ld:IDLE #H%s",
                                slot, csid, slot, psid, slot, idle);
            }
            else {
                /* Vox and TCH burst type settings*/

                if (burstType == 1 || burstType == 0) {
                    /* TCH half & full*/
                  p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:ENCR:STAT %s;"
                                  ":SOUR:PHS:SLOT%ld:ENCR:KEY #H%x",
                                  slot, offOnArr[encryption], slot, securityKey);
        }

                p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:SACC %s",
                                slot, dataSourceArr[sacch]);
                if (sacch == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:SACC:DLIS \"%s\"",
                        slot, sacchList);
                }
                p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:TCH %s", slot,
                    dataSourceArr[tchVox]);
                if (tchVox == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:SOUR:TCH:DLIS \"%s\"",
                        slot, tchVoxList);
                }
            }
            p2data += sprintf (p2data, ";:SOUR:PHS:SLOT%ld:UWOR #H%x", slot, uniqueWord);
        }
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: WCDMA Channels                                                  */
/* Purpose:  This function configures a single WCDMA forward link channel.   */
/*           Every channel can be independently configured by multiple       */
/*           calls to this function.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_WCDMAChannels (ViSession instrumentHandle, ViInt32 channel,
                    ViInt32 chSelect, ViInt32 chType, ViInt32 symbolRate,
                    ViInt32 shortCode, ViInt32 upperWord, ViInt32 lowerDWord,
                    ViInt32 longCodeOffset, ViInt32 LMSShortCode, ViInt32 source,
                    ViString dataList, ViInt32 dataOffset, ViInt32 TPCData,
                    ViString TPCDataList, ViReal64 power, ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar  buffer[BUFFER_SIZE],
        buffer1[BUFFER_SIZE],
        buffer2[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (channel, 0, 63))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (chSelect, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (chType, 0, 5))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (symbolRate, 0, 6))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (shortCode, 0, 511))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (upperWord, 0, 511))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (lowerDWord, 0, 2147483647))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (longCodeOffset, 0, 81919))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (LMSShortCode, 0, 255))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (source, 0, 4))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (dataOffset, 0, 10239))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViInt32Range (TPCData, 0, 3))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViReal64Range (power, -103.0, 0.0))
        return RSSMIQ_ERROR_INSTR_PARAMETER16;
    if (rssmiq_invalidViBooleanRange (state))
        return RSSMIQ_ERROR_INSTR_PARAMETER17;

    sprintf (buffer1, ":SOUR:WCDM:CHAN%ld:", channel);
    sprintf (buffer2, ":SOUR:WCDM:CHAN%ld:%s", channel, wcdmaChArr[chSelect]);

    p2data = buffer + sprintf (buffer, "\n%sTYPE %s;%sSRAT %s;%sSCOD %ld;%sLCOD #H%lx%lx",
                  buffer2, wcdmaChTypeArr[chType], buffer2, wcdmaSRatArr[symbolRate],
                  buffer2, shortCode, buffer1, upperWord, lowerDWord);

  if (chType == 0)
      p2data += sprintf (p2data, ";%sSCOD:LMS #H%lx", buffer1, LMSShortCode);
    else
      p2data += sprintf (p2data, ";%sLCOD:OFFS %ld", buffer1, longCodeOffset);

    p2data += sprintf (p2data, ";%sPOW %leDB;%sDATA %s", buffer2, power, buffer2,
                                wcdmaSourArr[source]);

  if (source == 4)
      p2data += sprintf (p2data, ";%sDATA:DLIS \"%s\"", buffer2, dataList);
  if (chType != 0)
    p2data += sprintf (p2data, ";%sDATA:OFFS %ld", buffer2, dataOffset);

  if ((chType == 1)||(chType == 2)) {
    p2data += sprintf (p2data, ";%sTPC %s", buffer2, wcdmaTPCDataArr[TPCData]);
    if (TPCData == 3)
      p2data += sprintf (p2data, ";%sTPC:DLIS \"%s\"", buffer2, TPCDataList);
    }
    p2data += sprintf (p2data, ";%sSTAT %s\n", buffer2, offOnArr[state]);

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: IS95 Channels                                                   */
/* Purpose:  This function configures a single IS95 forward link channel.    */
/*           All channels can be independently configured by multiple calls  */
/*           to this function.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_is95Channels (ViSession instrumentHandle, ViInt32 channel,
                    ViInt32 walshCode, ViReal64 power, ViInt32 revLinkData,
                    ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (channel, 0, 63))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (walshCode, 0, 63))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (power, -100.0, 100.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (revLinkData, 0, 3))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER6;

    p2data = buffer + sprintf (buffer, "\n");

    if (channel > 0 && channel < 18) {
        /* Walsh code for chans 1 to 17*/
        p2data += sprintf (p2data, ":SOUR:IS95:CHAN%ld:WALS %ld;", channel, walshCode);
    }
    if (channel >= 0 && channel < 4) {
        /* Power for chans 0 to 3*/
        p2data += sprintf (p2data, ":SOUR:IS95:CHAN%ld:POW %le;", channel, power);
    }
    if (channel > 0 && channel < 64) {
        p2data += sprintf (p2data, ":SOUR:IS95:CHAN%ld:DATA %s;", channel,
                            revLinkDataArr[revLinkData]);
    }
    p2data += sprintf (p2data, ":SOUR:IS95:CHAN%ld:STAT %s\n", channel, offOnArr[state]);

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: NADC Slot                                                       */
/* Purpose:  This function specifies the parameters of a single NADC slot.   */
/*           All slots can be independently configured by multiple calls to  */
/*           this function.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_nadcSlot (ViSession instrumentHandle, ViInt32 slot,
                    ViInt32 burstType, ViInt32 level, ViBoolean setToDefault,
                    ViInt32 data, ViString dataList, ViInt32 sacch,
                    ViString sacchList, ViInt32 sync, ViInt32 cdvcc, ViInt32 rsvd)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (slot, 1, 6))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (burstType, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (level, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (setToDefault))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (data, 0, 8))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (sacch, 0, 8))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (sync, 0,  268435456))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (cdvcc, 0,  4095))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (rsvd, -1,  4095))
        return VI_ERROR_INSTR_PARAMETER12;

    p2data = buffer + sprintf (buffer, "\n:SOUR:NADC:SLOT%ld:TYPE %s;:SOUR:NADC:SLOT%ld:LEV %s",
                        slot, nadcSlotTypeArr[burstType], slot, slotAttArr[level]);
    if (setToDefault) {
        /* Set to default*/
        p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:PRES", slot);
    }
    else {
        switch (burstType) {
            case 0:
            case 1:
                /* Traffic and All Data channel burst type*/
                p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:SOUR:DATA %s", slot,
                    dataSourceArr[data]);
                if (data == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:SOUR:DATA:DLIS \"%s\"",
                        slot, dataList);
                }
                if (burstType == 1) {
                    /* All Data burst*/
                    break;
                }
                p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:SOUR:SACC %s", slot,
                    dataSourceArr[sacch]);
                if (sacch == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:SOUR:SACC:DLIS \"%s\"",
                        slot, sacchList);
                    }
                if (rsvd != -1) {
                    p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:RSVD #H%x", slot, rsvd);
                }
            case 2:
                p2data += sprintf (p2data, ";:SOUR:NADC:SLOT%ld:SYNC #H%x;"
                                ":SOUR:NADC:SLOT%ld:CDVC #H%x", slot, sync, slot, cdvcc);
            break;
        }
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: PDC Slot                                                        */
/* Purpose:  This function specifies the parameters of a single PDC slot.    */
/*           All slots can be independently configured by multiple calls     */
/*           to this function.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_pdcSlot (ViSession instrumentHandle, ViInt32 slot,
                    ViInt32 burstType, ViInt32 level, ViBoolean setToDefault,
                    ViBoolean scramble, ViInt32 scrambleStart, ViBoolean superFrame,
                    ViInt32 rchPosition, ViString preamble, ViInt32 syncWord,
                    ViInt32 syncWord2, ViInt32 stealFlag, ViInt32 dataSync,
                    ViString dataSyncList, ViInt32 sacch, ViString sacchList,
                    ViInt32 rch, ViString rchList, ViString postamble,
                    ViInt32 colorCode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (slot, 0, 5))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (burstType, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (level, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (setToDefault))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (scramble))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (scrambleStart, 0,  511))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (superFrame))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (rchPosition, 1, 17))
        return VI_ERROR_INSTR_PARAMETER9;
    if (burstType == 0 || burstType == 3) {
        if (rssmiq_invalidViInt32Range (syncWord, 0, 1048576))
            return VI_ERROR_INSTR_PARAMETER11;
    }
    if (rssmiq_invalidViInt32Range (syncWord2, 0,  1048576))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViInt32Range (stealFlag, 0,  1))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViInt32Range (dataSync, 0, 8))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViInt32Range (sacch, 0, 8))
        return RSSMIQ_ERROR_INSTR_PARAMETER16;
    if (rssmiq_invalidViInt32Range (rch, 0, 8))
        return RSSMIQ_ERROR_INSTR_PARAMETER18;
    if (rssmiq_invalidViInt32Range (colorCode, 0, 255))
        return RSSMIQ_ERROR_INSTR_PARAMETER21;

    p2data = buffer + sprintf (buffer, "\n:SOUR:PDC:SLOT%ld:TYPE %s;:SOUR:PDC:SLOT%ld:LEV %s",
                        slot, pdcSlotTypeArr[burstType], slot, slotAttArr[level]);

    if (setToDefault) {
        /* Set to default*/
        p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:PRES", slot);
    }
    else {
        switch (burstType) {
            case 0:
                /* Traffic channel burst type*/
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:DATA %s", slot,
                    dataSourceArr[dataSync]);
                if (dataSync == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:DATA:DLIS \"%s\"",
                        slot, dataSyncList);
                }
            case 3:
                /* Traffic & Vox channel burst type*/
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SCR:STAT %s;"
                                ":SOUR:PDC:SLOT%ld:SCR:STAR #H%x;:SOUR:PDC:SLOT%ld"
                                ":SFR:STAT %s;:SOUR:PDC:SLOT%ld:SFR:RCHP %ld;"
                                ":SOUR:PDC:SLOT%ld:PRE #H%s",
                                slot, offOnArr[scramble], slot, scrambleStart,
                                slot, offOnArr[superFrame], slot, rchPosition,
                                slot, preamble);

                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:SACC %s", slot,
                                dataSourceArr[sacch]);
                if (sacch == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:SACC:DLIS \"%s\"",
                                    slot, sacchList);
                }
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:RCH %s", slot,
                                dataSourceArr[rch]);
                if (rch == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:RCH:DLIS \"%s\"",
                                    slot, rchList);
                }
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SYNC #H%x;"
                                ":SOUR:PDC:SLOT%ld:SYNC2 #H%x;:SOUR:PDC:SLOT%ld"
                                ":CCOD #H%x;:SOUR:PDC:SLOT%ld:SF %ld",
                                slot, syncWord, slot, syncWord2,
                                slot, colorCode, slot, stealFlag);
            break;
            case 1:
                /* All Data burst type*/
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:DATA %s", slot,
                    dataSourceArr[dataSync]);
                if (dataSync == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:DATA:DLIS \"%s\"",
                        slot, dataSyncList);
                }
            break;
            case 2:
                /* Sync burst type*/
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:PRE #H%s", slot, preamble);

                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:SI %s", slot, dataSourceArr[dataSync]);
                if (dataSync == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SOUR:SI:DLIS \"%s\"", slot, dataSyncList);
                }
                if (strlen (postamble)) {
                    p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:POST #H%s", slot, postamble);
                }
                p2data += sprintf (p2data, ";:SOUR:PDC:SLOT%ld:SYNC #H%x", slot, syncWord);
            break;
        }
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: GSM Slot                                                        */
/* Purpose:  This function specifies the parameters of a single GSM slot.    */
/*           All slots can be independently configured by multiple calls     */
/*           to this function.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_gsmSlot (ViSession instrumentHandle, ViInt32 slot,
                    ViInt32 burstType, ViInt32 level, ViBoolean setToDefault,
                    ViInt32 stealingFlag, ViInt32 data, ViString dataList,
                    ViInt32 tsc, ViString userTSC, ViBoolean hopTrigger)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (slot, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (burstType, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (level, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (setToDefault))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (stealingFlag, 0,  1))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (data, 0,  8))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (tsc, 0,  8))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViBooleanRange (hopTrigger))
        return VI_ERROR_INSTR_PARAMETER11;

    p2data = buffer + sprintf (buffer, "\n:SOUR:GSM:SLOT%ld:TYPE %s;:SOUR:GSM:SLOT%ld"
                        ":LEV %s;:SOUR:GSM:SLOT%ld:HOPP:TRIG %s", slot,
                        gsmSlotTypeArr[burstType], slot, slotAttArr[level], slot,
                        offOnArr[hopTrigger]);
    if (setToDefault) {
        /* Set to default*/
        p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:PRES", slot);
    }
    else {
        switch (burstType) {
            case 0:
                /* Normal burst type*/
                p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:SF %ld",

                                slot, stealingFlag);
            case 3:
                /* EDGE burst type*/
                p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:TSC:SEL %s",

                                slot, tscArr[tsc]);
                if (tsc == 8) {
                    /* User defined training sequence*/
                    p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:TSC:USER #H%s",
                                  slot, userTSC);
                }
            case 2:
                /* All Data burst type*/
                p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:SOUR:DATA %s", slot,
                                    dataSourceArr[data]);
                if (data == 8) {
                    /* Data List source*/
                    p2data += sprintf (p2data, ";:SOUR:GSM:SLOT%ld:SOUR:DATA:DLIS \"%s\"",
                                    slot, dataList);
                }
            break;
        }
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: DECT Slot                                                       */
/* Purpose:  This function specifies the parameters of a single DECT slot.   */
/*           All slots can be independently configured by multiple calls     */
/*           to this function.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_dectSlot (ViSession instrumentHandle, ViInt32 slot,
                    ViInt32 slotType, ViInt32 level, ViBoolean setToStd,
                    ViInt32 slotTimmShift, ViBoolean rampUp, ViInt32 rampData,
                    ViInt32 preamble, ViInt32 sync, ViInt32 aFieldData,
                    ViString aDataList, ViInt32 bFieldData, ViString bDataList,
                    ViBoolean zField)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViChar buffer1[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (slot, 0, 23))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (slotType, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (level, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (setToStd))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (slotTimmShift, -9, 9))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViBooleanRange (rampUp))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (rampData, 0, 4095))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (preamble, 0, 50047))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (sync, 0, 65535))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (aFieldData, 0, 8))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (bFieldData, 0, 8))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViBooleanRange (zField))
        return VI_ERROR_INSTR_PARAMETER15;

    p2data = buffer + sprintf (buffer, "\n:SOUR:DECT:SLOT%ld:TYPE %s"
                      ";:SOUR:DECT:SLOT%ld:LEV %s",

                      slot, dectSlotTypeArr[slot],
                      slot, dectLevelArr[level]);

    if (setToStd)
    p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:PRES", slot);
    else {
    p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:STSH %ld;"
                  ":SOUR:DECT:SLOT%ld:RAMP:CW %s;:SOUR:DECT:SLOT%ld:RAMP:DATA #H%x",
                  slot, slotTimmShift, slot, offOnArr[rampUp], slot, rampData);
        if (slotType == 2) /*All Data*/
      {
      p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SOUR:BFI %s", slot,
                dectFieldArr[bFieldData]);
            if (bFieldData == 8) /*List*/
        p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SOUR:BFI:DLIS %s",
                      slot, bDataList);
          }
        else{
          CHECKERR (viQueryf (instrumentHandle, ":SOUR:DECT:PRE:TYPE?", "%[^\n]", buffer1));

      if (strstr (buffer1, "PROL"))
        p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:PRE:PROL:DATA #H%lx",slot, preamble);
      else
        p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:PRE:DATA #H%lx",slot, preamble);

      p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SYNC #H%lx;:SOUR:DECT:SLOT%ld:SOUR:AFI %s",
                    slot, sync, slot, dectFieldArr[aFieldData]);

            if (aFieldData == 8) /*List*/
        p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SOUR:AFI:DLIS \"%s\"",
                      slot, aDataList);

      p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SYNC #H%lx;:SOUR:DECT:SLOT%ld:SOUR:BFI %s",
                    slot, sync, slot, dectFieldArr[bFieldData]);

            if (bFieldData == 8) /*List*/
        p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:SOUR:BFI:DLIS \"%s\"",
        slot, bDataList);

      p2data += sprintf (p2data, ";:SOUR:DECT:SLOT%ld:ZFI %s", slot, offOnArr[zField]);

          }
        }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get GPP3 Version                                          */
/* Purpose:  This function returns the version of GPP3.                      */
/*           It is required the option SMIQ-B45 installed in the instrument. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetGPP3Version (ViSession instrumentHandle,
                                              ViInt32 size, ViChar version[],
                                              ViInt32 *length)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 num_of_chars = size;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B45));

    if (!version)
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:GPP3:VERS?\n"));
    CHECKERR(viScanf(instrumentHandle, "%#s", &num_of_chars, version));

    if (length)
        *length = strlen(version);
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Chip Rate                                             */
/* Purpose:  This function returns the chip rate in cps                      */
/*           It is required the option SMIQ-B45 installed in the instrument. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetChipRate (ViSession instrumentHandle,
                                           ViInt32 *chipRate)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 megaChips;
    ViInt32 chips;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B45));

    if (!chipRate)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:CRAT?\n"));
    CHECKERR(viScanf(instrumentHandle, "R%ldM%ld", &megaChips, &chips));

    *chipRate = megaChips*1000000 + chips*100000;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get PCCP Length                                           */
/* Purpose:  This function returns the sequence length of P-CCPCH/BCH        */
/*           It is required the option SMIQ-B14 installed in the instrument. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetPCCPLength (ViSession instrumentHandle,
                                             ViInt32 *length)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    if (!length)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:BST:ENH:PCCP:SLEN?\n"));
    CHECKERR(viScanf(instrumentHandle, "%ld", length));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Configure Bit/Blocks Error                                */
/* Purpose:  This function configures insertion of bit errors into data      */
/*           field or CRC field and bit error rate.                          */
/*           It is required the option SMIQ-B48 installed in the instrument. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppConfigureBitBlocksErrors (ViSession instrumentHandle,
                                                        ViInt32 station,
                                                        ViInt32 error,
                                                        ViBoolean state,
                                                        ViReal64 rate)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar   tmpCommand[BUFFER_SIZE];

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (station, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (error, 0, 1))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (rate, 1.0E-7, 1.0E-1))
        return VI_ERROR_PARAMETER5;

    sprintf(tmpCommand,"\n:SOUR:W3GP:%s:ENH:DERR:%s", stationArr[station], errTypeArr[error]);
    CHECKERR(viPrintf(instrumentHandle, "%s:STAT %s; %s:RATE %le\n",
                                        tmpCommand, offOnArr[state], tmpCommand, rate));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Resulting BER                                         */
/* Purpose:  This function configures insertion of bit errors into data      */
/*           field or CRC field and bit error rate.                          */
/*           It is required the option SMIQ-B48 installed in the instrument. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetResultingBER (ViSession instrumentHandle,
                                               ViInt32 station, ViInt32 error,
                                               ViInt32 channel, ViReal64 *rate)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32  tmpUpp;
    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (station, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (error, 0, 1))
        return VI_ERROR_PARAMETER3;
    tmpUpp = ((error == RSSMIQ_W3GP_ERROR_BIT)? 2 : 1);
    if (rssmiq_invalidViInt32Range (channel, 0, tmpUpp))
        return VI_ERROR_PARAMETER4;
    if (!rate)
        return VI_ERROR_PARAMETER5;

    /*If mobile station and DPCH selected, use DPDC*/
    if ((channel == RSSMIQ_W3GP_CHANNEL_DPCH) && (station == RSSMIQ_W3GP_STATION_MOBILE))
        channel++;
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:%s:ENH:DERR:%s:%s?\n",
                                         stationArr[station], errTypeArr[error],
                                         w3gpchanTypeArr[channel]));
    CHECKERR(viScanf(instrumentHandle, "%le", rate));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading                                                          */
/* Purpose:  This function configures the fading simulator. It requires      */
/*           the option SMIQ-B14 installed in the instrument.                */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_recalculatingFadingSignal (ViSession instrumentHandle,
                                                    ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B14));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange(state))
        return VI_ERROR_PARAMETER2;
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:IGN:RFCH %s\n", offOnArr[state]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Get Extern Crest Factor                                  */
/* Purpose:  This function returns the crest factor to be set on the second  */
/*           SMIQ.                                                           */
/*           It requires the option SMIQ-B14 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingGetExternCrestFactor (ViSession instrumentHandle,
                                                     ViReal64 *crestFactor)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B14));

    /*- Check input parameter ranges ----------------------------------------*/
    if (!crestFactor)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:CFAC:EXT?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", crestFactor));

    return rssmiq_status;
}
/*===========================================================================*/
/* Function: Fading Default                                                  */
/* Purpose:  This function configures the fading simulator the default       */
/*           setting of the path parameters. Path 1 is switched on; all other*/
/*           paths are switched off.                                         */
/*           It requires the option SMIQ-B14 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingDefault (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B14));
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:DEF\n"));

    return rssmiq_status;
}


/*===========================================================================*/
/* Function: Fading Fine Delay Default                                       */
/* Purpose:  This function configures the fine delay fading simulation to    */
/*           the reset setting of the path parameters. Paths 1 and 2 are     */
/*           switched on; all other paths are switched off.                  */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingFineDelayDefault (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:FDEL:DEF\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Fine Delay                                               */
/* Purpose:  This function configures the fading fine delay simulation.      */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingFineDelay (ViSession instrumentHandle,
                                          ViBoolean state,  ViInt32 standard,
                                          ViInt32 speedUnit)
{
    static ViInt32 standard_with_B15[] = {RSSMIQ_FDEL_STANDARD_G3C2, RSSMIQ_FDEL_STANDARD_G3C3, RSSMIQ_FDEL_STANDARD_G3C4,
                                          RSSMIQ_FDEL_STANDARD_G3UEC2, RSSMIQ_FDEL_STANDARD_G3UEC3, RSSMIQ_FDEL_STANDARD_G3UEC6};
    ViBoolean in_std_B15;
    ViInt32 i;
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (standard, 0, 9))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (speedUnit, 0, 2))
        return VI_ERROR_PARAMETER4;
    in_std_B15 = VI_FALSE;
    for (i=0;i<6;i++)
        if (standard == standard_with_B15[i])
        {
            in_std_B15 = VI_TRUE;
            break;
        }
    if (in_std_B15)
        CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B15));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:FDEL:STAT %s;:SOUR:FSIM:FDEL:STAN %s;:SOUR:FSIM:FDEL:SPE:UNIT %s\n",
             offOnArr[state], fsimStandardArr[standard], speedUnitArr[speedUnit]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Fine Delay Path                                          */
/* Purpose:  This function configures configures a single path of the fine   */
/*           delay simulation.                                               */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingFineDelayPath (ViSession instrumentHandle,
                                              ViInt32 path, ViBoolean state,
                                              ViInt32 profile,
                                              ViReal64 freqRatio,
                                              ViInt32 movingPar,
                                              ViReal64 speedDoplFreq,
                                              ViReal64 pathLoss_in_dB,
                                              ViReal64 delay_in_us)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32  tmpPathRange;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;


    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));
    /*The paths 3 and 4 can be used only if option SMIQ-B15 installed*/
    if (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B15) < VI_SUCCESS)
        tmpPathRange = 2;
    else
        tmpPathRange = 4;
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (path, 1, tmpPathRange))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (profile, 0, 1))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (freqRatio, -1.0, 1.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (movingPar, 0, 1))
        return VI_ERROR_PARAMETER6;
    if (movingPar == RSSMIQ_FDEL_SPEED)
    {
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.005, 27777))
            return VI_ERROR_PARAMETER7;
    }
    else
    {
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.100, 1600.000))
            return VI_ERROR_PARAMETER7;
    }
    if (rssmiq_invalidViReal64Range (pathLoss_in_dB, 0.0, 50.0))
        return VI_ERROR_PARAMETER8;

    if (rssmiq_invalidViReal64Range (delay_in_us, 25.0E-9, 1637.0E-6))
        return VI_ERROR_INSTR_PARAMETER9;

    p2data = buffer + sprintf (buffer, "\n:SOUR:FSIM:FDEL:PATH%ld:PROF %s;:SOUR:FSIM:FDEL:PATH%ld:FRAT %le"
                                ";:SOUR:FSIM:FDEL:PATH%ld:LOSS %le;:SOUR:FSIM:FDEL:PATH%ld:DEL %le",
                                path, fadProfArr[profile], path, freqRatio, path, pathLoss_in_dB, path, delay_in_us);
    if (movingPar == RSSMIQ_FDEL_SPEED)
        p2data += sprintf (p2data, ";:SOUR:FSIM:FDEL:PATH%ld:SPE %le", path, speedDoplFreq);
    else
        p2data += sprintf (p2data, ";:SOUR:FSIM:FDEL:PATH%ld:FDOP %le", path, speedDoplFreq);
    p2data += sprintf (p2data, ";:SOUR:FSIM:FDEL:PATH%ld:STATE %s\n", path, offOnArr[state]);
    CHECKERR(viPrintf(instrumentHandle, "%s", buffer));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Moving Delay Default                                     */
/* Purpose:  This function configures the moving delay simulation to the     */
/*           reset setting of the path parameters.                           */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingMovingDelayDefault (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:MDEL:DEF\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Moving Delay                                             */
/* Purpose:  This function configures the moving delay simulation.           */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingMovingDelay (ViSession instrumentHandle,
                                            ViBoolean state,
                                            ViReal64 referenceSignalLoss,
                                            ViReal64 referenceSignalDelay,
                                            ViReal64 movingSignalLoss,
                                            ViReal64 movingMeanDelay,
                                            ViReal64 movingDelayVariation,
                                            ViInt32 movingVariationSpeed)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (referenceSignalLoss, 0.0, 50.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (referenceSignalDelay, 0.0, 1638.0E-6))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (movingSignalLoss, 0.0, 50.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (movingMeanDelay, 0.25E-6, 1637.8E-6))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (movingDelayVariation, 0.3E-6, 100.0E-6))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViInt32Range (movingVariationSpeed, 10, 500))
        return VI_ERROR_PARAMETER8;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:MDEL:REF:LOSS %le;:SOUR:FSIM:MDEL:REF:DEL %le"
                                        ";:SOUR:FSIM:MDEL:MOV:LOSS %le;:SOUR:FSIM:MDEL:MOV:DEL:MEAN %le"
                                        ";:SOUR:FSIM:MDEL:MOV:DEL:VAR %le;:SOUR:FSIM:MDEL:MOV:VPER %ld"
                                        ";:SOUR:FSIM:MDEL:STAT %s\n", referenceSignalLoss,
                                        referenceSignalDelay, movingSignalLoss, movingMeanDelay,
                                        movingDelayVariation, movingVariationSpeed, offOnArr[state]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Birth-Death Delay Default                                */
/* Purpose:  This function configures the birth-death delay simulation to    */
/*           the reset setting of the path parameters.                       */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingBirthDeathDefault (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:BIRT:DEF\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Birth-Death Delay                                        */
/* Purpose:  This function configures the birth-death delay simulation.      */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingBirthDeath (ViSession instrumentHandle,
                                           ViBoolean state,
                                           ViInt32 insertionLoss,
                                           ViInt32 speedUnit)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));
    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (insertionLoss, 0, 1))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (speedUnit, 0, 2))
        return VI_ERROR_PARAMETER4;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:BIRT:ILOS:MODE %s;:SOUR:FSIM:BIRT:SPE:UNIT %s"
                                        ";:SOUR:FSIM:BIRT:STAT %s\n", fadingILossArr[insertionLoss],
                                        speedUnitArr[speedUnit], offOnArr[state]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Birth Death Delay Path                                   */
/* Purpose:  This function configures configures configures a single path of */
/*           the birth death simulation.                                     */
/*           It requires the option SMIQB49 installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingBirthDeathDelayPath (ViSession instrumentHandle,
                                                    ViInt32 path,
                                                    ViInt32 profile,
                                                    ViReal64 freqRatio,
                                                    ViInt32 movingPar,
                                                    ViReal64 speedDoplFreq,
                                                    ViReal64 pathLoss_in_dB,
                                                    ViReal64 delay,
                                                    ViReal64 dwellTimeUp)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B49));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (path, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (profile, 0, 0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (freqRatio, -1.0, 1.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (movingPar, 0, 1))
        return VI_ERROR_PARAMETER5;
    if (movingPar == RSSMIQ_FDEL_SPEED)
    {
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.005, 27777))
            return VI_ERROR_PARAMETER6;
    }
    else
    {
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.100, 1600.000))
            return VI_ERROR_PARAMETER6;
    }
    if (rssmiq_invalidViReal64Range (pathLoss_in_dB, 0.0, 50.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (delay, 5.0E-6, 1.0E-3))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViReal64Range (dwellTimeUp, 100.0E-3, 5.0))
        return VI_ERROR_INSTR_PARAMETER9;

    p2data = buffer + sprintf (buffer, "\n:SOUR:FSIM:BIRT:PATH%d:PROF %s;:SOUR:FSIM:BIRT:PATH%d:FRAT %le"
                                ";:SOUR:FSIM:BIRT:PATH%d:LOSS %le;:SOUR:FSIM:BIRT:PATH%d:DEL %le"
                                ";:SOUR:FSIM:BIRT:PATH%d:HOPP:DWEL %le",
                                path, fadProfArr[profile], path, freqRatio, path, pathLoss_in_dB,
                                path, delay, path, dwellTimeUp);

    if (movingPar == RSSMIQ_FDEL_SPEED)
        p2data += sprintf (p2data, ";:SOUR:FSIM:BIRT:PATH%ld:SPE %le", path, speedDoplFreq);
    else
        p2data += sprintf (p2data, ";:SOUR:FSIM:BIRT:PATH%ld:FDOP %le", path, speedDoplFreq);

    CHECKERR(viPrintf(instrumentHandle, "%s\n", buffer));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading                                                          */
/* Purpose:  This function configures the fading simulator. It requires      */
/*           the option SMIQ-B14 installed in the instrument.                */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fading (ViSession instrumentHandle, ViInt32 fading,
                    ViInt32 mode, ViInt32 standard, ViBoolean insLossSetMode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (fading, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (mode, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (standard, 0, 26))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (insLossSetMode))
        return VI_ERROR_PARAMETER5;

    p2data = buffer + sprintf (buffer, "\n:SOUR:FSIM %s", fadingConfArr[fading]);

    if (fading) {
        /* Configure fading*/
        if (mode == 2) {
            /* Reset fading*/
            p2data += sprintf (p2data, ";:SOUR:FSIM:SEQ:RES");
        }
        else {
            p2data += sprintf (p2data, ";:SOUR:FSIM:SEQ %s;:SOUR:FSIM:STAN %s;"
                            ":SOUR:FSIM:ILOSS:MODE %s",
                            fadingModeArr[mode], fadingStdArr[standard],
                            fadingILossArr[insLossSetMode]);
        }
    }

    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Path                                                     */
/* Purpose:  This function configures a single path of the fading simulator. */
/*           It requires the option SMIQ-B14 installed in the instrument.    */
/*           All paths can be configured by multiple calls to this function. */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingPath (ViSession instrumentHandle, ViInt32 path,
                    ViBoolean state, ViInt32 profile, ViBoolean discreteComponent,
                    ViReal64 powerRatio, ViReal64 freqRatio, ViReal64 speedDoplFreq,
                    ViBoolean movingPar, ViReal64 pathLoss, ViReal64 delay,
                    ViInt32 correlPath, ViReal64 correlAmpl, ViReal64 correlPhase,
                    ViBoolean logNormState, ViReal64 localConst, ViReal64 stdDev)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    ViInt32 options;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (path, 0, 12))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (profile, 0, 3))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (discreteComponent))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (powerRatio, -30.0, 30.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (freqRatio, -1.0, 1.0))
        return VI_ERROR_PARAMETER7;
    if (movingPar) {
        /* speedDoplFreq contains frequency*/
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.0, 305756.3))
            return VI_ERROR_PARAMETER8;
    }
    else {
        /* speedDoplFreq contains speed*/
        if (rssmiq_invalidViReal64Range (speedDoplFreq, 0.0, 27777.3))
            return VI_ERROR_PARAMETER8;
    }
    if (rssmiq_invalidViBooleanRange (movingPar))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViReal64Range (pathLoss, 0.0, 50.0))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViReal64Range (delay, 0.0, 1638.0))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (correlPath, 0, 6))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViReal64Range (correlAmpl, 0.0, 1.0))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViReal64Range (correlPhase, 0.0, 359.0))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViBooleanRange (logNormState))
        return VI_ERROR_INSTR_PARAMETER15;
    if (rssmiq_invalidViReal64Range (localConst, 120.0, 200.0))
        return RSSMIQ_ERROR_INSTR_PARAMETER16;
    if (rssmiq_invalidViReal64Range (stdDev, 0.0, 12.0))
        return RSSMIQ_ERROR_INSTR_PARAMETER17;

    p2data = buffer + sprintf (buffer, "\n:SOUR:FSIM:SPE:UNIT KMPH;:SOUR:FSIM:PATH%ld:STAT %s;"
                        ":SOUR:FSIM:PATH%ld:PROF %s;:SOUR:FSIM:PATH%ld:DCOM:STAT %s",
                        path, offOnArr[state], path, fadProfArr[profile], path,
                        offOnArr[discreteComponent]);
    if (discreteComponent) {
        /* Set discrete component parameters*/
        p2data += sprintf (p2data, ";:SOUR:FSIM:PATH%ld:PRAT %le;FRAT %le", path,
            powerRatio, freqRatio);
    }
    if (movingPar) {
        /* speedDoplFreq contains doppler frequency*/
        p2data += sprintf (p2data, ";:SOUR:FSIM:PATH%ld:FDOP %le;LOSS %le;DEL %fE-6",
            path, speedDoplFreq, pathLoss, delay);
    }
    else {
        /* speedDoplFreq contains speed in km/h*/
        p2data += sprintf (p2data, ";:SOUR:FSIM:PATH%ld:SPE %le;LOSS %le;DEL %fE-6",
            path, speedDoplFreq/3.6, pathLoss, delay);
    }
    /* Check for options B14 and B15*/
    if ((rssmiq_status = rssmiq_instrOptions (instrumentHandle, &options)) < 0)
        return rssmiq_status;

    if ((options & RSSMIQ_OPT_B14) || (options & RSSMIQ_OPT_B15)) {
        /* Options SMIQ-B14 and SMIQ-B15 are installed, configure correlated paths */
        p2data += sprintf (p2data, ";:SOUR:FSIM:PATH%ld:CORR:PATH %s;"
                        ":SOUR:FSIM:PATH%ld:CORR:COEF %le;PHAS %le",
                        path, correlPathAtt[correlPath], path, correlAmpl, correlPhase);
    }
    p2data += sprintf (p2data, ";:SOUR:FSIM:PATH%ld:LOGN:STAT %s;"
                    ":SOUR:FSIM:PATH%ld:LOGN:LCON %le;CSTD %le\n",
                    path, offOnArr[logNormState], path, localConst, stdDev);

    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Fading Phase for CPHAS                                          */
/* Purpose:  This function sets the phase for CPHAS fading.                  */
/*           It requires the option SMIQ-B14 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_fadingPhaseForCPHAS (ViSession instrumentHandle,
                                              ViInt32 path,
                                              ViReal64 phase_in_deg)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange instrPtr;
    ViInt32 tmp_path;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B14));
    /*- Check input parameter ranges ----------------------------------------*/
    tmp_path = ((instrPtr->options & RSSMIQ_OPT_B15) ? 12 : 6);
    if (rssmiq_invalidViInt32Range (path, 1, tmp_path))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (phase_in_deg, 0.0, 360.0))
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:FSIM:PATH%d:CPH %le\n", path, phase_in_deg));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get IS95 Power                                                  */
/* Purpose:  This function returns the total power for the CDMA signal.      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getIS95Power (ViSession instrumentHandle,
                                       ViReal64 *power)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B42));

    /*- Check input parameter ranges ----------------------------------------*/
    if (!power)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:IS95:POW?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", power));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: IS95 Adjust Power                                               */
/* Purpose:  This function modifies the power of each active code channel.   */
/*           This means that the total power is set equal to the power in    */
/*           the level display.                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_dmIS95AdjustPower (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B42));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:IS95:POW:ADJ\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get WCDMAPower                                                  */
/* Purpose:  This function returns the total power for the WCDMA signal.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getWCDMAPower (ViSession instrumentHandle,
                                       ViReal64 *power)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B45));

    /*- Check input parameter ranges ----------------------------------------*/
    if (!power)
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:WCDM:POW?\n"));
    CHECKERR(viScanf(instrumentHandle, "%le", power));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: WCDMA Adjust Power                                               */
/* Purpose:  This function modifies the power of each active code channel.   */
/*           This means that the total power is set equal to the power in    */
/*           the level display.                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_dmWCDMAAdjustPower (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR(rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B45));

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:WCDM:POW:ADJ\n"));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP State                                                     */
/* Purpose:  This function controls the state of the W3GPP module. When      */
/*           turning on, it waits for all the calculations to complete.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppState (ViSession instrumentHandle, ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViInt32 esr = 0;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
      return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:W3GPP:STAT %s;*OPC\n", offOnArr[state]));

    if (state) {
      Delay (2.0);
      while ((esr & 1) == 0) {
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
      }
    }
  return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Setup                                                     */
/* Purpose:  This function resets the W3GPP module to the default state or   */
/*           loads/saves/deletes the W3GPP configuration.          */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppSetup (ViSession instrumentHandle,
                                       ViInt32 operation, ViString settingName)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 esr = 0;
    static ViString cmd[] = {"LOAD", "STOR", "DEL"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViInt32Range (operation, 0, 3))
        return VI_ERROR_PARAMETER2;

  if (operation == 3) {
    CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:PRES\n"));
  } else {
      CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:W3GPP:SETT:%s \"%s\";*OPC\n", cmd[operation], settingName));
    }

    if (operation == 0) {
      Delay (2.0);
      while ((esr & 1) == 0) {
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
      }
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Setup Catalog                                             */
/* Purpose:  This function returns a catalog of W3GPP setups.                */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppSetupCatalog (ViSession instrumentHandle,
                                               ViInt32 size, ViChar catalog[],
                                               ViInt32 *listLength)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 temp_size = size;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (size <= 0) return VI_ERROR_PARAMETER2;

    if (!catalog)  return VI_ERROR_PARAMETER3;

    CHECKERR (viQueryf (instrumentHandle, "\n:W3GPP:SETT:CAT?\n", "%#s", &temp_size, catalog));

    if (listLength) *listLength = size;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Test Model                                                */
/* Purpose:  This function selects the W3GPP test model.                     */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppTestModel (ViSession instrumentHandle,
                                         ViInt32 testModel)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  static ViString cmd[] = {"TEST1_16", "TEST1_32", "TEST1_64", "TEST2", "TEST3_16", "TEST3_32", "TEST_4", "C+D 60K", "C+D960K"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption (instrumentHandle, RSSMIQ_OPT_B45));

    if (rssmiq_invalidViInt32Range (testModel, 0, 8))
        return VI_ERROR_PARAMETER2;

    if (testModel <= 6)
        CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:SETT:TMOD '%s'\n", cmd[testModel]));
    else
        CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:SETT:TMOD:MST '%s'\n", cmd[testModel]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Test Model Catalog                                        */
/* Purpose:  This function returns the W3GPP test model catalog              */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppTestModelCatalog (ViSession instrumentHandle,
                                                ViInt32 station, ViInt32 size,
                                                ViChar catalog[],
                                                ViInt32 *length)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 num_of_chars = size;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B45));
    if (rssmiq_invalidViInt32Range(station, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (!catalog)
        return VI_ERROR_PARAMETER3;

    if (station == RSSMIQ_W3GP_STATION_BASE)
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:SETT:TMOD:CAT?\n"));
    else
        CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:SETT:TMOD:MST:CAT?\n"));
    CHECKERR(viScanf(instrumentHandle, "%#s", &num_of_chars, catalog));

    if (length)
       *length = strlen(catalog);

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Link                                                      */
/* Purpose:  This function configures the W3GPP link parameters.             */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppLink (ViSession instrumentHandle,
                  ViInt32 link,
                                    ViInt32 sequenceLength,
                                    ViInt32 clippingLevel,
                                    ViReal64 chipRateVar,
                                    ViInt32 filterType,
                                    ViString userFilterName,
                                    ViReal64 filterParameter,
                                    ViInt32 filterMode)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString linkCmd[] = {"FORW", "REV"};
  static ViString filtCmd[] = {"SCOS", "COS", "WCDMA", "USER"};
  static ViString fmodCmd[] = {"LACP", "LEVM"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViInt32Range (link, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (sequenceLength, 1, 13))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (clippingLevel, 1, 100))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (chipRateVar, 0.0001, 18.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (filterType, 0, 3))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (filterParameter, 0.01, 0.99))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (filterMode, 0, 1))
        return VI_ERROR_INSTR_PARAMETER9;

  p2data = buffer + sprintf (buffer, "\n:W3GPP:LINK %s"
                     ";SLEN %ld"
                     ";CLIP:LEV %ld"
                     ";:W3GPP:CRAT:VAR %le"
                     ";:W3GPP:FILT:TYPE %s"
                     ";PAR %le"
                     ";MODE %s",

                    linkCmd[link],
                    sequenceLength,
                    clippingLevel,
                    1.0E6*chipRateVar,
                    filtCmd[filterType],
                    filterParameter,
                    fmodCmd[filterMode]);

    if (filterType == 3) {  /* USER*/
    p2data += sprintf (p2data, ";SEL \"%s\"", userFilterName);
  }
  strcat (buffer, "\n");
  CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

  return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Parametrization                                           */
/* Purpose:  This function configures additional W3GPP parameters.           */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppParametrization (ViSession instrumentHandle,
                                               ViBoolean synchronizeChannels,
                                               ViBoolean SCCPCHState,
                                               ViInt32 SCCPCHSymbolRate,
                                               ViInt32 DPCHChannelCount,
                                               ViInt32 DPCHSymbolRate,
                                               ViInt32 crestFactor)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  static ViString cresCmd[] = {"MIN", "AVER", "WORS"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (synchronizeChannels))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (SCCPCHState))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (SCCPCHSymbolRate, 1, 7))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (DPCHChannelCount, 0, 512))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (DPCHSymbolRate, 0, 7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (crestFactor, 0, 2))
        return VI_ERROR_PARAMETER7;

  CHECKERR (viPrintf (instrumentHandle, "\n:W3GP:PPAR:SCH %s"
                    ";SCCP:STAT %s"
                    ";SRAT %s"
                    ";:W3GP:PPAR:DPCH:COUN %ld"
                    ";SRAT %s"
                    ";:W3GP:PPAR:CRES %s;EXEC\n",

                    offOnArr[synchronizeChannels],
                    offOnArr[SCCPCHState],
                    sRateArr[SCCPCHSymbolRate],
                    DPCHChannelCount,
                    sRateArr[DPCHSymbolRate],
                    cresCmd[crestFactor]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Copy Settings                                             */
/* Purpose:  This function copies base/mobile station parameters.            */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppCopySettings (ViSession instrumentHandle,
                                            ViInt32 source,
                                            ViInt32 destination,
                                            ViInt32 offset)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViInt32Range (source, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (destination, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (offset, -1, 511))
        return VI_ERROR_PARAMETER4;

    p2data = buffer + sprintf (buffer, "\n:W3GPP:COPY:SOUR %ld;DEST %ld",
                              source, destination);
    if (offset >= 0) {
      p2data += sprintf (p2data, ";COFF %ld;EXEC\n", offset);
    } else {
      p2data += sprintf (p2data, ";EXEC\n", offset);
    }

  CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Base Station                                              */
/* Purpose:  This function configures base station parameters.               */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBStation (ViSession instrumentHandle,
                                        ViInt32 baseStation,
                                        ViInt32 scramblingCode,
                                        ViBoolean TFCIState,
                                        ViInt32 TFCI,
                                        ViInt32 secondSCG,
                                        ViInt32 TPCRead,
                                        ViBoolean TPCMisuse,
                                        ViReal64 TPCPowerStep,
                                        ViInt32 transmitDiversity,
                                        ViInt32 pageIndicatorChannel,
                                        ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  static ViString  tpcrCmd[] = {"CONT", "S0A", "S1A", "S01A", "S10A"};
  static ViString  tdivCmd[] = {"OFF", "ANT1", "ANT2"};
  static ViString  piccCmd[] = {"D18", "D36", "D72", "D144"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_INSTR_PARAMETER12;

  if (state) {
      if (rssmiq_invalidViInt32Range (baseStation, 1, 4))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (scramblingCode, 0, 0x3FFFF))
          return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViBooleanRange (TFCIState))
          return VI_ERROR_PARAMETER4;
      if (rssmiq_invalidViInt32Range (TFCI, 0, 1023))
          return VI_ERROR_PARAMETER5;
      if (rssmiq_invalidViInt32Range (secondSCG, 0, 64))
          return VI_ERROR_PARAMETER6;
      if (rssmiq_invalidViInt32Range (TPCRead, 0, 4))
          return VI_ERROR_PARAMETER7;
      if (rssmiq_invalidViBooleanRange (TPCMisuse))
          return VI_ERROR_PARAMETER8;
      if (rssmiq_invalidViReal64Range (TPCPowerStep, -10.0, 10.0))
          return VI_ERROR_INSTR_PARAMETER9;
      if (rssmiq_invalidViInt32Range (transmitDiversity, 0, 2))
          return VI_ERROR_INSTR_PARAMETER10;
      if (rssmiq_invalidViInt32Range (pageIndicatorChannel, 0, 3))
          return VI_ERROR_INSTR_PARAMETER11;
  }

  if (state) {
      CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:BST%ld"
                        ":SCODE #H%lx"
                        ";TFCI %ld"
                        ";TFCI:STAT %s"
                        ";:W3GPP:BST%ld"
                        ":SSCG %ld"
                        ";TPC:READ %s"
                        ";MIS %s"
                        ";POW:STEP %le"
                      ";:W3GPP:BST%ld"
                      ":TRAN:DIV %s"
                      ";:W3GPP:BST%ld"
                      ":PIND:COUN %s"
                      ";:W3GPP:BST%ld"
                      ":STAT ON\n",

                      baseStation,
                      scramblingCode,
                      TFCI,
                      offOnArr[TFCIState],
                      baseStation,
                      secondSCG,
                      tpcrCmd[TPCRead],
                      offOnArr[TPCMisuse],
                      TPCPowerStep,
                      baseStation,
                      tdivCmd[transmitDiversity],
                      baseStation,
                      piccCmd[pageIndicatorChannel],
                      baseStation));
  } else {
      CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:BST%ld:STAT OFF\n", baseStation));
  }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Adjust Power                                              */
/* Purpose:  This function performs ADJUST POWER operation.                  */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppAdjustPower (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  return viPrintf (instrumentHandle, "\n:W3GPP:POW:ADJ\n");
}

/*===========================================================================*/
/* Function: W3GPP Get Power                                                 */
/* Purpose:  This function gets the actual power ratio of the WCDMA/W3GPP    */
/*           module.                                                         */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetPower (ViSession instrumentHandle,
                                       ViReal64 *power)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  return viQueryf (instrumentHandle, "\n:W3GPP:POW?\n", "%le", power);
}

/*===========================================================================*/
/* Function: W3GPP Nulti Channel                                             */
/* Purpose:  This function configures the base station multi channels.       */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMultiChannel (ViSession instrumentHandle,
                                            ViInt32 startChannel,
                                            ViInt32 stopChannel,
                                            ViInt32 symbolRate,
                                            ViInt32 pilotFieldLength,
                                            ViInt32 channelizationCode,
                                            ViInt32 channelCodeStep,
                                            ViReal64 channelPower,
                                            ViReal64 channelPowerStep,
                                            ViInt32 dataSource,
                                            ViString dataPattern,
                                            ViInt32 timingOffset,
                                            ViInt32 timingOffsetStep,
                                            ViInt32 TPCDataSource,
                                            ViString TPCDataPattern,
                                            ViBoolean multicode,
                                            ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  plenCmd[] = {"BIT2", "BIT4", "BIT8", "BIT16"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return RSSMIQ_ERROR_INSTR_PARAMETER17;

  if (state) {
    if (rssmiq_invalidViInt32Range (startChannel, 11, 138))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (stopChannel, 11, 138))
          return VI_ERROR_PARAMETER3;
      if (startChannel > stopChannel)
        return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViInt32Range (symbolRate, 0, 7))
          return VI_ERROR_PARAMETER4;
      if (rssmiq_invalidViInt32Range (pilotFieldLength, 0, 3))
          return VI_ERROR_PARAMETER5;
      if (rssmiq_invalidViInt32Range (channelizationCode, 0, 511))
          return VI_ERROR_PARAMETER6;
      if (rssmiq_invalidViInt32Range (channelCodeStep, 0, 511))
          return VI_ERROR_PARAMETER7;
      if (rssmiq_invalidViReal64Range (channelPower, -60.0, 0.0))
          return VI_ERROR_PARAMETER8;
      if (rssmiq_invalidViReal64Range (channelPowerStep, -60.0, 60.0))
          return VI_ERROR_INSTR_PARAMETER9;
      if (rssmiq_invalidViInt32Range (dataSource, 0, 6))
          return VI_ERROR_INSTR_PARAMETER10;
      if (rssmiq_invalidViInt32Range (timingOffset, 0, 149))
          return VI_ERROR_INSTR_PARAMETER12;
      if (rssmiq_invalidViInt32Range (timingOffsetStep, 0, 149))
          return VI_ERROR_INSTR_PARAMETER13;
      if (rssmiq_invalidViInt32Range (TPCDataSource, 4, 6))
          return VI_ERROR_INSTR_PARAMETER14;
      if (rssmiq_invalidViBooleanRange (multicode))
          return RSSMIQ_ERROR_INSTR_PARAMETER16;
  }

    if (state) {
      p2data = buffer + sprintf (buffer, "\n:W3GP:MCH:STAR %ld"
                         ";STOP %ld"
                         ";SRAT %s"
                         ";PLEN %s"
                         ";CCOD %ld"
                         ";CCOD:STEP %ld"
                         ";:W3GP:MCH:POW %le"
                         ";:W3GP:MCH:POW:STEP %le"
                         ";:W3GP:MCH:DATA %s"
                         ";TIM:OFFS %ld"
                         ";STEP %ld"
                         ";:W3GP:MCH:TPC %s"
                         ";MCOD %s",

                        startChannel,
                        stopChannel,
                        sRateArr[symbolRate],
                        plenCmd[pilotFieldLength],
                        channelizationCode,
                        channelCodeStep,
                        channelPower,
                        channelPowerStep,
                        dSourArr[dataSource],
                        timingOffset,
                        timingOffsetStep,
                        dSourArr[TPCDataSource],
                        offOnArr[multicode]);
    if (dataSource == 6) {
      p2data += sprintf (p2data, ";:W3GP:MCH:DATA:PATT #B%s,%ld", dataPattern, strlen (dataPattern));
    }
      if (TPCDataSource == 6) {
      p2data += sprintf (p2data, ";:W3GP:MCH:TPC:PATT #B%s,%ld", TPCDataPattern, strlen (TPCDataPattern));
      }
      p2data += sprintf (p2data, ";:W3GP:MCH:STAT ON");
    } else {
      p2data = buffer + sprintf (buffer, "\n:W3GPP:MCH:STAT OFF");
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

ViStatus _VI_FUNC rssmiq_w3gppMultiChannelExec (ViSession instrumentHandle,
                                               ViInt32 baseStation)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range(baseStation, 1, 4))
    return VI_ERROR_PARAMETER2;

  return viPrintf (instrumentHandle, "\n:W3GPP:BST%ld:MCH:EXEC\n", baseStation);
}

/*===========================================================================*/
/* Function: W3GPP Base Station Channel                                      */
/* Purpose:  This function configures a base station channel.                */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBStationChannel (ViSession instrumentHandle,
                                               ViInt32 baseStation,
                                               ViInt32 channel,
                                               ViInt32 symbolRate,
                                               ViInt32 channelizationCode,
                                               ViReal64 channelPower,
                                               ViInt32 dataSource,
                                               ViString dataPattern,
                                               ViInt32 timingOffset,
                                               ViInt32 pilotFieldLength,
                                               ViInt32 TPCDataSource,
                                               ViString TPCDataPattern,
                                               ViBoolean multicode,
                                               ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  plenCmd[] = {"BIT2", "BIT4", "BIT8", "BIT16"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_INSTR_PARAMETER13;

  if (state) {
    if (rssmiq_invalidViInt32Range (baseStation, 1, 4))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (channel, 0, 138))
          return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViInt32Range (symbolRate, 0, 7))
          return VI_ERROR_PARAMETER4;
      if (rssmiq_invalidViInt32Range (channelizationCode, 0, 511))
          return VI_ERROR_PARAMETER5;
      if (rssmiq_invalidViReal64Range (channelPower, -60.0, 0.0))
          return VI_ERROR_PARAMETER6;
      if (rssmiq_invalidViInt32Range (dataSource, 0, 6))
          return VI_ERROR_PARAMETER7;
      if (rssmiq_invalidViInt32Range (timingOffset, 0, 149))
          return VI_ERROR_INSTR_PARAMETER9;
      if (rssmiq_invalidViInt32Range (pilotFieldLength, 0, 3))
          return VI_ERROR_INSTR_PARAMETER10;
      if (rssmiq_invalidViInt32Range (TPCDataSource, 4, 6))
        return VI_ERROR_INSTR_PARAMETER11;
      if (rssmiq_invalidViBooleanRange (multicode))
          return VI_ERROR_INSTR_PARAMETER13;
    }

    if (state) {
      p2data = buffer + sprintf (buffer, "\n:W3GP:BST%ld"
                         ":CHAN%ld"
                         ":POW %le",

                        baseStation,
                        channel,
                        channelPower);

      if (channel == 5 || channel == 9 || channel > 10) {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":SRAT %s",

                      baseStation,
                      channel,
                      sRateArr[symbolRate]);
      }

      if (channel == 1 || channel > 4) {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":CCOD %ld",

                      baseStation,
                      channel,
                      channelizationCode);
    }

    switch (channel) {
      case 0: case 1: case 2: case 3: case 7: case 8: case 10: break;
      default:
          p2data += sprintf (p2data, ";:W3GP:BST%ld"
                         ":CHAN%ld"
                         ":DATA %s",

                        baseStation,
                        channel,
                        dSourArr[dataSource]);

        if (dataSource == 6) {
          p2data += sprintf (p2data, ";:W3GP:BST%ld"
                         ":CHAN%ld"
                         ":DATA:PATT #B%s,%ld",

                            baseStation,
                          channel,
                          dataPattern,
                          strlen (dataPattern));
        }
    }

    if ((channel == 5)||(channel==6))
    {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":TOFF %ld",

                      baseStation,
                      channel,
                      timingOffset);
    }

    if (channel > 10) {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":TOFF %ld"
                       ";PLEN %s"
                       ";MCOD %s",

                      baseStation,
                      channel,
                      timingOffset,
                      plenCmd[pilotFieldLength],
                      offOnArr[multicode]);
    }

    if ((channel > 6 && channel < 9) || channel > 9) {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":TPC %s",

                      baseStation,
                      channel,
                      dSourArr[TPCDataSource]);

        if (TPCDataSource == 6) {
        p2data += sprintf (p2data, ";:W3GP:BST%ld"
                       ":CHAN%ld"
                       ":TPC:PATT #B%s,%ld",

                          baseStation,
                        channel,
                        TPCDataPattern,
                        strlen (TPCDataPattern));
        }
    }

    p2data += sprintf (p2data, ";:W3GP:BST%ld"
                   ":CHAN%ld:STAT ON",

                      baseStation,
                    channel);
    } else {
    p2data = buffer + sprintf (buffer, "\n:W3GP:BST%ld"
                       ":CHAN%ld:STAT OFF",

                          baseStation,
                        channel);
    }
    strcat (buffer,"\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Domain Error                                          */
/* Purpose:  This function queries the instrument for the domain error.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetDomainError (ViSession instrumentHandle,
                                             ViInt32 baseStation,
                                             ViBoolean *domainError)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;
  if (rssmiq_invalidViInt32Range (baseStation, 1, 4))
        return VI_ERROR_PARAMETER2;

  return viQueryf (instrumentHandle, "\n:W3GPP:BST%ld:DOM:ERR?\n", "%hu", baseStation, domainError);
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station                                            */
/* Purpose:  This function configures mobile station parameteres.            */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStation (ViSession instrumentHandle,
                                        ViInt32 mobileStation,
                                        ViInt32 mode,
                                        ViInt32 scramblingCode,
                                        ViInt32 scramblingMode,
                                        ViInt32 TPCDataSource,
                                        ViString TPCDataPattern,
                                        ViInt32 TPCRead,
                                        ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  modeCmd[] = {"PRAC", "PCPC", "DPCD"};
  static ViString  smodCmd[] = {"LONG", "SHOR"};
  static ViString  tpcrCmd[] = {"CONT", "S0A", "S1A", "S01A", "S10A"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_INSTR_PARAMETER9;

  if (state) {
    if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (mode, 0, 2))
          return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViInt32Range (scramblingCode, 0, 0xFFFFFF))
          return VI_ERROR_PARAMETER4;
      if (rssmiq_invalidViInt32Range (scramblingMode, 0, 1))
          return VI_ERROR_PARAMETER5;
      if (rssmiq_invalidViInt32Range (TPCDataSource, 4, 7))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (TPCRead, 0, 4))
        return VI_ERROR_PARAMETER8;
    }

    if (state) {
      p2data = buffer + sprintf (buffer, "\n:W3GPP:MST%ld"
                         ":MODE %s"
                         ";SCOD #H%lx"
                         ";SCOD:MODE %s"
                         ";:W3GPP:MST%ld"
                         ":TPC:DATA %s"
                         ";READ %s",

                        mobileStation,
                        modeCmd[mode],
                        scramblingCode,
                        smodCmd[scramblingMode],
                        mobileStation,
                        dSourArr[TPCDataSource],
                        tpcrCmd[TPCRead]);

    if (TPCDataSource == 6) {
      p2data += sprintf (p2data, ";:W3GPP:MST%ld"
                     ":TPC:PATT #B%s,%ld",

                        mobileStation,
                      TPCDataPattern,
                      strlen (TPCDataPattern));
    }
    p2data += sprintf (p2data, ";:W3GPP:MST%ld:STAT ON", mobileStation);
    } else {
    p2data = buffer + sprintf (buffer, "\n:W3GPP:MST%ld:STAT OFF", mobileStation);
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station PRACH Channel                              */
/* Purpose:  This function configures the mobile station PRACH channel.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationPRACHChannel (ViSession instrumentHandle,
                                                    ViInt32 mobileStation,
                                                    ViInt32 repetition,
                                                    ViReal64 preamblePower,
                                                    ViReal64 dataPower,
                                                    ViReal64 controlPower,
                                                    ViInt32 messagePartLength,
                                                    ViInt32 signature,
                                                    ViInt32 ASlot,
                                                    ViInt32 symbolRate,
                                                    ViInt32 dataSource,
                                                    ViString dataPattern,
                                                    ViInt32 TFCI)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (repetition, 0, 10))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (preamblePower, -60.0, 0.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (dataPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (controlPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (messagePartLength, 1, 10))
        return VI_ERROR_PARAMETER7;


    if (rssmiq_invalidViInt32Range (signature, 0, 15))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (ASlot, 0, 14))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (symbolRate, 1, 4))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (dataSource, 0, 6))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (TFCI, 0, 1023))
        return VI_ERROR_INSTR_PARAMETER13;

  p2data = buffer + sprintf (buffer, "\n:W3GPP:MST%ld:PRAC"
                     ":PREP %ld"
                     ";PPOW %le"
                     ";DPOW %le"
                     ";CPOW %le"
                     ";MLEN %ld"
                     ";SIGN %ld"
                     ";ASL %ld"
                     ";SRAT %s"
                     ";DATA %s"
                     ";TFCI %ld",

                    mobileStation,
                    repetition,
                    preamblePower,
                    dataPower,
                    controlPower,
                    messagePartLength,
                    signature,
                    ASlot,
                    sRateArr[symbolRate],
                    dSourArr[dataSource],
                    TFCI);
  if (dataSource == 6) {
    p2data += sprintf (p2data, ";:W3GPP:MST%ld:PRAC"
                   ":PATT #B%s,%ld",

                    mobileStation,
                    dataPattern,
                    strlen (dataPattern));
  }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station PCPCH Channel                              */
/* Purpose:  This function configures the mobile station PCPCH channel.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationPCPCHChannel (ViSession instrumentHandle,
                                                    ViInt32 mobileStation,
                                                    ViInt32 repetition,
                                                    ViReal64 preamblePower,
                                                    ViReal64 preamblePowerStep,
                                                    ViReal64 dataPower,
                                                    ViReal64 controlPower,
                                                    ViInt32 scramblingCodeShared,
                                                    ViInt32 messageLength,
                                                    ViInt32 powerControlPreambleLength,
                                                    ViInt32 signature,
                                                    ViInt32 ASlot,
                                                    ViInt32 FBIMode,
                                                    ViInt32 FBIDataSource,
                                                    ViString FBIDataPattern,
                                                    ViInt32 symbolRate,
                                                    ViInt32 dataSource,
                                                    ViString dataPattern,
                                                    ViInt32 TFCI)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  fbimCmd[] = {"OFF", "D1B", "D2B"};
  static ViString  plenCmd[] = {"S0", "S8"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (repetition, 0, 10))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (preamblePower, -60.0, 0.0))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (preamblePowerStep, 0.0, 10.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (dataPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (controlPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange ((ViBoolean)scramblingCodeShared))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViInt32Range (messageLength, 1, 10))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (powerControlPreambleLength, 0, 1))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (signature, 0, 15))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (ASlot, 0, 14))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViInt32Range (FBIMode, 0, 2))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViInt32Range (FBIDataSource, 4, 6))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViInt32Range (symbolRate, 1, 7))
        return RSSMIQ_ERROR_INSTR_PARAMETER16;
    if (rssmiq_invalidViInt32Range (dataSource, 0, 6))
        return RSSMIQ_ERROR_INSTR_PARAMETER17;
    if (rssmiq_invalidViInt32Range (TFCI, 0, 1023))
        return RSSMIQ_ERROR_INSTR_PARAMETER19;

  p2data = buffer + sprintf (buffer, "\n:W3GPP:MST%ld:PCPC"
                     ":PREP %ld"
                     ";PPOW %le"
                     ";PPOW:STEP %le"
                     ";:W3GPP:MST%ld:PCPC"
                     ":DPOW %le"
                     ";CPOW %le"
                     ";SHAR %s"
                     ";MLEN %ld"
                     ";PLEN %s"
                     ";SIGN %ld"
                     ";ASL %ld"
                     ";FBI:MODE %s"
                     ";DATA %s"
                     ";:W3GPP:MST%ld:PCPC"
                     ":SRAT %s"
                     ";DATA %s"
                     ";TFCI %ld",

                    mobileStation,
                    repetition,
                    preamblePower,
                    preamblePowerStep,
                    mobileStation,
                    dataPower,
                    controlPower,
                    offOnArr[scramblingCodeShared],
                    messageLength,
                    plenCmd[powerControlPreambleLength],
                    signature,
                    ASlot,
                    fbimCmd[FBIMode],
                    dSourArr[FBIDataSource],
                    mobileStation,
                    sRateArr[symbolRate],
                    dSourArr[dataSource],
                    TFCI);
  if (FBIDataSource == 6) {
    p2data += sprintf (p2data, ";:W3GPP:MST%ld:PCPC"
                   ":FBI:PATT #B%s,%ld",

                    mobileStation,
                    FBIDataPattern,
                    strlen (FBIDataPattern));
  }

  if (dataSource == 6) {
    p2data += sprintf (p2data, ";:W3GPP:MST%ld:PCPC"
                   ":PATT #B%s,%ld",

                    mobileStation,
                    dataPattern,
                    strlen (dataPattern));
  }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station DPCCH Channel                              */
/* Purpose:  This function configures the mobile station DPCCH channel.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationDPCCHChannel (ViSession instrumentHandle,
                                                    ViInt32 mobileStation,
                                                    ViReal64 power,
                                                    ViBoolean TFCIState,
                                                    ViInt32 TFCI,
                                                    ViInt32 FBIMode,
                                                    ViInt32 FBIDataSource,
                                                    ViString FBIDataPattern,
                                                    ViBoolean TPCMisuse,
                                                    ViReal64 TPCPowerStep)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  fbimCmd[] = {"OFF", "D1B", "D2B"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (power, -60.0, 0.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (TFCIState))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (TFCI, 0, 1023))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViInt32Range (FBIMode, 0, 2))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (FBIDataSource, 4, 6))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViBooleanRange (TPCMisuse))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViReal64Range (TPCPowerStep, -10.0, 10.0))
        return VI_ERROR_INSTR_PARAMETER10;

  p2data = buffer + sprintf (buffer, "\n:W3GP:MST%ld:DPCC"
                     ":POW %le"
                     ";TFCI %ld"
                     ";TFCI:STAT %s"
                     ";:W3GP:MST%ld:DPCC"
                     ":FBI:MODE %s"
                     ";DATA %s"
                     ";:W3GP:MST%ld:DPCC"
                     ":TPC:MIS %s"
                     ";PST %le",

                    mobileStation,
                    power,
                    TFCI,
                    offOnArr[TFCIState],
                    mobileStation,
                    fbimCmd[FBIMode],
                    dSourArr[FBIDataSource],
                    mobileStation,
                    offOnArr[TPCMisuse],
                    TPCPowerStep);
  if (FBIDataSource == 6) {
    p2data += sprintf (p2data, ";:W3GP:MST%ld:DPCC"
                   ":FBI:PATT #B%s,%ld",

                    mobileStation,
                    FBIDataPattern,
                    strlen (FBIDataPattern));
  }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station DPCCH Timing Offset                        */
/* Purpose:  This function queries the mobile station DPCCH timing offset.   */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationDPCCHToff (ViSession instrumentHandle,
                                                ViInt32 mobileStation,
                                                ViInt32 *timingOffset)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;
  if (rssmiq_invalidViInt32Range(mobileStation, 1, 4))
    return VI_ERROR_PARAMETER2;

  return viQueryf (instrumentHandle, "\n:W3GPP:MST%ld:DPCC:TOFF?\n", "%ld",
                        mobileStation, timingOffset);
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station DPDCH Channel                              */
/* Purpose:  This function configures the mobile station DPDCH channel.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationDPDCH (ViSession instrumentHandle,
                                             ViInt32 mobileStation,
                                             ViReal64 power,
                                             ViInt32 overallSymbolRate)
{
  ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (power, -60.0, 0.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (overallSymbolRate, 1, 12))
        return VI_ERROR_PARAMETER4;

  CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:MST%ld:DPDC"
                    ":POW %le"
                    ";ORAT %s\n",

                    mobileStation,
                    power,
                    sRateArr[overallSymbolRate]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station DPDCH Channel                              */
/* Purpose:  This function configures the mobile station DPDCH channel.      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationDPDCHChannel (ViSession instrumentHandle,
                                                    ViInt32 mobileStation,
                                                    ViInt32 channel,
                                                    ViInt32 dataSource,
                                                    ViString dataPattern)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (channel, 1, 6))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (dataSource, 0, 6))
        return VI_ERROR_PARAMETER4;

  p2data = buffer + sprintf (buffer, "\n:W3GPP:MST%ld"
                     ":DPDC%ld"
                     ":DATA %s",

                    mobileStation,
                    channel,
                    dSourArr[dataSource]);
  if (dataSource == 6) {
    p2data += sprintf (p2data, ";PATT #B%s,%ld", dataPattern, strlen (dataPattern));
  }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Mobile Station DPDCH Parameters                       */
/* Purpose:  This function returns the parameters of the mobile station      */
/*           It requires the option SMIQ-B45 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetMStationDPDCHParam (ViSession instrumentHandle,
                                                     ViInt32 mobileStation,
                                                     ViInt32 channel,
                                                     ViInt32 *symbolRate,
                                                     ViInt32 *type,
                                                     ViInt32 *channelizationCode)
{
    ViStatus    rssmiq_status = VI_SUCCESS;
    ViInt32     tmpRate;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B45));

    if (rssmiq_invalidViInt32Range (mobileStation, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (channel, 1, 6))
        return VI_ERROR_PARAMETER3;
    if (!symbolRate)
        return VI_ERROR_PARAMETER4;
    if (!type)
        return VI_ERROR_PARAMETER5;
    if (!channelizationCode)
        return VI_ERROR_PARAMETER6;


    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:MST%ld:DPDC%ld:SRAT?\n",mobileStation, channel));
    CHECKERR(viScanf(instrumentHandle, "D%ldK", &tmpRate));
    *symbolRate = tmpRate*1000;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:MST%ld:DPDC%ld:TYPE?\n",mobileStation, channel));
    CHECKERR(viScanf(instrumentHandle, "%ld", type));
/*    CHECKERR(rssmiq_getIndexFromString(instrumentHandle, buff, w3gppChannelTypeArr, type));*/

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:MST%ld:DPDC%ld:CCOD?\n", mobileStation,channel));
    CHECKERR(viScanf(instrumentHandle, "%ld", channelizationCode));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Base Station Enhanced Overall Settings                    */
/* Purpose:  This function configures overall settings of the base station   */
/*           enhanced channels module.                                       */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBStationEnhancedOverall (ViSession instrumentHandle,
                                                       ViBoolean coding,
                                                       ViInt32 codingType,
                                                       ViBoolean codingInterleaver1,
                                                       ViBoolean codingInterleaver2,
                                                       ViBoolean extPowerControl,
                                                       ViReal64 extPwrCtrlStep,
                                                       ViReal64 extPwrCtrlRangeUp,
                                                       ViReal64 extPwrCtrlRangeDown,
                                                       ViInt32 radioFrameSeqLength,
                                                       ViInt32 symbolRate,
                                                       ViInt32 timingOffset,
                                                       ViInt32 pilotFieldLength,
                                                       ViBoolean errorInsertion,
                                                       ViReal64 requiredBER,
                                                       ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  static ViString  ctypCmd[] = {"M12K2", "M64K", "M144K", "M384K", "AMR"};
  static ViString  plenCmd[] = {"BIT2", "BIT4", "BIT8", "BIT16"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_INSTR_PARAMETER14;

  if (state) {
    if (rssmiq_invalidViBooleanRange (coding))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (codingType, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (codingInterleaver1))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (codingInterleaver2))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (extPowerControl))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (extPwrCtrlStep, 0.0, 6.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (extPwrCtrlRangeUp, 0.0, 30.0))
        return VI_ERROR_PARAMETER8;
    if (rssmiq_invalidViReal64Range (extPwrCtrlRangeDown, 0.0, 30.0))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssmiq_invalidViInt32Range (radioFrameSeqLength, 1, 1024))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViInt32Range (symbolRate, 0, 7))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssmiq_invalidViInt32Range (timingOffset, 1, 800))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssmiq_invalidViInt32Range (pilotFieldLength, 0, 3))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rssmiq_invalidViBooleanRange (errorInsertion))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rssmiq_invalidViReal64Range (requiredBER, 1.0E-7, 1.0E-1))
        return VI_ERROR_INSTR_PARAMETER15;
    }

    if (state) {
    CHECKERR (viPrintf (instrumentHandle,  "\n:W3GPP:BST:ENH:CCOD:TYPE %s"
                       ";STAT %s"
                       ";INT1 %s"
                       ";INT2 %s"
                       ";:W3GPP:BST:ENH:EPOW:STAT %s"
                       ";STEP %le"
                       ";RANG:UP %le"
                       ";DOWN %le"
                       ";:W3GPP:BST:ENH:SLEN %ld"
                       ";SRAT %s"
                       ";TOFF %ld"
                       ";PLEN %s"
                       ";:W3GPP:BST:ENH:DERR:STAT %s"
                       ";RATE %le;:W3GPP:BST:ENH:STAT ON\n",

                      ctypCmd[codingType],
                      offOnArr[coding],
                      offOnArr[codingInterleaver1],
                      offOnArr[codingInterleaver2],
                      offOnArr[extPowerControl],
                      extPwrCtrlStep,
                      extPwrCtrlRangeUp,
                      extPwrCtrlRangeDown,
                      radioFrameSeqLength,
                      sRateArr[symbolRate],
                      timingOffset,
                      plenCmd[pilotFieldLength],
                      offOnArr[errorInsertion],
                      requiredBER));
  } else {
    CHECKERR (viPrintf (instrumentHandle,  "\n:W3GPP:BST:ENH:STAT OFF\n"));
  }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Base Station Enhanced Channel                             */
/* Purpose:  This function configures the base station enhanced channel.     */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBStationEnhancedChannel (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 channelizationCode,
                                                       ViBoolean coding,
                                                       ViReal64 startPower,
                                                       ViInt32 powerControl,
                                                       ViInt32 dataSource,
                                                       ViString dataPattern,
                                                       ViString dataList,
                                                       ViInt32 TPCDataSource,
                                                       ViString TPCDataPattern,
                                                       ViString TPCDataList,
                                                       ViBoolean multicode,
                                                       ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  pconCmd[] = {"OFF", "UP", "DOWN"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_INSTR_PARAMETER14;

  if (state) {
    if (rssmiq_invalidViInt32Range (channel, 11, 14))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (channelizationCode, 0, 511))
          return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViBooleanRange (coding))
          return VI_ERROR_PARAMETER4;
      if (rssmiq_invalidViReal64Range (startPower, -60.0, 0.0))
          return VI_ERROR_PARAMETER5;
      if (rssmiq_invalidViInt32Range (powerControl, 0, 2))
          return VI_ERROR_PARAMETER6;
      if (rssmiq_invalidViInt32Range (dataSource, 0, 7))
          return VI_ERROR_PARAMETER7;
      if (rssmiq_invalidViInt32Range (TPCDataSource, 4, 7))
          return VI_ERROR_INSTR_PARAMETER10;
    if (rssmiq_invalidViBooleanRange (multicode))
        return VI_ERROR_INSTR_PARAMETER13;
  }

    if (state) {
    p2data = buffer + sprintf (buffer, "\n:W3GP:BST:ENH:CHAN%ld"
                       ":CHNC %ld"
                       ";CCOD %s"
                       ";POW:STAR %le"
                       ";CONT %s"
                       ";:W3GP:BST:ENH:CHAN%ld"
                       ":DATA %s"
                       ";TPC %s"
                       ";MCOD %s",

                      channel,
                      channelizationCode,
                      offOnArr[coding],
                      startPower,
                      pconCmd[powerControl],
                      channel,
                      dSourArr[dataSource],
                      dSourArr[TPCDataSource],
                      offOnArr[multicode]);
    switch (dataSource) {
      case 6:
        p2data += sprintf (p2data, ";:W3GP:BST:ENH:CHAN%ld"
                       ":DATA:PATT #B%s,%ld",

                        channel,
                        dataPattern,
                        strlen (dataPattern));
      break;
      case 7:
        p2data += sprintf (p2data, ";:W3GP:BST:ENH:CHAN%ld"
                       ":DATA:DSEL \"%s\"",

                        channel,
                        dataList);
      break;
    }

    switch (TPCDataSource) {
      case 6:
        p2data += sprintf (p2data, ";:W3GP:BST:ENH:CHAN%ld"
                       ":TPC:PATT #B%s,%ld",

                        channel,
                        TPCDataPattern,
                        strlen (TPCDataPattern));
      break;
      case 7:
        p2data += sprintf (p2data, ";:W3GP:BST:ENH:CHAN%ld"
                       ":TPC:DSEL \"%s\"",

                        channel,
                        TPCDataList);
      break;
    }
    p2data += sprintf (p2data, ";:W3GP:BST:ENH:CHAN%ld:STAT ON", channel);

  } else {
    p2data = buffer + sprintf (buffer, "\n:W3GP:BST:ENH:CHAN%ld:STAT OFF", channel);
    }
    strcat (buffer,"\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station Enhanced Overall Settings                  */
/* Purpose:  This function configures the overall settings of the mobile     */
/*           station enhanced channels.                                      */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationEnhancedOverall (ViSession instrumentHandle,
                                                       ViBoolean coding,
                                                       ViInt32 codingType,
                                                       ViBoolean codingInterleaver1,
                                                       ViBoolean codingInterleaver2,
                                                       ViBoolean extPowerControl,
                                                       ViReal64 DPCCHStartPower,
                                                       ViReal64 DPDCHStartPower,
                                                       ViReal64 extPwrCtrlStep,
                                                       ViReal64 extPwrCtrlRangeUp,
                                                       ViReal64 extPwrCtrlRangeDown,
                                                       ViInt32 radioFrameSeqLength,
                                                       ViInt32 overallSymbolRate,
                                                       ViBoolean DPCCHState,
                                                       ViBoolean errorInsertion,
                                                       ViReal64 requiredBER,
                                                       ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  static ViString  ctypCmd[] = {"M12K2", "M64K", "M144K", "M384K", "AMR"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (rssmiq_invalidViBooleanRange (state))
        return RSSMIQ_ERROR_INSTR_PARAMETER17;

  if (state) {
    if (rssmiq_invalidViBooleanRange (coding))
          return VI_ERROR_PARAMETER2;
      if (coding) {
        if (rssmiq_invalidViInt32Range (codingType, 0, 4))
            return VI_ERROR_PARAMETER3;
        if (rssmiq_invalidViBooleanRange (codingInterleaver1))
            return VI_ERROR_PARAMETER4;
        if (rssmiq_invalidViBooleanRange (codingInterleaver2))
            return VI_ERROR_PARAMETER5;
    }
      if (rssmiq_invalidViBooleanRange (extPowerControl))
          return VI_ERROR_PARAMETER6;
      if (extPowerControl) {
        if (rssmiq_invalidViReal64Range (DPCCHStartPower, -60.0, 0.0))
            return VI_ERROR_PARAMETER7;
        if (rssmiq_invalidViReal64Range (DPDCHStartPower, -60.0, 0.0))
            return VI_ERROR_PARAMETER8;
        if (rssmiq_invalidViReal64Range (extPwrCtrlStep, 0.0, 6.0))
            return VI_ERROR_INSTR_PARAMETER9;
        if (rssmiq_invalidViReal64Range (extPwrCtrlRangeUp, 0.0, 30.0))
            return VI_ERROR_INSTR_PARAMETER10;
        if (rssmiq_invalidViReal64Range (extPwrCtrlRangeDown, 0.0, 30.0))
            return VI_ERROR_INSTR_PARAMETER11;
      }
      if (rssmiq_invalidViInt32Range (radioFrameSeqLength, 1, 1024))
          return VI_ERROR_INSTR_PARAMETER12;
      if (rssmiq_invalidViInt32Range (overallSymbolRate, 1, 12))
          return VI_ERROR_INSTR_PARAMETER13;
      if (rssmiq_invalidViBooleanRange (DPCCHState))
          return VI_ERROR_INSTR_PARAMETER14;
      if (rssmiq_invalidViBooleanRange (errorInsertion))
          return VI_ERROR_INSTR_PARAMETER15;
      if (rssmiq_invalidViReal64Range (requiredBER, 1.0E-7, 1.0E-1))
          return RSSMIQ_ERROR_INSTR_PARAMETER16;
  }

    if (state) {
    p2data = buffer + sprintf (buffer, "\n:W3GPP:MST:ENH:CCOD:STAT %s"
                       ";:W3GPP:MST:ENH:EPOW:STAT %s"
                       ";:W3GPP:MST:ENH:SLEN %ld"
                       ";:W3GPP:MST:ENH:ORAT %s"
                       ";:W3GPP:MST:ENH:DPCC:STAT %s"
                       ";:W3GPP:MST:ENH:DERR:BIT:STAT %s"
                       ";:W3GPP:MST:ENH:DERR:BIT:RATE %le",

                      offOnArr[coding],
                      offOnArr[extPowerControl],
                      radioFrameSeqLength,
                      sRateArr[overallSymbolRate],
                      offOnArr[DPCCHState],
                      offOnArr[errorInsertion],
                      requiredBER);

    if (coding) {
      p2data += sprintf (p2data, ";:W3GPP:MST:ENH:CCOD:TYPE %s"
                     ";INT1 %s"
                     ";INT2 %s",

                    ctypCmd[codingType],
                    offOnArr[codingInterleaver1],
                    offOnArr[codingInterleaver2]);
    }

    if (extPowerControl) {
      p2data += sprintf (p2data, ";:W3GPP:MST:ENH:EPOW:STAR:DPCC %le"
                     ";DPDC %le"
                     ";:W3GPP:MST:ENH:EPOW:STEP %le"
                       ";RANG:UP %le"
                       ";DOWN %le",

                    DPCCHStartPower,
                    DPDCHStartPower,
                    extPwrCtrlStep,
                    extPwrCtrlRangeUp,
                    extPwrCtrlRangeDown);
    }

    p2data += sprintf (p2data, ";:W3GPP:MST:ENH:STAT ON");

  } else {
    p2data = buffer + sprintf (buffer, "\n:W3GPP:MST:ENH:STAT OFF");
    }
    strcat (buffer,"\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Mobile Station Enhanced Channel                           */
/* Purpose:  This function configures the mobile station enhanced channels.  */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationEnhancedChannel (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 dataSource,
                                                       ViString dataPattern,
                                                       ViString dataList)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (channel, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (dataSource, 0, 7))
        return VI_ERROR_PARAMETER3;

  p2data = buffer + sprintf (buffer, "\n:W3GPP:MST:ENH:CHAN%ld"
                     ":DATA %s",

                    channel,
                    dSourArr[dataSource]);
  switch (dataSource) {
    case 6:
      p2data += sprintf (p2data, ";DATA:PATT #B%s,%ld", dataPattern, strlen (dataPattern));
    break;
    case 7:
      p2data += sprintf (p2data, ";DATA:DSEL \"%s\"", dataList);
  }
    strcat (buffer,"\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Configure Enhanced Channel                                */
/* Purpose:  This function configures enhanced properties of channel.        */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppConfigureEnhancedChannel (ViSession instrumentHandle,
                                                        ViInt32 station,
                                                        ViInt32 channel,
                                                        ViInt32 channelType,
                                                        ViInt32 dataSource,
                                                        ViInt32 pattern,
                                                        ViChar dataList[])
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar   tmpCommand[BUFFER_SIZE];
    ViChar   tmpPattern[30];
    ViUInt32 bit;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    /*- Check parameter ranges ----------------------------------------------*/
    if (rssmiq_invalidViInt32Range (station, 0, 1))
        return VI_ERROR_PARAMETER2;

    if (station == RSSMIQ_W3GP_STATION_BASE)
    {
        if (rssmiq_invalidViInt32Range (channel, 11, 14) && (channel != 4))
            return VI_ERROR_PARAMETER3;
    }
    else
        if (rssmiq_invalidViInt32Range (channel, 0, 6))
            return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (channelType, 0, 1))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (dataSource, 0, 7))
        return VI_ERROR_PARAMETER5;
    if ((dataSource == RSSMIQ_DSOURCE_PATT) && (!pattern))
        return VI_ERROR_PARAMETER6;
    if ((dataSource == RSSMIQ_DSOURCE_DLIS) && (!dataList))
        return VI_ERROR_PARAMETER7;

    /*TmpCommand = :SOUR:W3GP:MST|BST:ENH:CHAN<i>:DTCH|DCCH*/
    sprintf(tmpCommand, "\n:SOUR:W3GP:%s:ENH:CHAN%ld:%s",
            stationArr[station], channel, w3gpchanTypeArr[channelType]);
    /*selects the data source for channel*/
    CHECKERR(viPrintf(instrumentHandle, "\n%s %s\n", tmpCommand, dSourArr[dataSource]));
    /*select the pattern or data list*/
    switch (dataSource){
        case RSSMIQ_DSOURCE_PATT:
            sprintf(tmpPattern, "%X", pattern);
            for(bit = 0;bit < 32; bit++)
                if(pattern&(1<<(31-bit)))
                    break;
            CHECKERR(viPrintf(instrumentHandle, "%s:PATT #H%s,%ld\n", tmpCommand, tmpPattern, 32-bit));
            break;
        case RSSMIQ_DSOURCE_DLIS:
            CHECKERR(viPrintf(instrumentHandle, "%s:DSEL '%s'\n", tmpCommand, dataList));
            break;
        default:
            break;
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Mobile Station Enhanced Parameter                     */
/* Purpose:  This function returns the parameters of selected mobile         */
/*           station and channel.                                            */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetMStationEnhParam (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32 *symbolRate,
                                                   ViInt32 *channelizationCode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32  tempRate;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;
    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    /*- Check parameter ranges ----------------------------------------------*/
    if (rssmiq_invalidViInt32Range (channel, 0, 6))
        return VI_ERROR_PARAMETER2;
    if (!symbolRate)
        return VI_ERROR_PARAMETER3;
    if (!channelizationCode)
        return VI_ERROR_PARAMETER4;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:MST:ENH:CHAN%ld:SRAT?\n", channel));
    CHECKERR(viScanf(instrumentHandle, "D%ldK", &tempRate));
    *symbolRate = tempRate * 1000;
    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:MST:ENH:CHAN%ld:CHNC?\n", channel));
    CHECKERR(viScanf(instrumentHandle, "%ld", channelizationCode));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Get Free Frame Memory                                     */
/* Purpose:  This function queries the free memory for storing frame data.   */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetFreeFrameMem (ViSession instrumentHandle,
                                              ViInt32 *freeFrames)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  return viQueryf (instrumentHandle, "\n:W3GPP:BST:ENH:SLEN:FREE?\n", "%ld", freeFrames);
}

/*===========================================================================*/
/* Function: W3GPP Get Actual BER                                            */
/* Purpose:  This function queries the actual achieved BER value.            */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppGetActualBER (ViSession instrumentHandle,
                                           ViInt32 station,
                                           ViReal64 *actualBER)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (station, 0, 1))
        return VI_ERROR_PARAMETER2;

  return viQueryf (instrumentHandle, "\n:W3GPP:%s:ENH:DERR:RRAT?\n", "%le",
                  (station == 0) ? "BST" : "MST", actualBER);
}

/*===========================================================================*/
/* Function: W3GPP Get Actual BER                                            */
/* Purpose:  This function queries the actual achieved BER value.            */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBaseStationOCNSState (ViSession instrumentHandle,
                                                    ViBoolean state)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check option --------------------------------------------------------*/
    CHECKERR (rssmiq_checkOption(instrumentHandle, RSSMIQ_OPT_B48));

    /*- Check parameter ranges ----------------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:W3GP:BST:OCNS:STAT %s\n", offOnArr[state]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: W3GPP Base Station OCNS                                         */
/* Purpose:  This function configures the orthogonal channel noise source    */
/*           (OCNS) for enhanced channels. Settings performed by this        */
/*           function apply only to base station 1 set to forward link.      */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppBStationOCNS (ViSession instrumentHandle,
                                            ViInt32 symbolRate,
                                            ViInt32 count,
                                            ViInt32 crestFactor,
                                            ViReal64 OCNSPower,
                                            ViBoolean PCCPCHState,
                                            ViReal64 PCCPCHPower,
                                            ViReal64 enhancedChannelsPower)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  static ViString  cfacCmd[] = {"MIN", "AVER", "WORS"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViInt32Range (symbolRate, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (count, 1, 508))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (crestFactor, 0, 2))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViReal64Range (OCNSPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (PCCPCHState))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViReal64Range (PCCPCHPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER7;
    if (rssmiq_invalidViReal64Range (enhancedChannelsPower, -60.0, 0.0))
        return VI_ERROR_PARAMETER8;

  CHECKERR (viPrintf (instrumentHandle, "\n:W3GP:BST:OCNS:SRAT %s"
                      ";COUN %ld"
                      ";CRES %s"
                      ";POW %le"
                      ";EPOW %le"
                      ";PCCPCH:STAT %s"
                      ";POW %le;:W3GP:BST:OCNS:EXEC\n",

                       sRateArr[symbolRate],
                       count,
                       cfacCmd[crestFactor],
                       OCNSPower,
                       enhancedChannelsPower,
                       offOnArr[PCCPCHState],
                       PCCPCHPower));

    return rssmiq_status;
}


/*===========================================================================*/
/* Function: W3GPP Mobile Station Additional                                 */
/* Purpose:  This function configures additional mobile stations.            */
/*           It requires the option SMIQ-B48 installed in the instrument.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_w3gppMStationAdditional (ViSession instrumentHandle,
                                                  ViInt32 count,
                                                  ViInt32 SCInitIncrement,
                                                  ViReal64 powerOffset,
                                                  ViBoolean state)
{
  ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  if (rssmiq_invalidViBooleanRange (state))
      return VI_ERROR_PARAMETER5;
  if (state) {
    if (rssmiq_invalidViInt32Range (count, 1, 50))
          return VI_ERROR_PARAMETER2;
      if (rssmiq_invalidViInt32Range (SCInitIncrement, 1, 0x100))
          return VI_ERROR_PARAMETER3;
      if (rssmiq_invalidViReal64Range (powerOffset, -20.0, 20.0))
          return VI_ERROR_PARAMETER4;
  }

    if (state) {
    CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:MST:ADD:COUN %ld"
                       ";SCOD:STEP #H%lx"
                       ";:W3GPP:MST:ADD:POW:OFFS %le;:W3GPP:MST:ADD:STAT ON\n",

                      count,
                      SCInitIncrement,
                      powerOffset));
  } else {
    CHECKERR (viPrintf (instrumentHandle, "\n:W3GPP:MST:ADD:STAT OFF\n"));
  }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Noise Distortion Simulator                                      */
/* Purpose:  This function controls settings of the noise generator and the  */
/*           distortion simulator. It requires the noise generator and       */
/*           distortion simulator option be installed in the instrument.     */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_noiseDistSim (ViSession instrumentHandle, ViBoolean noise,
                    ViReal64 c2n, ViReal64 systemBandwidth, ViBoolean distortion)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 esr = 0;
    rssmiq_instrRange   instrPtr;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (noise))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (c2n, -30.0, 30.0))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (systemBandwidth, 10.0, 10000.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:SOUR:NOIS %s"
                          ";:SOUR:NOIS:SNR %leDB"
                          ";:SOUR:NOIS:BAND %fKHZ"
                            ";*OPC\n",
                            offOnArr[noise],
                            c2n,
                            systemBandwidth));
    }
    else
    {
        if (rssmiq_invalidViBooleanRange (distortion))
            return VI_ERROR_PARAMETER5;

        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:SOUR:NOIS %s"
                          ";:SOUR:NOIS:SNR %leDB"
                          ";:SOUR:NOIS:BAND %fKHZ"
                            ";:SOUR:DIST %s;*OPC\n",

                            offOnArr[noise],
                            c2n,
                            systemBandwidth,
                            offOnArr[distortion]));

        if (distortion) {
          while ((esr & 1) == 0) {
            Delay (2.0);
            CHECKERR (viQueryf (instrumentHandle, "*ESR?", "%ld", &esr));
          }
        }
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Characteristics                                      */
/* Purpose:  This function manages characteristics of the distortion     */
/*           simulator. It requires the noise generator and distortion       */
/*           simulator option be installed in the instrument.            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distCharact (ViSession instrumentHandle, ViInt32 action,
               ViString name, ViReal64 am2amx[],
               ViReal64 am2amy[], ViInt32 numAM2AMElements,
               ViReal64 am2pmx[], ViReal64 am2pmy[],
               ViInt32 numAM2PMElements)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE+100];
    ViInt32 i, esr = 0;
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (numAM2AMElements, 5, 30))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (numAM2PMElements, 5, 30))
        return VI_ERROR_INSTR_PARAMETER9;

    switch (action) {
        case 0:
            /* Select an existing characteristic*/
            CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:SOUR:DIST:DATA:SEL \"%s\";*OPC\n", name));
        break;
        case 1:
            /* Create a new characteristic*/
            p2data = buffer + sprintf (buffer, "\n*CLS;:SOUR:DIST:DATA:SEL \"%s\"", name);

            p2data += sprintf (p2data, ";:SOUR:DIST:DATA:AMB ");
            for (i=0; i<numAM2AMElements; i++) {
                p2data += sprintf (p2data, "%.2f,", am2amx[i]);
            }
            *(--p2data) = '\0';

            p2data += sprintf (p2data, ";:SOUR:DIST:DATA:AM ");
            for (i=0; i<numAM2AMElements; i++) {
                p2data += sprintf (p2data, "%.2f,", am2amy[i]);
            }
            *(--p2data) = '\0';

            p2data += sprintf (p2data, ";:SOUR:DIST:DATA:PMB ");
            for (i=0; i<numAM2PMElements; i++) {
                p2data += sprintf (p2data, "%.2f,", am2pmx[i]);
            }
            *(--p2data) = '\0';

            p2data += sprintf (p2data, ";:SOUR:DIST:DATA:PM ");
            for (i=0; i<numAM2PMElements; i++) {
                p2data += sprintf (p2data, "%.2f,", am2pmy[i]);
            }
            *(--p2data) = '\0';

            p2data += sprintf (p2data, ";*OPC\n");

        CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));
        break;
        case 2:
            /* Delete an existing characteristic*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:DATA:DEL \"%s\"\n", name));
        break;
        case 3:
            /* Delete all existing characteristics*/
            CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:DATA:DEL:ALL\n"));
        break;
    }

    if (action  < 2) {
      while ((esr & 1) == 0) {
        Delay (2.0);
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
      }
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Catalog                                          */
/* Purpose:  This Function returns a list with the names of all        */
/*       characteristics stored in the unit.               */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distCatalog (ViSession instrumentHandle, ViInt32 size,
                                      ViChar list[], ViInt32 *listLength)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    if (size <= 0) return VI_ERROR_PARAMETER2;

    if (!list) return VI_ERROR_PARAMETER3;

  CHECKERR (viQueryf (instrumentHandle, "\n:SOUR:DIST:DATA:CAT?\n", "%#s",
                     &size, list));

  if (listLength) *listLength = size;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Distortion Data Memory Info                                 */
/* Purpose:  This Function queries for distortion data memory info.      */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distMemInfo (ViSession instrumentHandle, ViBoolean modulation,
                    ViPInt32 remainCap, ViPInt32 occupCap,
                    ViPInt32 outLength, ViPInt32 inLength)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViByte *buffer;
    ViInt32 tmpRemainCap,
        tmpOccupCap,
      tmpOutLength,
      tmpInLength;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (modulation))
        return VI_ERROR_PARAMETER2;

    if (modulation == 0)
      buffer = "\n:SOUR:DIST:DATA:AM:FREE?;:SOUR:DIST:DATA:AM:POIN?;:SOUR:DIST:DATA:AMB:POIN?\n";
    else
      buffer = "\n:SOUR:DIST:DATA:PM:FREE?;:SOUR:DIST:DATA:PM:POIN?;:SOUR:DIST:DATA:PMB:POIN?\n";

    CHECKERR (viQueryf (instrumentHandle, buffer, "%ld,%ld;%ld;%ld",
                          &tmpRemainCap, &tmpOccupCap, &tmpOutLength, &tmpInLength));

    if (remainCap) *remainCap = tmpRemainCap;
    if (occupCap)  *occupCap  = tmpOccupCap;
    if (outLength) *outLength = tmpOutLength;
    if (inLength)  *inLength  = tmpInLength;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Mode                                           */
/* Purpose:  This function sets the distortion mode and level correction.  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distMode (ViSession instrumentHandle, ViInt32 mode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
  ViChar buffer[BUFFER_SIZE];
  ViString p2data;
  ViInt32 esr = 0;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (mode, 0, 1))
        return VI_ERROR_PARAMETER2;

  p2data = buffer + sprintf (buffer, "\n*CLS;:SOUR:DIST:MODE %s", dataPolyArr[mode]);

  p2data +=  sprintf (p2data, ";*OPC\n");


    CHECKERR (viWrite (instrumentHandle, buffer, p2data - buffer, 0));

    while ((esr & 1) == 0) {
      Delay (2.0);
      CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Polynomial Coef                                    */
/* Purpose:  This Function sets the polynomial coeficient k2 to k5.        */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distPolyCoef (ViSession instrumentHandle, ViInt32 mode,
                     ViInt32 coef, ViReal64 value)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViReal64 max = 10.0;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (mode, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (coef, 2, 5))
        return VI_ERROR_PARAMETER3;

    if (mode != 0) max = 60.0;

    if (rssmiq_invalidViReal64Range (value, -max, max))
        return VI_ERROR_PARAMETER4;

    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:POLY:AM%s:K%ld %.2Lf\n",
                       (mode == 0) ? "AM" : "PM", coef, value));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Recalculate                                          */
/* Purpose:  This Function recalculates the distortion data.                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distRecalculate (ViSession instrumentHandle)
{
  ViStatus rssmiq_status = VI_SUCCESS;
  ViInt32 esr = 0;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:SOUR:DIST:REC;*OPC\n"));

    while ((esr & 1) == 0) {
      Delay (2.0);
      CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
    }

  return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Level Correction                                     */
/* Purpose:  This function sets the level correction.            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distLevCorrect (ViSession instrumentHandle, ViInt32 mode,
                     ViReal64 level)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (mode, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViReal64Range (level, -20, 6))
        return VI_ERROR_PARAMETER3;

  if (mode == 0) {
    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:DATA:LEV:CORR %.2Lf\n",level));
  }
  if (mode == 1) {
    CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:POLY:LEV:CORR %.2Lf\n",level));
  }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Distortion Inversion Function                                   */
/* Purpose:  This function svitches ON/OFF the iversion of the distortion    */
/*           charakteristic.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_distInvFunc (ViSession instrumentHandle, ViBoolean inversion)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

  CHECKERR (viPrintf (instrumentHandle, "\n:SOUR:DIST:POLY:IFUN %s\n",offOnArr[inversion]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Set Arb                                               */
/* Purpose:  This Function switches the arbitrary waveform generator on/off. */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_setArb (ViSession instrumentHandle, ViBoolean state,
                 ViInt32 sequence)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 esr = 0;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (sequence, 0, 3))
        return VI_ERROR_PARAMETER3;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:BB:ARB:STAT %s;:BB:ARB:SEQ %s;*OPC\n", offOnArr[state], arbSeqArr[sequence]));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:ARB:STAT %s;:ARB:SEQ %s;*OPC\n", offOnArr[state], arbSeqArr[sequence]));
    }

    while ((esr & 1) == 0)
    {
        Delay (2.0);
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Arb Catalog                                           */
/* Purpose:  This Function returns a list of all waveforms stored in the unit*/
/*         and number of waveforms in the list.              */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getArbCatalog (ViSession instrumentHandle, ViInt32 buffSize,
                    ViPInt32 number, ViChar _VI_FAR list[])
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (buffSize <= 0) return VI_ERROR_PARAMETER2;

    if (instrPtr->instrType)
    {
        if (number)
        {
            CHECKERR (viQueryf (instrumentHandle, "\n:BB:ARB:WAV:CAT:LENG?\n", "%ld", number));
        }

        if (list)
        {
            CHECKERR (viQueryf (instrumentHandle, "\n:BB:ARB:WAV:CAT?\n", "%#s", &buffSize, list));
        }
    }
    else
    {
        if (number)
        {
            CHECKERR (viQueryf (instrumentHandle, "\n:ARB:WAV:CAT:LENG?\n", "%ld", number));
        }

        if (list)
        {
            CHECKERR (viQueryf (instrumentHandle, "\n:ARB:WAV:CAT?\n", "%#s", &buffSize, list));
        }
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Arb Data Memory Info                                  */
/* Purpose:  This function queries for free memory space and for the number  */
/*         of samples contained in a waveform.               */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getArbMemInfo (ViSession instrumentHandle, ViPInt32 freeSpace,
                    ViPInt32 numOfSamples)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 tmpFreeSpace,
        tmpNumOfSamples;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
    {
        CHECKERR (viQueryf (instrumentHandle, "\n:BB:ARB:WAV:POIN?\n", "%ld",
                            &tmpNumOfSamples));
    }
    else
    {
        CHECKERR (viQueryf (instrumentHandle, "\n:ARB:WAV:FREE?;:ARB:WAV:POIN?\n", "%ld;%ld",
                                &tmpFreeSpace, &tmpNumOfSamples));
        if (freeSpace) *freeSpace = tmpFreeSpace;
    }

    if (numOfSamples) *numOfSamples = tmpNumOfSamples;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Arb Trigger                                         */
/* Purpose:  This function configures the arbitrary trigger.         */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbTrigger (ViSession instrumentHandle, ViBoolean source,
                   ViInt32 delay, ViInt32 inhibit)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (delay, 0, 65535))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (inhibit, 0, 67100000))
        return VI_ERROR_PARAMETER4;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:BB:ARB:TRIG:SOUR %s;:BB:ARB:TRIG:DEL %ld;:ARB:TRIG:INH %ld\n",
                  intExtArr[source], delay, inhibit));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n:ARB:TRIG:SOUR %s;:ARB:TRIG:DEL %ld;:ARB:TRIG:INH %ld\n",
                  intExtArr[source], delay, inhibit));
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Arb Trigger Output                                      */
/* Purpose:  This function configures the arbitrary trigger output.      */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbTriggerOut (ViSession instrumentHandle, ViInt32 output,
                    ViBoolean polarity, ViInt32 delay,
                    ViString mode, ViInt32 onTime,
                    ViInt32 offTime)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (output, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (delay, 0, 524255))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (onTime, 0, 524255))
        return VI_ERROR_PARAMETER6;
    if (rssmiq_invalidViInt32Range (offTime, 0, 524255))
        return VI_ERROR_PARAMETER7;

    if (instrPtr->instrType)
    {
        p2data = buffer + sprintf (buffer, "\n:BB:ARB:TRIG:OUTP%ld:DEL %ld"
                           ";:BB:ARB:TRIG:OUTP%ld:MODE %s",
                          output, delay,
                          output, mode);

        if (strstr (mode, "USER"))
        {
          p2data += sprintf (p2data, ";:BB:ARB:TRIG:OUTP%ld:ONT %ld"
                         ";:BB:ARB:TRIG:OUTP%ld:OFFT %ld",
                        output, onTime,
                        output, offTime);
        }
    }
    else
    {
        if (rssmiq_invalidViBooleanRange (polarity))
            return VI_ERROR_PARAMETER3;

        p2data = buffer + sprintf (buffer, "\n:ARB:TRIG:OUTP%ld:POL %s"
                           ";:ARB:TRIG:OUTP%ld:DEL %ld"
                           ";:ARB:TRIG:OUTP%ld:MODE \"%s\"",

                          output, negPosArr[polarity],
                          output, delay,
                          output, mode);

        if (strstr (mode, "USER"))
        {
          p2data += sprintf (p2data, ";:ARB:TRIG:OUTP%ld:ONT %ld"
                         ";:ARB:TRIG:OUTP%ld:OFFT %ld",

                        output, onTime,
                        output, offTime);
        }
    }
    strcat (buffer, "\n");
  CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get Arb Trigger Output Catalog                                  */
/* Purpose:  This Function returns a list of all available modes.      */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getArbTriggOutCatalog (ViSession instrumentHandle,
                                                ViInt32 output,
                                                ViChar list[],
                                                ViInt32 size,
                                                ViInt32 *listLength)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));
    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (output, 1, 2))
        return VI_ERROR_PARAMETER2;

    if (!list) return VI_ERROR_PARAMETER3;

    if (size <=0) return VI_ERROR_PARAMETER4;

    CHECKERR (viQueryf (instrumentHandle, "\n:ARB:TRIG:OUTP%ld:MODE:CAT?\n", "%#s", output, &size, list));

    if (listLength) *listLength = size;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Arb Automatic Setting                                     */
/* Purpose:  This function configures the arbitrary automatic setting.     */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbAutoSetting (ViSession instrumentHandle,
                                         ViBoolean state,
                                         ViBoolean iqFilter,
                                         ViBoolean iqSwap,
                                         ViBoolean type,
                                         ViBoolean mode)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (iqFilter))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (iqSwap))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (type))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (mode))
        return VI_ERROR_PARAMETER6;

    CHECKERR (viPrintf (instrumentHandle, "\n:ARB:ASET:STAT %s;:"
                      "ARB:ASET:DM:IQF %s"
                      ";:ARB:ASET:DM:IQSW %s"
                      ";:ARB:ASET:BERT:TYPE %s"
                      ";:ARB:ASET:TRIG:MODE %s\n",

                      offOnArr[state],
                      offOnArr[iqFilter],
                      offOnArr[iqSwap],
                      offOnArr[type],
                      offOnArr[mode]));
    return rssmiq_status;
}


/*===========================================================================*/
/* Function: Arb Clock                                           */
/* Purpose:  This function configures the arbitrary sample clock.      */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbClock (ViSession instrumentHandle, ViReal64 clock,
                    ViBoolean source, ViReal64 delay)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViReal64Range (clock, 1.0E+3, 40.0E+6))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViReal64Range (delay, 0.0, 0.99))
        return VI_ERROR_PARAMETER4;

    if (instrPtr->instrType)
    {
        p2data = buffer + sprintf (buffer, "\n:BB:ARB:CLOC:SOUR %s",
                      intExtArr[source]);

        if (source == 0) /*Internal*/
        p2data += sprintf (p2data, ";:BB:ARB:CLOC %le",clock);
    }
    else
    {
        p2data = buffer + sprintf (buffer, "\n:ARB:CLOC:SOUR %s"
                     ";:ARB:CLOC:DEL %le",
                      intExtArr[source],
                      delay);

        if (source == 0) /*Internal*/
        p2data += sprintf (p2data, ";:ARB:CLOC %le",clock);
    }
    strcat (buffer, "\n");
  CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Arb IQ Level                                        */
/* Purpose:  This function configures the arbitrary IQ level.        */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbIQLevel (ViSession instrumentHandle, ViInt32 level,
                   ViBoolean mode,
                   ViReal64 skew)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (level, -3, 6))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (mode))
        return VI_ERROR_PARAMETER3;

  CHECKERR (viPrintf (instrumentHandle, "\n:ARB:IQ:LEV %ld"
                    ";:ARB:IQ:LEV:MODE %s"
                    ";:ARB:IQ:SKEW %ldPS\n",

                      level,
                      mode ? "MAN" : "AUTO",
                      (int)skew));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Arb Waveform                                        */
/* Purpose:  This function selects or deletes the specified file.      */
/*                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_arbWav (ViSession instrumentHandle, ViBoolean operation,
                 ViString name)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 esr = 0;

    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (operation))
        return VI_ERROR_PARAMETER2;

    if (instrPtr->instrType)
    {
        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:BB:ARB:WAV:%s \"%s\";*OPC\n",
                          delSelArr[operation], name));
    }
    else
    {
        CHECKERR (viPrintf (instrumentHandle, "\n*CLS;:ARB:WAV:%s \"%s\";*OPC\n",
                          delSelArr[operation], name));

    }

    while ((esr & 1) == 0)
    {
        Delay (2.0);
        CHECKERR (viQueryf (instrumentHandle, "*ESR?\n", "%ld", &esr));
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: RF Output                                                       */
/* Purpose:  This function controls the RF output of the instrument.         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_rfOutput (ViSession instrumentHandle, ViBoolean state,
                    ViInt32 attenuator)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
    {
        if (rssmiq_invalidViInt32Range (attenuator, 0, 1))
            return VI_ERROR_PARAMETER3;
    }
    else
    {
        if (rssmiq_invalidViInt32Range (attenuator, 0, 2))
            return VI_ERROR_PARAMETER3;
    }

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n:OUTP:STATE %s;:OUTP:AMOD %s\n", offOnArr[state],
                                          outAttModeArr[attenuator]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Get RF Level Limit                                              */
/* Purpose:  This function the level range in which the level is set without */
/*           interruption in the attenuator fixed mode                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_getRFLevelLimit (ViSession instrumentHandle,
                                          ViInt32 limit, ViReal64 *level)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (limit, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (!level)
        return VI_ERROR_PARAMETER3;

    CHECKERR(viPrintf(instrumentHandle, "\n:OUTP:AFIX:RANG:%s?\n", afixedRangeArr[limit]));
    CHECKERR(viScanf(instrumentHandle, "%le", level));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Trigger Action                                                  */
/* Purpose:  This function triggers an action and optionally waits for     */
/*           the instrument to complete the triggered action.                */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_triggerAction (ViSession instrumentHandle, ViInt32 action,
                    ViBoolean wait)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViBoolean complete;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (action, 0, 8))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (wait))
        return VI_ERROR_PARAMETER3;

    CHECKERR (viPrintf (instrumentHandle, "\n%s\n", trigActionArr[action]));

    if (wait) {
      CHECKERR (rssmiq_operComplete (instrumentHandle, VI_TRUE, &complete));
  }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Operation Complete?                                             */
/* Purpose:  This function waits until all previous operations will have been*/
/*           completed. It can also check the current operation status       */
/*           without waiting to complete.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_operComplete (ViSession instrumentHandle, ViBoolean wait,
                    ViBoolean *complete)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViBoolean loop_end = 0;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (wait))
        return VI_ERROR_PARAMETER2;
    if (!complete)
      return VI_ERROR_PARAMETER3;

    /* OPC checking is done inside of this loop*/
    while (!loop_end) {
        /* This delay slows down the loop to 4 iterations per second*/
        /* Faster loop execution causes that the instrument does not behave*/
        /* correctly*/
        Delay (0.25);
        /* Checking the operation condition bit is not done by configuring*/
        /* status register masks and reading the status byte (serial poll),*/
        /* since this method does not work when doing serial I/O.*/
        CHECKERR (viQueryf (instrumentHandle, "\n:STAT:OPER:COND?\n", "%hu", complete));

        /* If instrument returns "8", the operation is in progress. "0" indicates*/
        /* that no operation is performed (or it has been completed). The value*/
        /* needs to be inverted so that the parameter complete? indicates 1 when completed.*/
        *complete = (ViBoolean)(!(*complete));
        if (wait) {
            /* Terminate loop if the operation is complete*/
            loop_end = *complete;
        }
        else {
            /* Terminate loop immediately, we are not in wait mode*/
            loop_end = 1;
        }
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Load Waveform                                                 */
/* Purpose:  Transfer user-defined I/Q waveform directly to the SMIQ RAM.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_loadWaveform (ViSession instrumentHandle, ViString name,
                               ViPReal64 I, ViPReal64 Q,ViInt32 size,
                               ViPUInt32 bytesWritten)

{
    ViStatus  rssmiq_status = VI_SUCCESS;
    ViUInt16    interface_type = VI_INTF_GPIB;
    ViInt32   headerSize, file_size;
    ViInt32   oldTimeout, i;
    ViPUInt16 tempBuffer;
    ViPUInt16 p2Buffer;
    ViPChar   p2CBuffer;
    ViChar    header[128];
    rssmiq_instrRange   instrPtr;
    ViUInt16  oldEndChar = VI_ASRL_END_NONE;
    ViBoolean oldTermChar = VI_FALSE;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!name) return VI_ERROR_PARAMETER2;
  if (!I) return VI_ERROR_PARAMETER3;
  if (!Q) return VI_ERROR_PARAMETER4;
  if (0>=size) return VI_ERROR_PARAMETER5;
  if(!bytesWritten) return VI_ERROR_PARAMETER6;

  (*bytesWritten) = 0;
  /* Create waveform header */
  sprintf (header, "\n{TYPE: WV, 0}\n{WAVEFORM-%d: 0,#", size*2*sizeof(ViUInt16)+3);

  /* Allocated temp buffer */
  tempBuffer=(ViPUInt16)malloc(2*size*sizeof(ViUInt16)+256+strlen(header)+1);

  /* Make Header */
  p2CBuffer=(ViPChar)tempBuffer;
    if (instrPtr->instrType)
    {
        sprintf(p2CBuffer,":FORM PACK;:BB:ARB:WAV:DATA '%s', #", name);
    }
    else
    {
        sprintf(p2CBuffer,":ARB:WAV:DATA \"%s\", #", name);
    }
  p2CBuffer+=strlen(p2CBuffer);
  sprintf(p2CBuffer+1,"%d",size*2*sizeof(ViUInt16)+strlen(header)+1);
  (*(p2CBuffer)) = strlen(p2CBuffer+1)+'0';
  p2CBuffer+=strlen(p2CBuffer);
  sprintf (p2CBuffer, "%s", header);
  p2CBuffer+=strlen(header);
  p2Buffer=(ViPUInt16)p2CBuffer;

  /* get header size */
  headerSize=strlen((ViPChar)tempBuffer);

  for(i=0;i<size;i++){
      /* Update buffer */
    (*p2Buffer++)=((ViUInt16)(32768.0+(I[i]*32000.0)+0.5))&0xfffc;
    (*p2Buffer++)=((ViUInt16)(32768.0+(Q[i]*32000.0)+0.5))&0xfffc;
  }

  p2CBuffer=(ViPChar)tempBuffer;
  file_size = 2*size*sizeof(ViUInt16)+headerSize;
  p2CBuffer[file_size] = '}';

  if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_INTF_TYPE, &interface_type)) < 0)
        return rssmiq_status;
    if (interface_type == VI_INTF_ASRL)
        {
        if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar)) < 0)
          return rssmiq_status;
        if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar)) < 0)
          return rssmiq_status;
        if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 20 * size)) < 0)
          return rssmiq_status;
        }
    else
        {
        CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER EOI"));
        if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 5 * size)) < 0)
            return rssmiq_status;
        }

  if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, &oldTimeout)) < 0)
        return rssmiq_status;

  /* Write buffer */
  if (rssmiq_status = (viWrite (instrumentHandle, (ViBuf)tempBuffer,
             file_size+1, bytesWritten)),
             rssmiq_status < VI_SUCCESS)
    {
    free(tempBuffer);
      if (interface_type == VI_INTF_ASRL)  /* Serial Port */
          {
          viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar);
          viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar);
          }
      else
          CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER STAN"));

    return rssmiq_status;
  }

  /* Free temp buffer */
  free(tempBuffer);
    if (interface_type == VI_INTF_ASRL)  /* Serial Port */
        {
        viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar);
        viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar);
        }
    else
        CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER STAN"));

  if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, oldTimeout)) < 0)
        return rssmiq_status;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Load Waveform File                                              */
/* Purpose:  This function transfers the "*.WV" file from the host computer  */
/*       into the SMIQ's RAM.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_loadWaveformFile (ViSession instrumentHandle, ViString name)

{
    ViStatus  rssmiq_status = VI_SUCCESS;
    ViUInt16  interface_type = VI_INTF_GPIB;
    ViInt32   headerSize;
    ViPUInt16 tempBuffer;
    ViPUInt16 p2Buffer;
    ViPChar   p2CBuffer;
    FILE      *sourceFile;
    ViInt32   file_size;
    ViUInt32  bytesWritten;
    ViUInt32  bytesRead;
    ViInt32   oldTimeout;
    ViString  p2name;
    ViChar    listName[256];
    rssmiq_instrRange   instrPtr;
    ViUInt16  oldEndChar = VI_ASRL_END_NONE;
    ViBoolean oldTermChar = VI_FALSE;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (!name) return VI_ERROR_PARAMETER2;

  /* Open file */
    if ((sourceFile = fopen (name, "rb")) == VI_NULL)
        return VI_ERROR_INSTR_FILE_OPEN; /* not defined by VTL */

  /* seek for size */
  if(fseek (sourceFile, 0, SEEK_END)) VI_ERROR_INSTR_FILE_OPEN;
  file_size=ftell(sourceFile);
  if(fseek (sourceFile, 0, SEEK_SET)) VI_ERROR_INSTR_FILE_OPEN;

  /* Allocate temp buffer */
  tempBuffer=(ViPUInt16)malloc(file_size+256);

    /* List name to be created in the instrument is same as the filename*/
    /* Extension is cut off, max length is 7 chars*/
  p2name = strrchr (name, '\\');
  strcpy (listName, p2name ? 1+p2name : name);
  if (strchr (listName, '.')) (*strchr (listName, '.')) = 0;
  if (strlen (listName) > 7) listName[7] = 0;

  /* Make Header */
  p2CBuffer=(ViPChar)tempBuffer;
    if (instrPtr->instrType)
    {
        sprintf(p2CBuffer,":BB:ARB:WAV:DATA '%s', #", listName);
    }
    else
    {
        sprintf(p2CBuffer,":ARB:WAV:DATA \"%s\", #", listName);
    }
  p2CBuffer+=strlen(p2CBuffer);
  sprintf(p2CBuffer+1,"%d",file_size);
  (*(p2CBuffer))=strlen(p2CBuffer+1)+'0';
  p2CBuffer+=strlen(p2CBuffer);
  p2Buffer=(ViPUInt16)p2CBuffer;

  /* get header size */
  headerSize=strlen((ViPChar)tempBuffer);

  /* Read file */
  bytesRead=fread (p2Buffer, 1, file_size, sourceFile);

  /* Init p2CBuffer */
  p2CBuffer=(ViPChar)tempBuffer;

  if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_INTF_TYPE, &interface_type)) < 0)
        return rssmiq_status;

    if (interface_type == VI_INTF_ASRL)
        {
    if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, &oldEndChar)) < 0)
          return rssmiq_status;
    if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, &oldTermChar)) < 0)
          return rssmiq_status;
    if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 20 * file_size)) < 0)
          return rssmiq_status;
        }
    else
      {
        CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER EOI"));
        if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 5 * file_size)) < 0)
          return rssmiq_status;
      }

  if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, &oldTimeout)) < 0)
        return rssmiq_status;
  if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, file_size*2)) < 0)
        return rssmiq_status;

  /* Write buffer */
  if (rssmiq_status = (viWrite (instrumentHandle, (ViBuf)tempBuffer,
             bytesRead+headerSize,&bytesWritten)),
             rssmiq_status < VI_SUCCESS)
    {
    free(tempBuffer);
      if (interface_type == VI_INTF_ASRL)  /* Serial Port */
          {
          viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar);
          viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar);
          }
      else
          CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER STAN"));
    return rssmiq_status;
  }

  /* Free temp buffer */
  free(tempBuffer);

  /* Close File */
  fclose(sourceFile);

    if (interface_type == VI_INTF_ASRL)  /* Serial Port */
        {
        viSetAttribute (instrumentHandle, VI_ATTR_ASRL_END_IN, oldEndChar);
        viSetAttribute (instrumentHandle, VI_ATTR_TERMCHAR_EN, oldTermChar);
        }
    else
        CHECKERR(viPrintf(instrumentHandle,":SYST:COMM:GPIB:LTER STAN"));

  if ((rssmiq_status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, oldTimeout)) < 0)
        return rssmiq_status;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Write To Instrument                                             */
/* Purpose:  This function writes a command string to the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_writeInstrData (ViSession instrumentHandle, ViString writeBuffer)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    if ((rssmiq_status = viWrite (instrumentHandle, (ViBuf)writeBuffer,
                            strlen (writeBuffer), 0)) < 0)
        return rssmiq_status;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Read Instrument Buffer                                          */
/* Purpose:  This function reads the output buffer of the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_readInstrData (ViSession instrumentHandle, ViInt32 numberBytesToRead,
                    ViChar _VI_FAR readBuffer[], ViPInt32 numBytesRead)
{
    ViStatus rssmiq_status = VI_SUCCESS;
  ViUInt32 tmpVal;

  if (numBytesRead)
    *numBytesRead = 0L;

    if ((rssmiq_status = viRead (instrumentHandle, (ViBuf)readBuffer, numberBytesToRead, &tmpVal)) < 0)
        return rssmiq_status;

  if (numBytesRead)
    *numBytesRead = (ViInt32)tmpVal;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_reset (ViSession instrumentHandle)
{
    ViUInt32 retCnt = 0;
    ViStatus rssmiq_status = VI_SUCCESS;

    /*  Initialize the instrument to a known state.  */
    if ((rssmiq_status = viWrite (instrumentHandle, (ViBuf)"\n*RST\n", 5, &retCnt)) < 0)
        return rssmiq_status;
  Delay (1.0);
    if ((rssmiq_status = rssmiq_defaultInstrSetup (instrumentHandle)) < 0)
        return rssmiq_status;

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_self_test (ViSession instrumentHandle, ViPInt16 testResult,
                    ViChar _VI_FAR testMessage[])
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    /* CHECKERR (viQueryf (instrumentHandle, "\n:TEST:ALL?", "%ld,%[^\n]", testResult, testMessage));*/
    if (instrPtr->instrType)
    {
        CHECKERR (viQueryf (instrumentHandle, "\n*TST?\n", "%ld", testResult));
    }
    else
    {
        CHECKERR (viQueryf (instrumentHandle, "\n:TEST:ALL?\n", "%ld", testResult));
    }

    strcpy (testMessage, *testResult ? "FAILED":"PASSED");

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result. If the error query function is not supported by the  */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_ERROR_QUERY.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                    ViChar _VI_FAR errorMessage[])
{
    ViStatus rssmiq_status = VI_SUCCESS;

  CHECKERR (viQueryf (instrumentHandle, "\n:SYST:ERR?\n", "%ld,\"%[^\"]", errorCode, errorMessage));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_error_message (ViSession instrumentHandle, ViStatus statusCode,
                    ViChar _VI_FAR errMessage[])
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt16 i;
    static rssmiq_tStringValPair statusDescArray[] = {
        {VI_WARN_NSUP_ID_QUERY,     "WARNING: ID Query not supported"},
        {VI_WARN_NSUP_RESET,        "WARNING: Reset not supported"},
        {VI_WARN_NSUP_SELF_TEST,    "WARNING: Self-test not supported"},
        {VI_WARN_NSUP_ERROR_QUERY,  "WARNING: Error Query not supported"},
        {VI_WARN_NSUP_REV_QUERY,    "WARNING: Revision Query not supported"},
        {VI_ERROR_PARAMETER1,   "ERROR: Parameter 1 out of range"},
        {VI_ERROR_PARAMETER2,   "ERROR: Parameter 2 out of range"},
        {VI_ERROR_PARAMETER3,   "ERROR: Parameter 3 out of range"},
        {VI_ERROR_PARAMETER4,   "ERROR: Parameter 4 out of range"},
        {VI_ERROR_PARAMETER5,   "ERROR: Parameter 5 out of range"},
        {VI_ERROR_PARAMETER6,   "ERROR: Parameter 6 out of range"},
        {VI_ERROR_PARAMETER7,   "ERROR: Parameter 7 out of range"},
        {VI_ERROR_PARAMETER8,   "ERROR: Parameter 8 out of range"},
        {VI_ERROR_FAIL_ID_QUERY,"ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE, "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_FILE_OPEN,    "ERROR: Opening the specified file"},
        {VI_ERROR_INSTR_FILE_WRITE,   "ERROR: Writing to the specified file"},
        {VI_ERROR_INSTR_FILE_READ,    "ERROR: Reading from the specified file"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response"},
        {VI_ERROR_INSTR_PARAMETER9 ,  "ERROR: Parameter 9 out of range"},
        {VI_ERROR_INSTR_PARAMETER10,  "ERROR: Parameter 10 out of range"},
        {VI_ERROR_INSTR_PARAMETER11,  "ERROR: Parameter 11 out of range"},
        {VI_ERROR_INSTR_PARAMETER12,  "ERROR: Parameter 12 out of range"},
        {VI_ERROR_INSTR_PARAMETER13,  "ERROR: Parameter 13 out of range"},
        {VI_ERROR_INSTR_PARAMETER14,  "ERROR: Parameter 14 out of range"},
        {VI_ERROR_INSTR_PARAMETER15,  "ERROR: Parameter 15 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER16,  "ERROR: Parameter 16 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER17,  "ERROR: Parameter 17 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER18,  "ERROR: Parameter 18 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER19,  "ERROR: Parameter 29 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER20,  "ERROR: Parameter 20 out of range"},
        {RSSMIQ_ERROR_INSTR_PARAMETER21,  "ERROR: Parameter 21 out of range"},


        /*=CHANGE:=============================================================*/
        /* Insert instrument-specific error codes here.  Example:              */
        /*=====================================================================*/
        {RSSMIQ_ERROR_INVALID_CONFIGURATION, "ERROR: Instrument configuration error"},
        {RSSMIQ_ERROR_INSTRUMENT_ERROR, "ERROR: Not compatible with SMU"},
        {RSSMIQ_ERROR_INSTRUMENT_OPTION, "ERROR: Option not installed"},
        {VI_NULL, VI_NULL}
    };

    rssmiq_status = viStatusDesc (instrumentHandle, statusCode, errMessage);
    if (rssmiq_status == VI_WARN_UNKNOWN_STATUS) {
        for (i = 0; statusDescArray[i].stringName; i++) {
            if (statusDescArray[i].stringVal == statusCode) {
                strcpy (errMessage, statusDescArray[i].stringName);
                return (VI_SUCCESS);
            }
        }
        sprintf (errMessage, "Unknown Error 0x%x", statusCode);
        return (VI_WARN_UNKNOWN_STATUS);
    }

    rssmiq_status = VI_SUCCESS;
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*           If the revision query function is not supported by the          */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_REV_QUERY.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_revision_query (ViSession instrumentHandle,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    ViStatus rssmiq_status = VI_SUCCESS;

    strcpy (driverRev, RSSMIQ_REVISION);

    CHECKERR (viQueryf (instrumentHandle, "*IDN?", "%*[^,],%*[^,],%*[^,],%[^\n]", instrRev));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Save/Recall Setup                                               */
/* Purpose:  This function saves or recalls instrument's setup.              */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_saveRecallSetup (ViSession instrumentHandle, ViBoolean setupMode,
                    ViInt32 setupNumber)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (setupMode))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (setupNumber, 0, 50))
        return VI_ERROR_PARAMETER3;

    CHECKERR (viPrintf (instrumentHandle, "\n%s %hd\n", setModeArr[setupMode], setupNumber));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Instrument Options                                              */
/* Purpose:  This function returns a list of options which the instrument is */
/*           equipped with.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_instrOptions (ViSession instrumentHandle, ViInt32 *options)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar   buffer[BUFFER_SIZE];
    ViChar   option[BUFFER_SIZE],
            *p2option;
    ViUInt32 i;

    static char* optionsList[] = {"SM-B1",   /* Reference oscillator OCXO */
                                  "SM-B5",   /* FM/PM modulator */
                                  "SMIQB10", /* Modulation coder */
                                  "SMIQB11", /* Data generator */
                                  "SMIQB12", /* Memory extension for SMIQB11 */
                                  "SMIQB12", /* Second memory extension */
                                  "SMIQB14", /* Fading simulator */
                                  "SMIQB15", /* Second fading simulator */
                                  "SMIQB16", /* Broadband FM */
                                  "SMIQB20", /* Modulation coder */
                                  "SMIQB21", /* Bit error rate test */
                                  "SMIQB42",
                                  "",
                                /* SMIQB43      Digital Standard W-CDMA */
                                  "SMIQB44",
                                  "SMIQB45", /* Digital Standard 3GPP W-CDMA */
                                  "SMIQB46",
                                  "SMIQB47", /* LOW ACP Filter */
                                  "SMIQB48", /* Enhanced Channels for 3GPP W-CDMA */
                                /* SMIQB49      Dynamic Fading */
                                  "SMIQB60",
                                  "SMIQK11",
                                  "SMIQB12",
                                  "SMIQB51", /*Digital Standard GPS*/
                                  "SMIQB49", /*Extended Fading Functions for W-CDMA */
                                  "SMIQB57",
                                  NULL};

    CHECKERR (viQueryf (instrumentHandle, "\n*OPT?\n", "%[^\n]", buffer));

    /* The instrument sometimes fails to return correct option     */
    /* list on the first try, so the driver works with a list read */
    /* on second try, which is always correct.                     */

    CHECKERR (viQueryf (instrumentHandle, "\n*OPT?\n", "%[^\n]", buffer));

    *options = 0;

    for (i = 0; optionsList[i]; i++)
    {
        if (strlen(optionsList[i]) == 0)
            continue;

        strcpy(option, optionsList[i]);
        p2option = buffer;

        while ((p2option = strstr(p2option, option)) != NULL)
        {
            /* the last option */
            if (strchr(p2option, ',') && !strchr(option, ','))
                strcat(option, ",");

            if (!strncmp(p2option, option, strlen(option)))
            {
                /* If option B12 has been detected we should be
                   continue search secondary SMIQB12 option. */
                if ((*options & RSSMIQ_OPT_B12) && ((1 << i) == RSSMIQ_OPT_B12SEC))
                {
                    if ((p2option = strstr(++p2option, option)) == NULL)
                        break;
                }

                *options |= (1 << i);
                break;
            }
            p2option++;
        }
    }

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Reference Oscillator                                            */
/* Purpose:  This function configures the reference frequency source.        */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_refOsc (ViSession instrumentHandle, ViBoolean source,
                    ViBoolean intAdj, ViInt32 intAdjFreq,
                    ViInt32 extOscFreq, ViReal64 deltaPhase)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViString p2data;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (source))
    return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViBooleanRange (intAdj))
    return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViInt32Range (intAdjFreq, 0, 4095))
    return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViInt32Range (extOscFreq, 1, 16))
    return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViReal64Range (deltaPhase, -270.0, 270.0))
    return VI_ERROR_PARAMETER6;

    p2data = buffer + sprintf (buffer, "\n:SOUR:ROSC:SOUR %s;:SOUR:PHASE %fDEG",
                          intExtArr[source], deltaPhase);
    if (source) {
        p2data += sprintf (p2data, ";:SOUR:ROSC:EXT:FREQ %ldMHz", extOscFreq);
    }
    else {
        p2data += sprintf (p2data, ";:SOUR:ROSC:INT:ADJ:STAT %s;VAL %ld",
                          offOnArr[intAdj], intAdjFreq);
    }
    strcat (buffer, "\n");
    CHECKERR (viWrite (instrumentHandle, buffer, strlen (buffer), 0));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Set Phase Reference                                             */
/* Purpose:  This function selects filter from list for defined system. This */
/*           action has effect only if user defined filter is selected.      */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_setPhaseReference (ViSession instrumentHandle)
{
    return viPrintf(instrumentHandle, "\n:SOUR:PHAS:REF\n");
}

/*===========================================================================*/
/* Function: Auxiliary I/O                                                   */
/* Purpose:  This function configures the TRIGGER input, BLANK output and    */
/*           MARKER outputs.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_auxIO (ViSession instrumentHandle, ViInt32 extTrigSlope, ViInt32 blankMode,
                    ViBoolean blankTime, ViBoolean blankPolarity,
                    ViBoolean markerPolarity)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViString bmodArr[] = {"SWE", "RFOF", "BUSY"};
    rssmiq_instrRange   instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->instrType)
        return RSSMIQ_ERROR_INSTRUMENT_ERROR;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (extTrigSlope, 0, 2))
        return VI_ERROR_PARAMETER2;
    if (rssmiq_invalidViInt32Range (blankMode, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rssmiq_invalidViBooleanRange (blankTime))
        return VI_ERROR_PARAMETER4;
    if (rssmiq_invalidViBooleanRange (blankPolarity))
        return VI_ERROR_PARAMETER5;
    if (rssmiq_invalidViBooleanRange (markerPolarity))
        return VI_ERROR_PARAMETER6;

    CHECKERR (viPrintf (instrumentHandle, "\n:OUTP:BLAN:MODE %s;:OUTP:BLAN:POL %s;:SOUR2:SWE:BTIM %s;:TRIG:SLOP %s;"
                        ":MARK:POL %s\n",
                        bmodArr[blankMode], normInvArr[blankPolarity], normLongArr[blankTime],
                        trigSlopArr[extTrigSlope], normInvArr[markerPolarity]));
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Beeper                                                          */
/* Purpose:  This function turns on or off the beeper.                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_beeper (ViSession instrumentHandle, ViBoolean beeper)
{
    ViStatus rssmiq_status = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViBooleanRange (beeper))
      return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n:SYST:BEEP:STAT %s\n", offOnArr[beeper]));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Calibrate                                                       */
/* Purpose:  This function performs the instrument calibration.              */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_calibrate (ViSession instrumentHandle, ViInt32 mode,
                    ViBoolean *failed)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    ViUInt32 timeout;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssmiq_invalidViInt32Range (mode, 0, 5))
    return VI_ERROR_PARAMETER2;

    CHECKERR (viPrintf (instrumentHandle, "\n%s\n", calModeArr[mode]));

    if (mode < 1 || mode > 2) {
        /* Readout of the calibration result*/
        /* Timeout is changed to 100 s temporarily*/
        CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, &timeout));

        CHECKERR (viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, 100000));

        CHECKERR (viRead (instrumentHandle, buffer, 512, 0));

        CHECKERR (viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, timeout));

        if (sscanf (buffer, "%hd", failed) != 1) {
            rssmiq_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rssmiq_status;
        }
    }
    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rssmiq_close (ViSession instrumentHandle)
{
    rssmiq_instrRange instrPtr;
    ViSession rmSession;
    ViStatus rssmiq_status = VI_SUCCESS;

    if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_RM_SESSION, &rmSession)) < 0)
        return rssmiq_status;
    if ((rssmiq_status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rssmiq_status;

    if (instrPtr != NULL)
        free (instrPtr);

    rssmiq_status = viClose (instrumentHandle);
    viClose (rmSession);

    return rssmiq_status;
}


/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViBoolean rssmiq_invalidViBooleanRange (ViBoolean val)
{
    return (ViBoolean)((val != VI_FALSE && val != VI_TRUE) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Short Signed Integer Value Out Of Range - ViInt16               */
/* Purpose:  This function checks a short signed integer value to see if it  */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssmiq_invalidViInt16Range (ViInt16 val, ViInt16 min, ViInt16 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssmiq_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Unsigned Char Value Out Of Range - ViUInt8                      */
/* Purpose:  This function checks an unsigned char value to see if it        */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssmiq_invalidViUInt8Range (ViUInt8 val, ViUInt8 min, ViUInt8 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Short Unsigned Integer Value Out Of Range - ViUInt16            */
/* Purpose:  This function checks a short unsigned integer value to see if it*/
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssmiq_invalidViUInt16Range (ViUInt16 val, ViUInt16 min, ViUInt16 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Long Unsigned Integer Value Out Of Range - ViUInt32             */
/* Purpose:  This function checks a long unsigned integer value to see if it */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssmiq_invalidViUInt32Range (ViUInt32 val, ViUInt32 min, ViUInt32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Real (Float) Value Out Of Range - ViReal32                      */
/* Purpose:  This function checks a real (float) value to see if it lies     */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rssmiq_invalidViReal32Range (ViReal32 val, ViReal32 min, ViReal32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rssmiq_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rssmiq_init function.  When   */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrumentHandle that is returned from rssmiq_init to       */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rssmiq_initCleanUp (ViSession openRMSession,
                    ViPSession openinstrumentHandle, ViStatus currentStatus)
{
    rssmiq_instrRange instrPtr;

    if (viGetAttribute (*openinstrumentHandle, VI_ATTR_USER_DATA, &instrPtr) >= 0)
        if (instrPtr != NULL)
            free (instrPtr);

    viClose (*openinstrumentHandle);
    viClose (openRMSession);
    *openinstrumentHandle = VI_NULL;

    return currentStatus;
}

/*****************************************************************************/
/*----------- INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINES HERE -------------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument.  This    */
/*           function is called by the rssmiq_reset operation and by the     */
/*           rssmiq_init function if the reset option has not been           */
/*           selected.  This function is useful for configuring any          */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions such as turning headers ON or OFF   */
/*           or using the long or short form for commands, queries, and data.*/
/*===========================================================================*/
ViStatus rssmiq_defaultInstrSetup (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 options = 0;
    rssmiq_instrRange instrPtr;

    /* Determine if the structure has been initialized for the current VISA  */
    /* Session and malloc if it has not.                                     */
    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr == NULL)
        instrPtr = malloc (sizeof (struct rssmiq_statusDataRanges));

    instrPtr -> errorChecking = VI_FALSE;
    strcpy (instrPtr -> instrDriverRevision, RSSMIQ_REVISION);

    /*Query options and set it to intrPtr*/
    CHECKERR (rssmiq_instrOptions (instrumentHandle, &options));
    instrPtr->options = options;
    CHECKERR (viSetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViUInt32)instrPtr));

    return rssmiq_status;
}

/*=========================================================================*/
/* Function: Check Status                                                  */
/* Purpose:  This function reads the ESR register.                         */
/*=========================================================================*/
ViStatus rssmiq_checkStatus (ViSession instrumentHandle)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViInt32 esrByte = 0;
    rssmiq_instrRange instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> errorChecking) { /* Is Error Checking Enabled? */
        /*--------------- Read the Standard Event Register --------------------*/
        CHECKERR (viQueryf (instrumentHandle, "*ESR?", "%ld", &esrByte));

        /*---------------- Check if any error or message bit was asserted -------*/
        if ((esrByte & 0x3C) != 0) {
           rssmiq_status = RSSMIQ_ERROR_INSTRUMENT_ERROR;
           CHECKERR (viWrite (instrumentHandle, "*CLS", 4, 0));
        } else
           rssmiq_status = VI_SUCCESS;
    }


    return rssmiq_status;
}

/*==========================================================================*/
/* Function: Swap ViUInt32                                                  */
/* Purpose:  This function reverses bytes in the ViUInt32 number.     */
/*==========================================================================*/
ViUInt32 rssmiq_swapViUInt32 (ViUInt32 val)
{
  ViChar *tmp;
  ViChar t;
  ViUInt32 valOut;

  valOut = val;

  tmp = (ViChar*)&valOut;

  t = tmp[0];
  tmp[0] = tmp[3];
  tmp[3] = t;

  t = tmp[1];
  tmp[1] = tmp[2];
  tmp[2] = t;

  return valOut;
}

/*===========================================================================*/
/* Function: Get Index From String                                           */
/* Purpose:  This function returns index for string.                         */
/*===========================================================================*/
ViStatus rssmiq_getIndexFromString (ViSession instrumentHandle, ViString string,
                                     ViString *list, ViInt32 *index)
{
    ViStatus    rssmiq_status = VI_SUCCESS;
    ViInt32     i;

    for (i =0; list[i]; i++)
        if (strncmp(string, list[i], strlen (string)) == 0) break;

    *index = i;

    return (list[i]) ? rssmiq_status : VI_ERROR_INSTR_INTERPRETING_RESPONSE;
}


/*===========================================================================*/
/* Function: Check Option                                                    */
/* Purpose:  This function checks the required options.                      */
/*===========================================================================*/
ViStatus rssmiq_checkOption (ViSession instrumentHandle, ViInt32 option)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    rssmiq_instrRange instrPtr;

    CHECKERR (viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, &instrPtr));
    if (!(option & instrPtr->options))
        return  RSSMIQ_ERROR_INSTRUMENT_OPTION;
    else
        return  rssmiq_status;
}

/*===========================================================================*/
/* Function: Get DM Format                                                   */
/* Purpose:  This function returns the format of DM                          */
/*===========================================================================*/
ViStatus rssmiq_getDMFormat(ViSession instrumentHandle, ViInt32 *format)
{
    ViStatus rssmiq_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];

    CHECKERR(viPrintf(instrumentHandle, "\n:SOUR:DM:FORMAT?\n"));
    CHECKERR(viScanf(instrumentHandle, "%s", buffer));
    CHECKERR(rssmiq_getIndexFromString(instrumentHandle, buffer, dmModArr, format));

    return rssmiq_status;
}

/*===========================================================================*/
/* Function: Delay                                                           */
/* Purpose:  This function delays without use of utility.h                   */
/*===========================================================================*/
static void rssmiq_delay (ViReal64 delay)
{
    time_t time_first, time_actual;

    time (&time_first);
    time_actual = time_first;
    while (time_actual < (time_first+delay))
        time (&time_actual);
}

/*****************************************************************************/
/*=== END INSTRUMENT DRIVER SOURCE CODE =====================================*/
/*****************************************************************************/
